set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETCOLUMN
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPCOLUMN
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETCOLUMN
       @ObjNum int,
       @DbName sysname
 AS
     set nocount on
     select c.colid,
            c.status,
            c.colstat,
            c.xusertype,
            c.xtype,
            c.length,
            isnull(c.prec,0),
            isnull(c.scale,0),
            isnull(c.cdefault,0),
            c.name,
            isnull(c.autoval,0),
            c.collation,
            databasepropertyex(@DbName, 'Collation')
     from syscolumns c
     where c.id = @ObjNum
     order by c.colid
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPCOLUMN
       @ObjNum int
 AS
declare  @index     int             /* index of NL in default text    */
declare  @wlen      int             /* Current processed length       */
declare  @DftId     int             /* Default Id number              */
declare  @ChkId     int             /* Check/Rule Id number           */
declare  @SeqId     int             /* Default Text sequence record   */
declare  @TotDft    int             /* Total Default Text length      */
declare  @Ml        int             /* current output length          */
declare  @Sl        int             /* current text length            */
declare  @cstat     smallint        /* Internal status                */
declare  @colid     smallint        /* Column Id                      */
declare  @Rule      char(1)         /* Column has a bound rule        */
declare  @SysDft    char(1)         /* Column has a bound default     */
declare  @ChkSet    char(1)         /* Multiple Check constraints     */
declare  @Ctext     varchar(255)    /* current text record            */
declare  @Stext     nvarchar(4000)  /* current text record            */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for life of this SP              *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Extended column data               *
 *--------------------------------------------------------------------*/
     create table #colext(colno   smallint,
                          ruleval char(1),
                          sdftval char(1),
                          chkset  char(1),
                          dftid   int,
                          chkid   int,
                          lendft  int,
                          seqid   int,
                          dfttext varchar(255))
/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of table columns                      *
 *--------------------------------------------------------------------*/
    declare col_cursor cursor for
     select c.colid,
            isnull(c.cdefault,0),
            isnull(c.domain,0)
     from syscolumns c
     where c.id = @ObjNum
     order by c.colid
     for read only
/*--------------------------------------------------------------------*
 *  Open the cursor for syscolumns                                    *
 *--------------------------------------------------------------------*/
    open col_cursor
/*--------------------------------------------------------------------*
 *  Process Column data                                               *
 *--------------------------------------------------------------------*/
    fetch col_cursor into @colid,
                          @DftId,
                          @ChkId

    while (@@fetch_status = 0)
    begin
      set @SeqId = 0
/*--------------------------------------------------------------------*
 *  Determine if a declared or bound default available                *
 *--------------------------------------------------------------------*/
      set @SysDft = 'N'
      if (@DftId > 0)                /* Have some type of default     */
        begin
          if (OBJECTPROPERTY(@DftId,'IsDefault') = 0)
            begin
              set @SysDft = 'D'     /* Declared default               */
/*--------------------------------------------------------------------*
 *  Get total length of default text                                  *
 *--------------------------------------------------------------------*/
              select @TotDft = sum(datalength(text))
                from syscomments
               where id = @DftId
            end
          else set @SysDft = 'B'
        end
/*--------------------------------------------------------------------*
 *  Determine if a declared check constraint or bound rule available  *
 *--------------------------------------------------------------------*/
      set @Rule = 'N'            /* No Rule or Check constraint    */
      set @ChkSet = 'N'          /* No set active                  */
      if (@ChkId > 0)            /* Have some type of check        */
        begin
          if (OBJECTPROPERTY(@ChkId,'IsRule') > 0)
            set @Rule = 'B'         /* Column or UDT bound rule       */
/*--------------------------------------------------------------------*
 *  Determine if 1 or more  Rule/Check is active                      *
 *--------------------------------------------------------------------*/
          set @index = 0
          select @index = count(*) from sysobjects
           where parent_obj = @ObjNum
             and (OBJECTPROPERTY(id,'IsCheckCnst') = 1 or OBJECTPROPERTY(id,'IsRule') = 1)
             and info = @colid
          if (@index > 0 AND @Rule = 'N') set @Rule = 'D'
          if (@index > 1) set @ChkSet = 'Y'
        end
/*--------------------------------------------------------------------*
 *  If a declared Default is active extract the text                  *
 *--------------------------------------------------------------------*/
          if (@SysDft = 'D')         /* Have a declared default       */
          begin
/*--------------------------------------------------------------------*
 *  Declare the cursor for extract of Default text for column         *
 *--------------------------------------------------------------------*/
            declare txt_cursor cursor
              LOCAL READ_ONLY
              for select datalength(s.text), s.text
                    from syscomments s
                   where s.id = @DftId
                   order by s.colid

            open txt_cursor
            fetch txt_cursor into @Sl, @Stext
            set @index = 1
            while (@@fetch_status = 0)
              begin
               set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 255 or less bytes each.             *
 *--------------------------------------------------------------------*/
               while(@Sl > 0)
               begin
                  if (@Sl < 255) set @Ml = @Sl
                  set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
                  insert into #colext values
                             (@colid,
                              @Rule,
                              @SysDft,
                              @ChkSet,
                              @DftId,
                              @ChkId,
                              @TotDft,
                              @SeqId,
                              @Ctext)
                  set @Sl = @Sl - @Ml
                  set @index = @index + @Ml
                  set @SeqId = @SeqId + 1
                end
                set @index = 1
                fetch txt_cursor into @Sl,@Stext
            end
            close txt_cursor
            deallocate txt_cursor
          end
/*--------------------------------------------------------------------*
 *  Column has no assigned default                                    *
 *  Check for Computed column, if not write basic record              *
 *--------------------------------------------------------------------*/
          else
          begin
            if (COLUMNPROPERTY(@ObjNum,@colid,'IsComputed') = 1)
              begin
                 select @Sl = datalength(s.text), @Stext = s.text
                   from syscomments s
                  where s.id = @ObjNum
                    and s.number = @colid
                    and s.colid = 1
                 set @index = 1
                 set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 255 or less bytes each.             *
 *--------------------------------------------------------------------*/
                 while(@Sl > 0)
                 begin
                   if (@Sl < 255) set @Ml = @Sl
                   set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
                   insert into #colext values
                              (@colid,
                               @Rule,
                               'V',
                               'N',
                               0,
                               0,
                               @Sl,
                               @SeqId,
                               @Ctext)
                   set @Sl = @Sl - @Ml
                   set @index = @index + @Ml
                   set @SeqId = @SeqId + 1
                end
              end
/*--------------------------------------------------------------------*
 *  Add a basic column descriptor record                              *
 *--------------------------------------------------------------------*/
              else
                insert into #colext values
                           (@colid,
                            @Rule,
                            @SysDft,
                            @ChkSet,
                            @DftId,
                            @ChkId,
                            0,
                            0,
                           ' ')
          end
          fetch col_cursor into @colid,
                                @DftId,
                                @ChkId
        end
      close col_cursor
      deallocate col_cursor
/*--------------------------------------------------------------------*
 *  Select the returned data                                          *
 *--------------------------------------------------------------------*/
      select colno,
             ruleval,
             sdftval,
             chkset,
             dftid,
             chkid,
             lendft,
             seqid,
             dfttext
        from #colext
        order by colno,seqid
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETCOLUMN to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPCOLUMN to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go
