set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETDEPENDS
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETDEPENDS
       @CidUid    smallint,
       @CidName   sysname
 AS
DECLARE @DepUid    smallint         /* Uid to search for              */
DECLARE @ReqUid    smallint         /* Required Object Uid            */
DECLARE @RefUid    smallint         /* Reference Object Uid           */
DECLARE @ReqType   smallint         /* Required Object Type           */
DECLARE @RefType   smallint         /* Reference Object type          */
DECLARE @ReqCName  sysname          /* Required Object Creator Name   */
DECLARE @ReqOName  sysname          /* Required Object Name           */
DECLARE @RefCName  sysname          /* Reference Object Creator Name  */
DECLARE @RefOName  sysname          /* Reference Object Name          */
DECLARE @DepRQ     tinyint          /* Dependency is REQUIRES         */
DECLARE @DepSA     tinyint          /* Dependency selall attribute    */
DECLARE @DepUA     tinyint          /* Dependency resultobj attribute */
DECLARE @DepRA     tinyint          /* Dependency readobj attribute   */
DECLARE @Resolve   tinyint          /* Process input Uid name         */

/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     set nocount on
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  If Internal UID not provided extract it now                       *
 *--------------------------------------------------------------------*/
     set @DepUid = @CidUid
     if (@DepUid = 0) set @DepUid = user_id(@CidName)

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Dependency List                    *
 *--------------------------------------------------------------------*/
     create table #deplist(ReqUid   smallint,
                           ReqCName sysname,
                           ReqOName sysname,
                           ReqType  smallint,
                           RefUid   smallint,
                           RefCName sysname,
                           RefOName sysname,
                           RefType  smallint,
                           DepType  char(1))

/*--------------------------------------------------------------------*
 *  Declare the search cursor                                         *
 *--------------------------------------------------------------------*/
    DECLARE dlst CURSOR FOR
       select p.uid,
              user_name(p.uid),
              p.name,
              case
                when OBJECTPROPERTY(p.id,'IsView') = 1      then 1
                when OBJECTPROPERTY(p.id,'IsUserTable') = 1 then 2
                when OBJECTPROPERTY(p.id,'IsProcedure') = 1 then 3
                when OBJECTPROPERTY(p.id,'IsTrigger') = 1   then 4
                when OBJECTPROPERTY(p.id,'IsInlineFunction') = 1   then 5
                when OBJECTPROPERTY(p.id,'IsScalarFunction') = 1   then 5
                when OBJECTPROPERTY(p.id,'IsTableFunction') = 1   then 5
                else 99
              end,
              d.uid,
              user_name(d.uid),
              d.name,
              case
                when OBJECTPROPERTY(d.id,'IsView') = 1      then 1
                when OBJECTPROPERTY(d.id,'IsUserTable') = 1 then 2
                when OBJECTPROPERTY(d.id,'IsProcedure') = 1 then 3
                when OBJECTPROPERTY(d.id,'IsTrigger') = 1   then 4
                when OBJECTPROPERTY(d.id,'IsInlineFunction') = 1   then 5
                when OBJECTPROPERTY(d.id,'IsScalarFunction') = 1   then 5
                when OBJECTPROPERTY(d.id,'IsTableFunction') = 1   then 5
                else 99
              end,
              convert(tinyint,f.selall),
              convert(tinyint,f.resultobj),
              convert(tinyint,f.readobj),
              convert(tinyint,0)
         from sysobjects p, sysobjects d, sysdepends f
        where f.id <> f.depid
          and d.id = f.id
          and p.id = f.depid
          and (p.uid = @DepUid or d.uid = @DepUid)
          and p.name != 'sysconstraints'
          and objectproperty(p.id,'IsCheckCnst') = 0
          and objectproperty(p.id,'IsSystemTable') = 0
          and objectproperty(d.id,'IsCheckCnst') = 0
          and objectproperty(d.id,'IsSystemTable') = 0
       UNION
       select p.uid,
              user_name(p.uid),
              p.name,
              case
                when OBJECTPROPERTY(p.id,'IsView') = 1      then 1
                when OBJECTPROPERTY(p.id,'IsUserTable') = 1 then 2
                when OBJECTPROPERTY(p.id,'IsProcedure') = 1 then 3
                when OBJECTPROPERTY(p.id,'IsTrigger') = 1   then 4
                when OBJECTPROPERTY(p.id,'IsInlineFunction') = 1   then 5
                when OBJECTPROPERTY(p.id,'IsScalarFunction') = 1   then 5
                when OBJECTPROPERTY(p.id,'IsTableFunction') = 1   then 5
                else 99
              end,
              d.uid,
              user_name(d.uid),
              d.name,
              4,              /* Explicit Id of a Dependent Trigger */
              convert(tinyint,0),
              convert(tinyint,0),
              convert(tinyint,0),
              convert(tinyint,1)
         from sysobjects p, sysobjects d
        where OBJECTPROPERTY(d.id,'IsTrigger') = 1
          and (p.uid = @DepUid or d.uid = @DepUid)
          and p.id = d.parent_obj
        order by 1,3
    FOR READ ONLY

/*--------------------------------------------------------------------*
 *  Scan The System Dependencies for a result set                     *
 *--------------------------------------------------------------------*/
    OPEN dlst
    FETCH dlst INTO @ReqUid, @ReqCName, @ReqOName, @ReqType,
                    @RefUid, @RefCName, @RefOName, @RefType,
                    @DepSA,  @DepUA,    @DepRA,    @DepRQ
    set @Resolve = 1            /* Need to resolve input Uid       */

/*--------------------------------------------------------------------*
 *  Process the set of dependencies returned by the Query             *
 *--------------------------------------------------------------------*/
    while (@@fetch_status = 0)
     begin

/*--------------------------------------------------------------------*
 *  Mark the 1st record to identify which Uid is the Input Uid        *
 *--------------------------------------------------------------------*/
      if (@Resolve = 1)
       begin
        if (@ReqUid = @DepUid) set @ReqType = @ReqType + 256
        else set @RefType = @RefType + 256
        set @Resolve = 0
       end
/*--------------------------------------------------------------------*
 *  Add the record(s) to the set                                      *
 *--------------------------------------------------------------------*/
      if (@DepRQ = 0 AND @DepSA = 0 AND @DepUA = 0 AND @DepRA = 0)
         insert into #deplist values
           (@ReqUid,
            @ReqCName,
            @ReqOName,
            @ReqType,
            @RefUid,
            @RefCName,
            @RefOName,
            @RefType,
            'N')
      else
       begin
        if (@DepRQ = 1)
           insert into #deplist values
             (@ReqUid,
              @ReqCName,
              @ReqOName,
              @ReqType,
              @RefUid,
              @RefCName,
              @RefOName,
              @RefType,
              'R')
        if (@DepUA = 1)
           insert into #deplist values
             (@ReqUid,
              @ReqCName,
              @ReqOName,
              @ReqType,
              @RefUid,
              @RefCName,
              @RefOName,
              @RefType,
              'M')
        if (@DepSA = 1 or @DepRA = 1)
           insert into #deplist values
             (@ReqUid,
              @ReqCName,
              @ReqOName,
              @ReqType,
              @RefUid,
              @RefCName,
              @RefOName,
              @RefType,
              'S')
       end

/*--------------------------------------------------------------------*
 *  Get the next result set record                                    *
 *--------------------------------------------------------------------*/
      FETCH dlst INTO @ReqUid, @ReqCName, @ReqOName, @ReqType,
                      @RefUid, @RefCName, @RefOName, @RefType,
                      @DepSA,  @DepUA,    @DepRA,    @DepRQ
     end

/*--------------------------------------------------------------------*
 *  Close the cursor                                                  *
 *--------------------------------------------------------------------*/
    close dlst
    deallocate dlst

/*--------------------------------------------------------------------*
 *  Return the Dependency Result Set to our caller                    *
 *--------------------------------------------------------------------*/
    select ReqUid, ReqCName, ReqOName, ReqType,
           RefUid, RefCName, RefOName, RefType,
           DepType
      from #deplist
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETDEPENDS to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

