set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETINDEX
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSINDEXLIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETINDEX
       @ObjNum int
 AS
declare  @obj_name  nvarchar(258)   /* User.Table Name                */
declare  @idxname   sysname         /* Index name                     */
declare  @grpname   sysname         /* Index FileGroup name           */
declare  @status    int             /* Index status flags             */
declare  @groupid   smallint        /* FileGroup Id                   */
declare  @rowinpage smallint        /* rows per page                  */
declare  @idxid     smallint        /* Index identifier               */
declare  @keycnt    smallint        /* Number keys in index           */
declare  @fillfact  tinyint         /* Original Fill Factor           */
declare  @Pkd       char(1)         /* Primary Key Index              */
declare  @Unq       char(1)         /* Unique index                   */
declare  @Cls       char(1)         /* Clustered index                */
declare  @Dup       char(1)         /* Duplicates valid               */
declare  @Key       char(1)         /* Ignore duplicate key           */
declare  @Row       char(1)         /* Ignore duplicate row           */
declare  @Pad       char(1)         /* PAD Index                      */
declare  @GDft      char(1)         /* Index FileGroup is default     */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Index Key data.                    *
 *--------------------------------------------------------------------*/
     create table #idxkeys(idxname  sysname,
                           grpname  sysname,
                           groupid  smallint,
                           dupval   char(1),
                           ignkey   char(1),
                           ignrow   char(1),
                           pkdidx   char(1),
                           unqidx   char(1),
                           clsidx   char(1),
                           padidx   char(1),
                           groupdft char(1),
                           fillfact tinyint,
                           rowpage  smallint,
                           keycnt   smallint,
                           cname1   sysname,
                           cname1s  char(1),
                           cname2   sysname null,
                           cname2s  char(1) null,
                           cname3   sysname null,
                           cname3s  char(1) null,
                           cname4   sysname null,
                           cname4s  char(1) null,
                           cname5   sysname null,
                           cname5s  char(1) null,
                           cname6   sysname null,
                           cname6s  char(1) null,
                           cname7   sysname null,
                           cname7s  char(1) null,
                           cname8   sysname null,
                           cname8s  char(1) null,
                           cname9   sysname null,
                           cname9s  char(1) null,
                           cname10  sysname null,
                           cname10s char(1) null,
                           cname11  sysname null,
                           cname11s char(1) null,
                           cname12  sysname null,
                           cname12s char(1) null,
                           cname13  sysname null,
                           cname13s char(1) null,
                           cname14  sysname null,
                           cname14s char(1) null,
                           cname15  sysname null,
                           cname15s char(1) null,
                           cname16  sysname null,
                           cname16s char(1) null)

/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of sysindexes for Index rows          *
 *--------------------------------------------------------------------*/
    declare idx_cursor cursor for
        select i.name,
               i.groupid,
               isnull(FILEGROUP_NAME(i.groupid),' '),
               i.indid,
               i.status,
               isnull(i.OrigFillFactor,0),
               case
                 when (isnull(IndexProperty(@ObjNum,i.name,N'IsPadIndex'),0) <> 0) then 'Y'
                 else 'N'
               end,
               case
                 when (isnull(FILEGROUPPROPERTY(FILEGROUP_NAME(i.groupid),'IsDefault'),0) <> 0)
                   then 'Y'
                   else 'N'
               end,
               (select count(x.id)
                  from sysindexkeys x
                 where i.indid = x.indid and x.id = i.id)
          from sysindexes i
          where i.id = @ObjNum
            and i.indid > 0
            and i.indid < 255
            and INDEXPROPERTY(@ObjNum,i.name,'IsStatistics') <> 1
            and INDEXPROPERTY(@ObjNum,i.name,'IsAutoStatistics') <> 1
            and INDEXPROPERTY(@ObjNum,i.name,'IsHypothetical') <> 1
          for read only

/*--------------------------------------------------------------------*
 *  Build fully qualified name of owning table                        *
 *--------------------------------------------------------------------*/
     set @obj_name = user_name(OBJECTPROPERTY(@ObjNum,'OwnerId')) + '.' + object_name(@ObjNum)
/*--------------------------------------------------------------------*
 *  Open the cursor for sysindexes                                    *
 *--------------------------------------------------------------------*/
    open idx_cursor

/*--------------------------------------------------------------------*
 *  Process the rows returned and populate entries in                 *
 *  #idxkeys temporary table                                          *
 *--------------------------------------------------------------------*/
    set @rowinpage = 0
    fetch idx_cursor into @idxname,
                          @groupid,
                          @grpname,
                          @idxid,
                          @status,
                          @fillfact,
                          @Pad,
                          @GDft,
                          @keycnt

    while (@@fetch_status = 0)
    begin
      set @Pkd = 'N'
      set @Unq = 'D'
      if (@status & 2 = 2)           /* Unique or Primary Key index   */
        set @Unq = 'U'

      if (@status & 2048 = 2048) select @Pkd = 'Y'   /* Primary Key */
      if (@status & 4096 = 4096) select @Unq = 'R'   /* Unq Constraint */

      set @Cls = 'N'
      if (@status & 16 = 16)         /* Clustered Index               */
        set @Cls = 'Y'

/*--------------------------------------------------------------------*
 *  Determine Duplicate Key/Row options                               *
 *--------------------------------------------------------------------*/
      set @Dup = 'N'
      if (@status & 64 = 64)         /* Duplicates valid              */
        set @Dup = 'Y'

      set @Key = 'N'
      if (@status & 1 = 1)           /* Ignore duplicate key          */
        set @Key = 'Y'

      set @Row = 'N'
      if (@status & 4 = 4)           /* Ignore duplicate row          */
        set @Row = 'Y'

/*--------------------------------------------------------------------*
 *  Build the record by requesting the Index Column name for          *
 *  each active key position.                                         *
 *--------------------------------------------------------------------*/
      if (@keycnt is not null)
         insert into #idxkeys values
               (@idxname,
                @grpname,
                @groupid,
                @Dup,
                @Key,
                @Row,
                @Pkd,
                @Unq,
                @Cls,
                @Pad,
                @GDft,
                @fillfact,
                @rowinpage,
                @keycnt,
                isnull(index_col(@obj_name,@idxid,1),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,1,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,2),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,2,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,3),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,3,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,4),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,4,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,5),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,5,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,6),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,6,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,7),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,7,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,8),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,8,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,9),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,9,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,10),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,10,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,11),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,11,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,12),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,12,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,13),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,13,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,14),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,14,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,15),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,15,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,16),' '),
                case
                   when INDEXKEY_PROPERTY(@ObjNum,@idxid,16,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end)

    fetch idx_cursor into @idxname,
                          @groupid,
                          @grpname,
                          @idxid,
                          @status,
                          @fillfact,
                          @Pad,
                          @GDft,
                          @keycnt
    end

/*--------------------------------------------------------------------*
 *  Close the cursor for sysindexes                                   *
 *--------------------------------------------------------------------*/
    close idx_cursor
    deallocate idx_cursor

/*--------------------------------------------------------------------*
 *  Select the returned data, if any, for the Table Indexes           *
 *--------------------------------------------------------------------*/
     select idxname,grpname,groupid,
            dupval,ignkey,ignrow,
            pkdidx,unqidx,clsidx,
            padidx,groupdft,fillfact,
            rowpage,keycnt,
            cname1,cname1s,cname2,cname2s,cname3,cname3s,cname4,cname4s,
            cname5,cname5s,cname6,cname6s,cname7,cname7s,cname8,cname8s,
            cname9,cname9s,cname10,cname10s,cname11,cname11s,cname12,cname12s,
            cname13,cname13s,cname14,cname14s,cname15,cname15s,cname16,cname16s
        from #idxkeys
     return(0)
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSINDEXLIST
       @ExclType smallint,
       @InclType smallint
 AS
declare  @tid       int             /* Table object id                */
declare  @status    int             /* Index status flags             */
declare  @cid       smallint        /* Table owner Id                 */
declare  @idxid     smallint        /* Index identifier               */
declare  @keycnt    smallint        /* Number keys in index           */
declare  @mode      smallint        /* Table exclusion mode           */
declare  @obj_name  nvarchar(258)   /* User.Table Name                */
declare  @idxname   sysname         /* Index name                     */
declare  @Unq       char(1)         /* Index Type U, D, P             */
declare  @Use       char(1)         /* Output record                  */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Index Key data.                    *
 *--------------------------------------------------------------------*/
     create table #idxlist(cidname  sysname,
                           tblname  sysname,
                           idxname  sysname,
                           unqidx   char(1),
                           keycnt   smallint,
                           cname1   sysname,
                           cname1s  char(1),
                           cname2   sysname null,
                           cname2s  char(1) null,
                           cname3   sysname null,
                           cname3s  char(1) null,
                           cname4   sysname null,
                           cname4s  char(1) null,
                           cname5   sysname null,
                           cname5s  char(1) null,
                           cname6   sysname null,
                           cname6s  char(1) null,
                           cname7   sysname null,
                           cname7s  char(1) null,
                           cname8   sysname null,
                           cname8s  char(1) null,
                           cname9   sysname null,
                           cname9s  char(1) null,
                           cname10  sysname null,
                           cname10s char(1) null,
                           cname11  sysname null,
                           cname11s char(1) null,
                           cname12  sysname null,
                           cname12s char(1) null,
                           cname13  sysname null,
                           cname13s char(1) null,
                           cname14  sysname null,
                           cname14s char(1) null,
                           cname15  sysname null,
                           cname15s char(1) null,
                           cname16  sysname null,
                           cname16s char(1) null)

/*--------------------------------------------------------------------*
 *  Determine the Table exclusion mode                                *
 *--------------------------------------------------------------------*/
    set @mode = 0
    if (@ExclType & 4 = 4) set @mode = 1          /* System Tables */
    if (@ExclType & 2 = 2) set @mode = @mode + 2  /* PK Tables     */

/*--------------------------------------------------------------------*
 *  Declare,Open the appropriate cursor and fetch 1st record          *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of sysindexes                         *
 *  Includes all indexes                                              *
 *--------------------------------------------------------------------*/
    declare lst_cursor0 cursor for
        select i.name,
               i.indid,
               i.status,
               (select count(x.id)
                  from sysindexkeys x
                 where i.indid = x.indid and x.id = i.id),
               i.id,
               o.uid
          from sysindexes i, sysobjects o
          where OBJECTPROPERTY(o.id,'IsTable') = 1
            and OBJECTPROPERTY(o.id,'TableHasIndex') = 1
            and o.id = i.id
            and i.indid > 0
            and i.indid < 255
            and INDEXPROPERTY(o.id,i.name,'IsStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsAutoStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsHypothetical') <> 1
          for read only
        OPEN lst_cursor0
        fetch lst_cursor0 into @idxname,
                               @idxid,
                               @status,
                               @keycnt,
                               @tid,
                               @cid
      end

    if @mode = 1
      begin
/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of sysindexes                         *
 *  Excludes indexes for System Tables                                *
 *--------------------------------------------------------------------*/
    declare lst_cursor1 cursor for
        select i.name,
               i.indid,
               i.status,
               (select count(x.id)
                  from sysindexkeys x
                 where i.indid = x.indid and x.id = i.id),
               i.id,
               o.uid
          from sysindexes i, sysobjects o
          where OBJECTPROPERTY(o.id,'IsTable') = 1
            and OBJECTPROPERTY(o.id,'TableHasIndex') = 1
            and OBJECTPROPERTY(o.id,'IsSystemTable') = 0
            and o.id = i.id
            and i.indid > 0
            and i.indid < 255
            and INDEXPROPERTY(o.id,i.name,'IsStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsAutoStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsHypothetical') <> 1
          for read only
        OPEN lst_cursor1
        fetch lst_cursor1 into @idxname,
                               @idxid,
                               @status,
                               @keycnt,
                               @tid,
                               @cid
      end

    if @mode = 2
      begin
/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of sysindexes                         *
 *  Excludes indexes for Tables with Primary Keys                     *
 *--------------------------------------------------------------------*/
    declare lst_cursor2 cursor for
        select i.name,
               i.indid,
               i.status,
               (select count(x.id)
                  from sysindexkeys x
                 where i.indid = x.indid and x.id = i.id),
               i.id,
               o.uid
          from sysindexes i, sysobjects o
          where OBJECTPROPERTY(o.id,'IsTable') = 1
            and OBJECTPROPERTY(o.id,'TableHasIndex') = 1
            and OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 0
            and o.id = i.id
            and i.indid > 0
            and i.indid < 255
            and INDEXPROPERTY(o.id,i.name,'IsStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsAutoStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsHypothetical') <> 1
          for read only
        OPEN lst_cursor2
        fetch lst_cursor2 into @idxname,
                               @idxid,
                               @status,
                               @keycnt,
                               @tid,
                               @cid
      end

    if @mode = 3
      begin
/*--------------------------------------------------------------------*
 *  Declare the cursor for scan of sysindexes                         *
 *  Excludes indexes for System Tables and Tables with Primary Keys   *
 *--------------------------------------------------------------------*/
    declare lst_cursor3 cursor for
        select i.name,
               i.indid,
               i.status,
               (select count(x.id)
                  from sysindexkeys x
                 where i.indid = x.indid and x.id = i.id),
               i.id,
               o.uid
          from sysindexes i, sysobjects o
          where OBJECTPROPERTY(o.id,'IsTable') = 1
            and OBJECTPROPERTY(o.id,'IsSystemTable') = 0
            and OBJECTPROPERTY(o.id,'TableHasIndex') = 1
            and OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 0
            and o.id = i.id
            and i.indid > 0
            and i.indid < 255
            and INDEXPROPERTY(o.id,i.name,'IsStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsAutoStatistics') <> 1
            and INDEXPROPERTY(o.id,i.name,'IsHypothetical') <> 1
          for read only
        OPEN lst_cursor3
        fetch lst_cursor3 into @idxname,
                               @idxid,
                               @status,
                               @keycnt,
                               @tid,
                               @cid
      end

/*--------------------------------------------------------------------*
 *  Process the rows returned and populate entries in                 *
 *  #idxlist temporary table                                          *
 *--------------------------------------------------------------------*/
    while (@@fetch_status = 0)
    begin
      set @Unq = 'D'              /* Assume Duplicates allowed     */
      if (@status & 2 = 2) set @Unq = 'U'     /* Unique or PK         */
      if (@status & 2048 = 2048) set @Unq = 'P'      /* Primary Key   */

/*--------------------------------------------------------------------*
 *  Determine if index type to be included                            *
 *--------------------------------------------------------------------*/
     set @Use = 'N'              /* Assume excluded                */
     if (@InclType & 1 = 1 and @Unq = 'P') set @Use = 'Y'
     if (@InclType & 2 = 2 and @Unq = 'U') set @Use = 'Y'
     if (@InclType & 4 = 4 and @Unq = 'D') set @Use = 'Y'

/*--------------------------------------------------------------------*
 *  Add the index record to the Temporary table                       *
 *--------------------------------------------------------------------*/
     if (@Use = 'Y')
       begin
         set @obj_name = user_name(@cid) + '.' + object_name(@tid)
         insert into #idxlist values
               (user_name(@cid),
                object_name(@tid),
                @idxname,
                @Unq,
                @keycnt,
                isnull(index_col(@obj_name,@idxid,1),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,1,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,2),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,2,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,3),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,3,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,4),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,4,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,5),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,5,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,6),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,6,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,7),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,7,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,8),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,8,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,9),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,9,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,10),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,10,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,11),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,11,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,12),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,12,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,13),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,13,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,14),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,14,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,15),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,15,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end,
                isnull(index_col(@obj_name,@idxid,16),' '),
                case
                   when INDEXKEY_PROPERTY(@tid,@idxid,16,'IsDescending') <> 1
                     then ' '
                     else 'Y'
                end)
       end
/*--------------------------------------------------------------------*
 *  Fetch the next record using the proper cursor                     *
 *--------------------------------------------------------------------*/
      if @mode = 0
          fetch lst_cursor0 into @idxname,
                                 @idxid,
                                 @status,
                                 @keycnt,
                                 @tid,
                                 @cid

      if @mode = 1
          fetch lst_cursor1 into @idxname,
                                 @idxid,
                                 @status,
                                 @keycnt,
                                 @tid,
                                 @cid

      if @mode = 2
          fetch lst_cursor2 into @idxname,
                                 @idxid,
                                 @status,
                                 @keycnt,
                                 @tid,
                                 @cid

      if @mode = 3
          fetch lst_cursor3 into @idxname,
                                 @idxid,
                                 @status,
                                 @keycnt,
                                 @tid,
                                 @cid
    end

/*--------------------------------------------------------------------*
 *  Close the Query cursor                                            *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
        CLOSE lst_cursor0
        deallocate lst_cursor0
     end

    if @mode = 1
      begin
        CLOSE lst_cursor1
        deallocate lst_cursor1
     end

    if @mode = 2
      begin
        CLOSE lst_cursor2
        deallocate lst_cursor2
     end

    if @mode = 3
      begin
        CLOSE lst_cursor3
        deallocate lst_cursor3
     end

/*--------------------------------------------------------------------*
 *  Select the returned data, if any, for the Index List              *
 *--------------------------------------------------------------------*/
     select cidname,tblname,idxname,
            unqidx,keycnt,
            cname1,cname1s,cname2,cname2s,cname3,cname3s,cname4,cname4s,
            cname5,cname5s,cname6,cname6s,cname7,cname7s,cname8,cname8s,
            cname9,cname9s,cname10,cname10s,cname11,cname11s,cname12,cname12s,
            cname13,cname13s,cname14,cname14s,cname15,cname15s,cname16,cname16s
        from #idxlist
        order by cidname,tblname,idxname
     return(0)
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETINDEX to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSINDEXLIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

