set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKDEF
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKLIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKDEF
       @ObjNum int
 AS
declare  @numkey    smallint        /* Number of keys in index        */
declare  @idxid     smallint        /* Index identifier               */
declare  @obj_name  nvarchar(258)   /* User.Table Name                */
declare  @idx_name  sysname         /* Primary Key Index name         */
declare  @user      smallint        /* Table owner Id                 */
declare  @status    int             /* Index status flag              */
declare  @i         smallint        /* Loop variable                  */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for life of this SP              *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Primary Key data.                  *
 *  The contents of this table are inserted by the CSSBLDPKDEF SP     *
 *--------------------------------------------------------------------*/
     create table #pkdkeys(colname    sysname,
                           keyseq     smallint,
                           pkidxid    smallint,
                           pkidxname  sysname)

/*--------------------------------------------------------------------*
 *  Build the Fully Qualified Table Name                              *
 *--------------------------------------------------------------------*/
     set @obj_name = user_name(OBJECTPROPERTY(@ObjNum,'OwnerId')) + '.' + object_name(@ObjNum)
/*--------------------------------------------------------------------*
 *  If the Table has a Primary Key. Locate the Index for it           *
 *--------------------------------------------------------------------*/
     if (OBJECTPROPERTY(@ObjNum,'TableHasPrimaryKey') = 1)
     begin
       set @numkey = 0
       set @idxid  = 0
       select @numkey =
              (select count(x.id)
               from sysindexkeys x
               where i.indid = x.indid and x.id = i.id),
              @idxid = i.indid,
              @status = i.status,
              @idx_name = i.name
          from sysindexes i
          where i.id = @ObjNum
            and i.indid > 0
            and (i.status & 2048) = 2048
/*--------------------------------------------------------------------*
 *  Build the record by requesting the Index Column name for          *
 *  each active key position.                                         *
 *--------------------------------------------------------------------*/
       if (@numkey > 0)
       begin
          set @i = 1
          while @i <= @numkey
          begin
             insert into #pkdkeys values
                (isnull(index_col(@obj_name,@idxid,@i),''),
                 @i,
                 @idxid,
                 @idx_name)
             set @i = @i + 1
          end
       end
     end
/*--------------------------------------------------------------------*
 *  Select the returned data, if any, for the Primary Keys            *
 *--------------------------------------------------------------------*/
     select colname, keyseq, pkidxid, pkidxname
        from #pkdkeys
        order by keyseq
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKLIST
       @CidPattern sysname,
       @TblPattern sysname
 AS
declare  @objnum    int             /* Current Object Number          */
declare  @numkey    smallint        /* Number of keys in index        */
declare  @cid_name  sysname         /* Creator Name                   */
declare  @tbl_name  sysname         /* Table Name                     */
declare  @user      smallint        /* Table owner Id                 */
declare  @mode      smallint        /* Query Mode in effect           */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Primary Key List                   *
 *--------------------------------------------------------------------*/
     create table #pkdlist(CidName sysname,
                           TblName sysname)

/*--------------------------------------------------------------------*
 *  Compute the Query select to use for this scan                     *
 *  bas-ed on whether the input patterns have LIKE wildcards.          *
 *  Mode values are:                                                  *
 *       0 - Explicit Creator name and Explicit Table name            *
 *       1 - Generic Creator name and Explicit Table name             *
 *       2 - Explicit Creator name and Generic Table name             *
 *       3 - Generic Creator name and Generic Table name              *
 *--------------------------------------------------------------------*/
     set @mode = 0               /* Assume Explicit CID/TBL names  */

/*--------------------------------------------------------------------*
 *  Check Creator Name for LIKE wildcard characters                   *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@CidPattern) > 0) or
         (charindex('_',@CidPattern) > 0))
       set @mode = 1

/*--------------------------------------------------------------------*
 *  Check Table Name for LIKE wildcard characters                     *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@TblPattern) > 0) or
         (charindex('_',@TblPattern) > 0))
       set @mode = @mode + 2

/*--------------------------------------------------------------------*
 *  Open the appropriate cursor and fetch 1st record                  *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
DECLARE plst0 CURSOR FOR
     SELECT u.name, o.name, o.id
       FROM sysusers u, sysobjects o
      WHERE u.name = @CidPattern
        AND o.uid = u.uid
        AND o.name = @TblPattern
        AND OBJECTPROPERTY(o.id,'IsTable') = 1
        AND OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 1
      FOR READ ONLY
        OPEN plst0
        FETCH plst0 INTO @cid_name, @tbl_name, @objnum
      end

    if @mode = 1
      begin
DECLARE plst1 CURSOR FOR
     SELECT u.name, o.name, o.id
       FROM sysusers u, sysobjects o
      WHERE u.name like @CidPattern
        AND o.uid = u.uid
        AND o.name = @TblPattern
        AND OBJECTPROPERTY(o.id,'IsTable') = 1
        AND OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 1
      FOR READ ONLY
        OPEN plst1
        FETCH plst1 INTO @cid_name, @tbl_name, @objnum
      end

    if @mode = 2
      begin
DECLARE plst2 CURSOR FOR
     SELECT u.name, o.name, o.id
       FROM sysusers u, sysobjects o
      WHERE u.name = @CidPattern
        AND o.uid = u.uid
        AND o.name like @TblPattern ESCAPE ''!''
        AND OBJECTPROPERTY(o.id,'IsTable') = 1
        AND OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 1
      FOR READ ONLY
        OPEN plst2
        FETCH plst2 INTO @cid_name, @tbl_name, @objnum
      end

    if @mode = 3
      begin
DECLARE plst3 CURSOR FOR
     SELECT u.name, o.name, o.id
       FROM sysusers u, sysobjects o
      WHERE u.name like @CidPattern
        AND o.uid = u.uid
        AND o.name like @TblPattern
        AND OBJECTPROPERTY(o.id,'IsTable') = 1
        AND OBJECTPROPERTY(o.id,'TableHasPrimaryKey') = 1
      FOR READ ONLY
        OPEN plst3
        FETCH plst3 INTO @cid_name, @tbl_name, @objnum
      end
/*--------------------------------------------------------------------*
 *  Process the set of tables returned by the Query                   *
 *--------------------------------------------------------------------*/
    while (@@fetch_status = 0)
     begin
/*--------------------------------------------------------------------*
 *  Find the Index for the Primary Key                                *
 *--------------------------------------------------------------------*/
       set @numkey = null
       select @numkey = keycnt
          from sysindexes
          where id = @objnum
            and indid > 0
            and (status & 2048) = 2048
/*--------------------------------------------------------------------*
 *  If an entry was found then add the row to the Result Table        *
 *--------------------------------------------------------------------*/
       if (@numkey is not null)
       begin
         insert into #pkdlist values(@cid_name, @tbl_name)
       end

/*--------------------------------------------------------------------*
 *  Retrieve next record in result set                                *
 *--------------------------------------------------------------------*/
    if @mode = 0
        FETCH plst0 INTO @cid_name, @tbl_name, @objnum

    if @mode = 1
        FETCH plst1 INTO @cid_name, @tbl_name, @objnum

    if @mode = 2
        FETCH plst2 INTO @cid_name, @tbl_name, @objnum

    if @mode = 3
        FETCH plst3 INTO @cid_name, @tbl_name, @objnum

     end                               /* Loop thru result set        */

/*--------------------------------------------------------------------*
 *  Close the Query cursor                                            *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
        CLOSE plst0
        deallocate plst0
      end

    if @mode = 1
      begin
        CLOSE plst1
        deallocate plst1
      end

    if @mode = 2
      begin
        CLOSE plst2
        deallocate plst2
      end

    if @mode = 3
      begin
        CLOSE plst3
        deallocate plst3
      end

/*--------------------------------------------------------------------*
 *  Select the returned data, if any, for the Primary Keys            *
 *--------------------------------------------------------------------*/
     select CidName, TblName
        from #pkdlist
        order by CidName, TblName
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKDEF to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETPKLIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

