set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSFINDRULE
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULE
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPRULE
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULELIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSFINDRULE
       @CidName   sysname,
       @ObjName   sysname
 AS
     select  o.id,
             o.uid,
             o.name,
             u.name
     from sysobjects o, sysusers u
     where OBJECTPROPERTY(o.id,'IsRule') = 1
       and o.name = @ObjName
       and u.uid = o.uid
       and u.name = @CidName
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULE
       @ObjNum int
 AS
     select  o.uid,
             o.name,
             u.name
     from sysobjects o, sysusers u
     where o.id = @ObjNum
       and OBJECTPROPERTY(o.id,'IsRule') = 1
       and u.uid = o.uid
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPRULE
       @ObjNum int
 AS
declare  @seqid     smallint        /* sequence identifier            */
declare  @Ml        int             /* current output length          */
declare  @Sl        int             /* current text length            */
declare  @index     int             /* substring                      */
declare  @Stext     nvarchar(4000)  /* current text record            */
declare  @Ctext     char(255)       /* current package record         */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Implicit Transaction mode for life of this SP             *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Rule Text                          *
 *--------------------------------------------------------------------*/
     create table #rultxt(seqid  smallint primary key,
                          pkgtext char(255))

/*--------------------------------------------------------------------*
 *  Declare the cursor for extract of rule text                       *
 *--------------------------------------------------------------------*/
    declare txt_cursor cursor for
     select datalength(s.text), s.text
     from syscomments s
     where s.id = @ObjNum
     order by s.colid
     for read only

     set @seqid = 0
     open txt_cursor
     fetch txt_cursor into @Sl, @Stext

/*--------------------------------------------------------------------*
 *  Read all records in Text set                                      *
 *--------------------------------------------------------------------*/
     while (@@fetch_status = 0)
     begin
       set @index = 1
       set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 255 or less bytes each.             *
 *--------------------------------------------------------------------*/
       while(@Sl > 0)
       begin
         if (@Sl < 255) set @Ml = @Sl
         set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
         set @seqid = @seqid + 1
         insert into #rultxt values (@seqid,@Ctext)
         set @Sl = @Sl - @Ml
         set @index = @index + @Ml
       end
       fetch txt_cursor into @Sl, @Stext
     end
     close txt_cursor
     deallocate txt_cursor

     select seqid,pkgtext from #rultxt
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULELIST
       @Owner    sysname,
       @Name     sysname,
       @SelMode  tinyint
 AS
     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Execute the appropriate Select for the mode                       *
 *--------------------------------------------------------------------*/
    if @SelMode = 0
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sysusers u
       WHERE OBJECTPROPERTY(o.id,'IsRule') = 1
         and u.uid = o.uid
         and u.name = @Owner
         and o.name = @Name
       order by u.name, o.name
      end

    if @SelMode = 1
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sysusers u
       WHERE OBJECTPROPERTY(o.id,'IsRule') = 1
         and u.uid = o.uid
         and u.name like @Owner
         and o.name = @Name
       order by u.name, o.name
      end

    if @SelMode = 2
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sysusers u
       WHERE OBJECTPROPERTY(o.id,'IsRule') = 1
         and u.uid = o.uid
         and u.name = @Owner
         and o.name like @Name
       order by u.name, o.name
      end

    if @SelMode = 3
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sysusers u
       WHERE OBJECTPROPERTY(o.id,'IsRule') = 1
         and u.uid = o.uid
         and u.name like @Owner
         and o.name like @Name
       order by u.name, o.name
      end
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSFINDRULE to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULE to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSEXPRULE to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSGETRULELIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go
