set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGGER
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGTEXT
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGGER
       @ObjNum int
 AS
     select t.id,
            t.uid,
            t.status,
            isnull(ObjectProperty(t.id, 'ExecIsTriggerDisabled'), 0),
            isnull(ObjectProperty(t.id, 'ExecIsInsteadOfTrigger'), 0),
            (select sum(datalength(c.text))
               from syscomments c
              where c.id = t.id
                and c.texttype != 6),
            u.name,
            t.name
     from sysobjects t, sysusers u
      where t.parent_obj = @ObjNum
        and OBJECTPROPERTY(t.id,'IsTrigger') = 1
        and u.uid = t.uid
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGTEXT
       @ObjNum int
 AS
declare  @seqid     smallint        /* sequence identifier            */
declare  @index     int             /* index in text buffer           */
declare  @Ml        int             /* current output length          */
declare  @Sl        int             /* current text length            */
declare  @Stext     nvarchar(4000)  /* current text record            */
declare  @Ctext     varchar(255)    /* current package record         */

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Trigger Text                       *
 *--------------------------------------------------------------------*/
     create table #tritxt(seqid  smallint primary key,
                          pkgtext varchar(255))

/*--------------------------------------------------------------------*
 *  Declare the cursor for extract of Trigger Text                    *
 *--------------------------------------------------------------------*/
    declare txt_cursor cursor for
     select datalength(s.text), s.text
     from syscomments s
     where s.id = @ObjNum
       and s.texttype != 6
     order by s.colid
     for read only

/*--------------------------------------------------------------------*
 *  Extract 1st Trigger Text record                                   *
 *--------------------------------------------------------------------*/
     set @seqid = 0
     open txt_cursor
     fetch txt_cursor into @Sl, @Stext
/*--------------------------------------------------------------------*
 *  For each record in the set of Trigger Text                        *
 *--------------------------------------------------------------------*/
     while (@@fetch_status = 0)
     begin
       set @index = 1
       set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 256 or less bytes each.             *
 *--------------------------------------------------------------------*/
       while(@Sl > 0)
       begin
         if (@Sl < 255) set @Ml = @Sl
         set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
         set @seqid = @seqid + 1
         insert into #tritxt values (@seqid,@Ctext)
         set @Sl = @Sl - @Ml
         set @index = @index + @Ml
       end
       fetch txt_cursor into @Sl, @Stext
     end
     close txt_cursor
     deallocate txt_cursor

/*--------------------------------------------------------------------*
 *  Select the returned data                                          *
 *--------------------------------------------------------------------*/
      select seqid,pkgtext from #tritxt
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGGER to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM80V0100_CSSTRIGTEXT to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

