set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSCHECKHAMESPACE
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSCHECKHAMESPACE
       @CreatorName       sysname,
       @ObjectName        sysname,
       @QualifierName     sysname,
       @QualifierCreator  sysname,
       @ObjType           int
AS
BEGIN
   declare  @objectType    char(2)
   declare  @constraintId  int
   declare  @objId         int
   declare  @constrStatus  int
   declare  @trigId        int
   declare  @trigIns       int
   declare  @trigUpd       int
   declare  @trigDel       int
   set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

if((@ObjType = 1) or  /*table*/
   (@ObjType = 2) or  /*view*/
   (@ObjType = 4) or  /*rule*/
   (@ObjType = 5) or  /*default*/
   (@ObjType =14) or  /*synonym*/ 
   (@ObjType =15) or  /*function*/
   (@ObjType =16))    /*procedure*/
  begin
     select o.type, '?', '?'
       from sysobjects o, sys.schemas u
      where (o.uid = u.schema_id)
        and (u.name = @CreatorName)
        and (o.name = @ObjectName)
  end
else if(@ObjType =12) /*trigger*/
  begin
     select @objectType = o.type, @objId = o.parent_obj, @trigId = o.id
       from sysobjects o, sys.schemas u
      where (o.uid = u.schema_id)
        and (u.name = @QualifierCreator)
        and (o.name = @QualifierName)
     if((@@rowcount > 0) and (@objectType in('TR', 'TA')))
       begin
        select @trigIns = ObjectProperty(@trigId, 'ExecIsInsertTrigger')
        select @trigUpd = ObjectProperty(@trigId, 'ExecIsUpdateTrigger')
        select @trigDel = ObjectProperty(@trigId, 'ExecIsDeleteTrigger')
        select ('T' +
               case
                   when (@trigIns=0)and(@trigUpd=0)and(@trigDel=0) then '0'
                   when (@trigIns=0)and(@trigUpd=0)and(@trigDel=1) then '1'
                   when (@trigIns=0)and(@trigUpd=1)and(@trigDel=0) then '2'
                   when (@trigIns=0)and(@trigUpd=1)and(@trigDel=1) then '3'
                   when (@trigIns=1)and(@trigUpd=0)and(@trigDel=0) then '4'
                   when (@trigIns=1)and(@trigUpd=0)and(@trigDel=1) then '5'
                   when (@trigIns=1)and(@trigUpd=1)and(@trigDel=0) then '6'
                   when (@trigIns=1)and(@trigUpd=1)and(@trigDel=1) then '7'
               end),
               o.name, u.name
          from sysobjects o, sys.schemas u
         where (o.uid = u.schema_id)
           and (o.id = @objId)
       end
     else if(@@rowcount > 0)
        select @objectType, '?', '?'
     else
        select '?', '?', '?'
        where  0=1 /*empty set*/
  end
else if(
   (@ObjType = 7) or  /*check*/
   (@ObjType = 9) or  /*PrimKey*/
   (@ObjType =10) or  /*relKey*/
   (@ObjType =11))    /*unique*/
  begin
     select @objectType = o.type,
            @constraintId = isnull(c.constid,0),
            @constrStatus = (isnull(c.status,0) &2)
       from sys.schemas u, sysobjects o LEFT JOIN sysconstraints c
         on o.id = c.constid
      where (o.uid = u.schema_id)
        and (u.name = @CreatorName)
        and (o.name = @QualifierName)

     if(@@rowcount > 0)
         begin
             if(@constraintId <> 0)
               begin
                   if((@constrStatus = 2)and(@objectType = 'K'))
                     select @objectType = 'Q '
                   select @objectType, tob.name, tu.name
                     from sysconstraints c, sysobjects tob, sys.schemas tu
                    where (@constraintId = c.constid)
                      and (c.id = tob.id)
                      and (tob.uid = tu.schema_id)
               end
             else
               select @objectType, '?', '?'
         end
      else
         select '?', '?', '?'
         where 1=2 /* return empty set */
  end
else if(@ObjType = 8) /*index*/
  begin
     if substring(@QualifierName, 1, 1) = '<'
        begin
           select
             case
               when isnull(i.object_id,0)>0
               then 'I '
             end
             from sys.tables t
                   inner join sys.fulltext_indexes i
               on i.object_id = t.object_id
            where t.name = substring(@QualifierName, 2, len(@QualifierName)-2)
              and t.schema_id = schema_ID(@CreatorName)
        end
     else
        begin
           select 'I ', @ObjectName, @CreatorName
             from sys.indexes i, sys.objects o
            where i.object_id = o.object_id
              and o.schema_id = schema_ID(@CreatorName)
              and o.name = @ObjectName
              and i.name = @QualifierName
        end
  end
else if(@ObjType = 6)  /*datatype*/
  begin
    select 'Y ', '?', '?'
    from systypes
    where name = @ObjectName
      and uid = schema_ID(@CreatorName)
  end
else if(@ObjType = 29) /*assembly*/
  begin
    select '= ','?','?'
    from sys.assemblies
    where name = @ObjectName
  end
else if(@ObjType = 30) /*partition scheme*/
  begin
    select '= ','?','?'
    from sys.partition_schemes
    where name = @ObjectName
  end
else if(@ObjType = 31) /*partition function*/
  begin
    select '= ','?','?'
    from sys.partition_functions
    where name = @ObjectName
  end
else
  begin
    select '?', '?', '?'
  end

END
go


grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSCHECKHAMESPACE to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

