set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSFINDDFLT
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLT
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSEXPDFLT
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLTLIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSFINDDFLT
       @CidName   sysname,
       @ObjName   sysname
 AS
     select  o.id,
             o.uid,
             o.name,
             u.name
     from sysobjects o, sys.schemas u
     where o.name = @ObjName
       and OBJECTPROPERTY(o.id,'IsDefault') = 1
       and u.schema_id = o.uid
       and u.name = @CidName
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLT
       @ObjNum int
 AS
     select  o.uid,
             o.name,
             u.name
     from sysobjects o, sys.schemas u
     where o.id = @ObjNum
       and OBJECTPROPERTY(o.id,'IsDefault') = 1
       and u.schema_id = o.uid
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSEXPDFLT
       @ObjNum int
 AS
declare  @seqid     smallint        /* sequence identifier            */
declare  @Ml        int             /* current output length          */
declare  @Sl        int             /* input text length              */
declare  @index     int             /* substring                      */
declare  @Stext     nvarchar(max)   /* current text record            */
declare  @Ctext     char(255)       /* current package record         */

     set nocount on
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Default Text                       *
 *--------------------------------------------------------------------*/
     create table #dfttxt(seqid  smallint primary key,
                          pkgtext char(255))

/*--------------------------------------------------------------------*
 *  Declare the cursor for extract of default text                    *
 *--------------------------------------------------------------------*/
    declare txt_cursor cursor for
     select datalength(s.text), s.text
     from syscomments s
     where s.id = @ObjNum
     order by s.colid
     for read only

     set @seqid = 0
     open txt_cursor
     fetch txt_cursor into @Sl, @Stext

/*--------------------------------------------------------------------*
 *  Read all records in Text set                                      *
 *--------------------------------------------------------------------*/
     while (@@fetch_status = 0)
     begin
       set @index = 1
       set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 255 or less bytes each.             *
 *--------------------------------------------------------------------*/
       while(@Sl > 0)
       begin
         if (@Sl < 255) set @Ml = @Sl
         set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
         set @seqid = @seqid + 1
         insert into #dfttxt values (@seqid,@Ctext)
         set @Sl = @Sl - @Ml
         set @index = @index + @Ml
       end
       fetch txt_cursor into @Sl, @Stext
     end
     close txt_cursor
     deallocate txt_cursor
     select seqid,pkgtext from #dfttxt
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLTLIST
       @Owner    sysname,
       @Name     sysname,
       @SelMode  tinyint
 AS
     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Execute the appropriate Select for the mode                       *
 *--------------------------------------------------------------------*/
    if @SelMode = 0
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sys.schemas u
       WHERE OBJECTPROPERTY(o.id,'IsDefault') = 1
         and u.schema_id = o.uid
         and u.name = @Owner
         and o.name = @Name
       order by u.name, o.name
      end

    if @SelMode = 1
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sys.schemas u
       WHERE OBJECTPROPERTY(o.id,'IsDefault') = 1
         and u.schema_id = o.uid
         and u.name like @Owner
         and o.name = @Name
       order by u.name, o.name
      end

    if @SelMode = 2
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sys.schemas u
       WHERE OBJECTPROPERTY(o.id,'IsDefault') = 1
         and u.schema_id = o.uid
         and u.name = @Owner
         and o.name like @Name
       order by u.name, o.name
      end

    if @SelMode = 3
      begin
      SELECT u.name,
             o.name
        FROM sysobjects o, sys.schemas u
       WHERE OBJECTPROPERTY(o.id,'IsDefault') = 1
         and u.schema_id = o.uid
         and u.name like @Owner
         and o.name like @Name
       order by u.name, o.name
      end
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSFINDDFLT to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLT to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSEXPDFLT to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSGETDFLTLIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

