set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLINK
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETCONDETAIL
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLINK
       @CidUid    smallint,
       @CidName   sysname
 AS
DECLARE @CidNum   smallint

     set nocount on
     set @CidNum = @CidUid

     if (@CidUid = -1)
       set @CidNum = schema_id(@CidName)

     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name,
            rd.uid,
            rp.uid,
            r.constid,
            case
              when (f.is_not_for_replication <> 0)
                then 'Y'
                else 'N'
              end,
            case
              when (f.is_disabled <> 0)
                then 'N'
                else 'Y'
              end,
            f.delete_referential_action,
            f.update_referential_action
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r,
            sys.foreign_keys f
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        and f.object_id = o.id
        and f.schema_id = o.uid
        AND (rd.uid = @CidNum or rp.uid = @CidNum)
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETCONDETAIL
       @ConId     int
 AS
 set nocount on
 SELECT r.keycnt,
        r.fkey1,r.fkey2,r.fkey3,r.fkey4,
        r.fkey5,r.fkey6,r.fkey7,r.fkey8,
        r.fkey9,r.fkey10,r.fkey11,r.fkey12,
        r.fkey13,r.fkey14,r.fkey15,r.fkey16,
        r.rkey1,r.rkey2,r.rkey3,r.rkey4,
        r.rkey5,r.rkey6,r.rkey7,r.rkey8,
        r.rkey9,r.rkey10,r.rkey11,r.rkey12,
        r.rkey13,r.rkey14,r.rkey15,r.rkey16
   FROM sysreferences r
   WHERE r.constid = @ConId
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLIST
       @CidPattern sysname,
       @TblPattern sysname,
       @RelPattern sysname
 AS
declare  @mode      smallint        /* Query Mode in effect           */

 set nocount on
/*--------------------------------------------------------------------*
 *  Compute the Query select to use for this scan bas-ed on            *
 *  whether the input patterns have LIKE wildcards.                   *
 *  Mode values are:                                                  *
 *       0 - All input patterns are explicit                          *
 *       1 - Generic Creator name                                     *
 *       2 - Generic Table name                                       *
 *       3 - Generic Creator and Table names                          *
 *       4 - Generic Relationship name                                *
 *       5 - Generic Creator and Relationship names                   *
 *       6 - Generic Table and Relationship names                     *
 *       7 - All input patterns are generic                           *
 *--------------------------------------------------------------------*/
     set @mode = 0               /* Assume Explicit names          */

/*--------------------------------------------------------------------*
 *  Check Creator Name for LIKE wildcard characters                   *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@CidPattern) > 0) or
         (charindex('_',@CidPattern) > 0))
       set @mode = 1

/*--------------------------------------------------------------------*
 *  Check Table Name for LIKE wildcard characters                     *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@TblPattern) > 0) or
         (charindex('_',@TblPattern) > 0))
       set @mode = @mode + 2

/*--------------------------------------------------------------------*
 *  Check RelName Name for LIKE wildcard characters                   *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@RelPattern) > 0) or
         (charindex('_',@RelPattern) > 0))
       set @mode = @mode + 4

/*--------------------------------------------------------------------*
 *  Execute the proper select statement bas-ed on Query Mode           *
 *--------------------------------------------------------------------*/
    if @mode = 0
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name = @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) = @CidPattern
        AND rd.name = @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 1
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name = @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) like @CidPattern
        AND rd.name = @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 2
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name = @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) = @CidPattern
        AND rd.name like @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 3
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name like @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) = @CidPattern
        AND rd.name like @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 4
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name like @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) = @CidPattern
        AND rd.name = @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 5
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name like @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) like @CidPattern
        AND rd.name = @TblPattern
      ORDER BY o.uid, rd.name,o.name

    if @mode = 6
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name like @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) = @CidPattern
        AND rd.name like @TblPattern ESCAPE ''!''
      ORDER BY o.uid, rd.name,o.name

    if @mode = 7
     SELECT schema_name(rd.uid),
            rd.name,
            o.name,
            schema_name(rp.uid),
            rp.name
       FROM sysobjects o,
            sysobjects rd,
            sysobjects rp,
            sysreferences r
      WHERE OBJECTPROPERTY(o.id,'IsForeignKey') = 1
        AND o.name like @RelPattern
        AND r.constid = o.id
        and rd.id = r.fkeyid
        and rp.id = r.rkeyid
        AND schema_name(rd.uid) like @CidPattern
        AND rd.name like @TblPattern
      ORDER BY o.uid, rd.name,o.name
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLINK to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSGETCONDETAIL to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM90V0100_CSSGETRELLIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

