set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGGER
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGTEXT
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGOPTS
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGGER
       @ObjNum int
 AS
declare  @dbname   sysname
DECLARE  @sql      nvarchar(4000)

set @dbname = ORIGINAL_DB_NAME()

SET @sql = N'
     select t.object_id,
            t.schema_id,
            isnull(ObjectProperty(t.object_id, ''ExecIsTriggerDisabled''), 0),
            isnull(ObjectProperty(t.object_id, ''ExecIsInsteadOfTrigger''), 0),
            isnull(ObjectProperty(t.object_id, ''ExecIsInsertTrigger''), 0),
            isnull(ObjectProperty(t.object_id, ''ExecIsUpdateTrigger''), 0),
            isnull(ObjectProperty(t.object_id, ''ExecIsDeleteTrigger''), 0),
            (select datalength(c.definition)
               from ['+ @dbname+'].sys.sql_modules c
              where c.object_id = t.object_id),
            u.name,
            t.name
     from ['+ @dbname+'].sys.all_objects t, ['+ @dbname+'].sys.schemas u
      where t.parent_object_id = '+CAST(@ObjNum AS NVARCHAR(10))+'
        and OBJECTPROPERTY(t.object_id,''IsTrigger'') = 1
        and u.schema_id = t.schema_id'
EXEC sp_executesql @sql
go


CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGTEXT
       @ObjNum int
 AS
declare  @seqid     smallint        /* sequence identifier            */
declare  @index     int             /* index in text buffer           */
declare  @Ml        int             /* current output length          */
declare  @Sl        int             /* current text length            */
declare  @Stext     nvarchar(4000)  /* current text record            */
declare  @Ctext     varchar(255)    /* current package record         */
declare  @dbname    sysname
DECLARE  @sql       nvarchar(4000)
declare  @txt_cursor CURSOR

set @dbname = ORIGINAL_DB_NAME()

     set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Trigger Text                       *
 *--------------------------------------------------------------------*/
     create table #tritxt(seqid  smallint primary key,
                          pkgtext varchar(255))

/*--------------------------------------------------------------------*
 *  Declare the cursor for extract of Trigger Text                    *
 *--------------------------------------------------------------------*/
 SET @sql = N'
    set @txt_cursor = cursor for
     select datalength(s.definition), s.definition
     from ['+ @dbname+'].sys.sql_modules s
     where s.object_id = '+CAST(@ObjNum AS nvarchar(10))+'
     for read only;
     OPEN @txt_cursor'
 EXEC sp_executesql @sql,N'@txt_cursor cursor output', @txt_cursor output


/*--------------------------------------------------------------------*
 *  Extract 1st Trigger Text record                                   *
 *--------------------------------------------------------------------*/
     set @seqid = 0
     fetch @txt_cursor into @Sl, @Stext
/*--------------------------------------------------------------------*
 *  For each record in the set of Trigger Text                        *
 *--------------------------------------------------------------------*/
     while (@@fetch_status = 0)
     begin
       set @index = 1
       set @Ml = 255
/*--------------------------------------------------------------------*
 *  Build output text packages of 256 or less bytes each.             *
 *--------------------------------------------------------------------*/
       while(@Sl > 0)
       begin
         if (@Sl < 255) set @Ml = @Sl
         set @Ctext = substring(@Stext,@index,@Ml)
/*--------------------------------------------------------------------*
 *  Write the output record                                           *
 *--------------------------------------------------------------------*/
         set @seqid = @seqid + 1
         insert into #tritxt values (@seqid,@Ctext)
         set @Sl = @Sl - @Ml
         set @index = @index + @Ml
       end
       fetch @txt_cursor into @Sl, @Stext
     end
     close @txt_cursor
     deallocate @txt_cursor

/*--------------------------------------------------------------------*
 *  Select the returned data                                          *
 *--------------------------------------------------------------------*/
      select seqid,pkgtext from #tritxt
go

/*--------------------------------------------------------------------*
 *  Return CLR Trigger options                                        *
 *--------------------------------------------------------------------*/
CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGOPTS
   @ObjNum  int
 AS
declare  @dbname   sysname
DECLARE  @sql      nvarchar(4000)

set @dbname = ORIGINAL_DB_NAME()

     set nocount on
SET @sql = N'
     select schema_name(p.schema_id), p.name,
            a.name, m.assembly_class, m.assembly_method,
            case isnull(m.execute_as_principal_id,0)
                 when  0 then NULL
                 when -2 then NULL
                 else u.name
             end,
            isnull(ObjectPropertyEx('+CAST(@ObjNum AS nvarchar(10))+', ''ExecIsTriggerNotForRepl''), 0)
     from ['+ @dbname+'].sys.all_objects o, ['+ @dbname+'].sys.all_objects p, ['+ @dbname+'].sys.triggers t,
          ['+ @dbname+'].sys.assemblies a, ['+ @dbname+'].sys.assembly_modules m
          left join ['+ @dbname+'].sys.schemas u
       on m.execute_as_principal_id = u.schema_id
    where m.object_id = '+CAST(@ObjNum AS nvarchar(10))+'
      and a.assembly_id = m.assembly_id
      and o.object_id = m.object_id

      and o.object_id = t.object_id

      and p.object_id = t.parent_id'
EXEC sp_executesql @sql
go


grant execute on ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGGER to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGTEXT to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM16V0100_CSSTRIGOPTS to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

