set quoted_identifier off
go

set implicit_transactions off
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNONYM
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNOBJECT
go

DROP PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSGETSYNLIST
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNONYM
       @SynCid  sysname,
       @SynName sysname
 AS
declare  @dbname   sysname
DECLARE  @sql      nvarchar(4000)

set      @dbname = ORIGINAL_DB_NAME()

     set nocount on
SET @sql = N'
     SELECT u.schema_id,
            s.object_id,
            parsename(s.base_object_name, 1),
            isnull(parsename(s.base_object_name, 2),''''),
            isnull(parsename(s.base_object_name, 3),''''),
            isnull(parsename(s.base_object_name, 4),''''),
            @@SERVERNAME,
            DB_NAME()
       FROM ['+ @dbname+'].sys.synonyms s, ['+ @dbname+'].sys.schemas u
      WHERE u.name = @ParSynCid 
        AND s.name = @ParSynName 
        AND s.schema_id = u.schema_id'
EXEC sp_executesql @sql, N'@ParSynCid sysname, @ParSynName sysname', 
						 @ParSynCid = @SynCid, @ParSynName = @SynName
go


CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNOBJECT
       @CidName   sysname,
       @ObjName   sysname
 AS
declare  @dbname   sysname
DECLARE  @sql      nvarchar(4000)

set      @dbname = ORIGINAL_DB_NAME()

 set nocount on
 SET @sql = N'
 SELECT o.object_id,
        o.type
   FROM ['+ @dbname+'].sys.schemas u, ['+ @dbname+'].sys.all_objects o
   WHERE u.name = @ParCidName 
     AND o.schema_id = u.schema_id
     AND o.name = @ParObjName '
EXEC sp_executesql @sql, N'@ParCidName sysname, @ParObjName sysname', 
						 @ParCidName = @CidName, @ParObjName = @ObjName
go

CREATE PROCEDURE ~ALTSPQUALIFIER..PSTM17V0100_CSSGETSYNLIST
       @CidPattern sysname,
       @SynPattern sysname
 AS
declare  @scid_name sysname         /* Creator Name                   */
declare  @syn_name  sysname         /* Synonym Name                   */
declare  @ocid_name sysname         /* Creator Name                   */
declare  @obj_name  sysname         /* Object  Name                   */
declare  @obj_num   int             /* Object  Number                 */
declare  @mode      smallint        /* Query Mode in effect           */
declare  @dbname   sysname
DECLARE  @sql      nvarchar(4000)
declare  @slst0    CURSOR
declare  @slst1    CURSOR
declare  @slst2    CURSOR
declare  @slst3    CURSOR

set      @dbname = ORIGINAL_DB_NAME()

   set nocount on
/*--------------------------------------------------------------------*
 *  Suspend Chained Transaction Mode for duration of this SP          *
 *--------------------------------------------------------------------*/
     if @@trancount = 0
     begin
       set implicit_transactions off
       set transaction isolation level READ COMMITTED
     end

/*--------------------------------------------------------------------*
 *  Temporary Table used to return Primary Key List                   *
 *--------------------------------------------------------------------*/
     create table #synlist(SCidName sysname,
                           SynName  sysname,
                           OCidName sysname,
                           ObjName  sysname,
                           ObjNum   int)

/*--------------------------------------------------------------------*
 *  Compute the Query select to use for this scan                     *
 *  bas-ed on whether the input patterns have LIKE wildcards.          *
 *  Mode values are:                                                  *
 *       0 - Explicit Creator name and Explicit Synonym name          *
 *       1 - Generic Creator name and Explicit Synonym name           *
 *       2 - Explicit Creator name and Generic Synonym name           *
 *       3 - Generic Creator name and Generic Synonym name            *
 *--------------------------------------------------------------------*/
     set @mode = 0               /* Assume Explicit CID/SYN names  */

/*--------------------------------------------------------------------*
 *  Check Creator Name for LIKE wildcard characters                   *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@CidPattern) > 0) or
         (charindex('_',@CidPattern) > 0))
       set @mode = 1

/*--------------------------------------------------------------------*
 *  Check Synonym Name for LIKE wildcard characters                   *
 *--------------------------------------------------------------------*/
     if ((charindex('%',@SynPattern) > 0) or
         (charindex('_',@SynPattern) > 0))
       set @mode = @mode + 2

/*--------------------------------------------------------------------*
 *  Open the appropriate cursor and fetch 1st record                  *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
SET @sql = N'
SET @slst0 = CURSOR FOR
     SELECT u.name,
            s.name,
            isnull(parsename(s.base_object_name, 2),u.name),
            parsename(s.base_object_name, 1),
            CASE
               WHEN isnull(parsename(s.base_object_name, 3),DB_NAME()) = DB_NAME()
                AND isnull(parsename(s.base_object_name, 4),'+@@SERVERNAME+') = '+@@SERVERNAME+'
               THEN isnull(OBJECT_ID(s.base_object_name),0)
               ELSE 1
            END
       FROM ['+ @dbname+'].sys.synonyms s, ['+ @dbname+'].sys.schemas u
      WHERE u.name = @ParCidPattern 
        AND s.name = @ParSynPattern 
        AND s.schema_id = u.schema_id
      FOR READ ONLY;
      OPEN @slst0'
EXEC sp_executesql @sql,N'@slst0 cursor output, @ParCidPattern sysname, @ParSynPattern sysname', 
		@slst0 output, @ParCidPattern = @CidPattern, @ParSynPattern = @SynPattern
        FETCH @slst0 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num
      end

    if @mode = 1
      begin
SET @sql = N'
SET @slst1 = CURSOR FOR
     SELECT u.name,
            s.name,
            isnull(parsename(s.base_object_name, 2),u.name),
            parsename(s.base_object_name, 1),
            CASE
               WHEN isnull(parsename(s.base_object_name, 3),DB_NAME()) = DB_NAME()
                AND isnull(parsename(s.base_object_name, 4),'+@@SERVERNAME+') = '+@@SERVERNAME+'
               THEN isnull(OBJECT_ID(s.base_object_name),0)
               ELSE 1
            END
       FROM ['+ @dbname+'].sys.synonyms s, ['+ @dbname+'].sys.schemas u
      WHERE u.name LIKE @ParCidPattern 
        AND s.name = @ParSynPattern 
        AND s.schema_id = u.schema_id
      FOR READ ONLY;
      OPEN @slst1'
EXEC sp_executesql @sql,N'@slst1 cursor output, @ParCidPattern sysname, @ParSynPattern sysname', 
		@slst1 output, @ParCidPattern = @CidPattern, @ParSynPattern = @SynPattern
        FETCH @slst1 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num
      end

    if @mode = 2
      begin
SET @sql = N'
SET @slst2 = CURSOR FOR
     SELECT u.name,
            s.name,
            isnull(parsename(s.base_object_name, 2),u.name),
            parsename(s.base_object_name, 1),
            CASE
               WHEN isnull(parsename(s.base_object_name, 3),DB_NAME()) = DB_NAME()
                AND isnull(parsename(s.base_object_name, 4),'+@@SERVERNAME+') = '+@@SERVERNAME+'
               THEN isnull(OBJECT_ID(s.base_object_name),0)
               ELSE 1
            END
       FROM ['+ @dbname+'].sys.synonyms s, ['+ @dbname+'].sys.schemas u
      WHERE u.name = @ParCidPattern 
        AND s.name LIKE @ParSynPattern 
        AND s.schema_id = u.schema_id
      FOR READ ONLY;
      OPEN @slst2'
EXEC sp_executesql @sql,N'@slst2 cursor output, @ParCidPattern sysname, @ParSynPattern sysname', 
		@slst2 output, @ParCidPattern = @CidPattern, @ParSynPattern = @SynPattern
        FETCH @slst2 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num
      end

    if @mode = 3
      begin
SET @sql = N'
SET @slst3 = CURSOR FOR
     SELECT u.name,
            s.name,
            isnull(parsename(s.base_object_name, 2),u.name),
            parsename(s.base_object_name, 1),
            CASE
               WHEN isnull(parsename(s.base_object_name, 3),DB_NAME()) = DB_NAME()
                AND isnull(parsename(s.base_object_name, 4),'+@@SERVERNAME+') = '+@@SERVERNAME+'
               THEN isnull(OBJECT_ID(s.base_object_name),0)
               ELSE 1
            END
       FROM ['+ @dbname+'].sys.synonyms s, ['+ @dbname+'].sys.schemas u
      WHERE u.name LIKE @ParCidPattern 
        AND s.name LIKE @ParSynPattern 
        AND s.schema_id = u.schema_id
      FOR READ ONLY;
      OPEN @slst3'
EXEC sp_executesql @sql,N'@slst3 cursor output, @ParCidPattern sysname, @ParSynPattern sysname', 
		@slst3 output, @ParCidPattern = @CidPattern, @ParSynPattern = @SynPattern
        FETCH @slst3 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num
      end

/*--------------------------------------------------------------------*
 *  Process the set of tables returned by the Query                   *
 *--------------------------------------------------------------------*/
    while (@@fetch_status = 0)
     begin
       insert into #synlist values
              (@scid_name, @syn_name, @ocid_name, @obj_name, @obj_num)

/*--------------------------------------------------------------------*
 *  Retrieve next record in result set                                *
 *--------------------------------------------------------------------*/
    if @mode = 0
        FETCH @slst0 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num

    if @mode = 1
        FETCH @slst1 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num

    if @mode = 2
        FETCH @slst2 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num

    if @mode = 3
        FETCH @slst3 INTO @scid_name, @syn_name, @ocid_name, @obj_name, @obj_num

     end                               /* Loop thru result set        */

/*--------------------------------------------------------------------*
 *  Close the Query cursor                                            *
 *--------------------------------------------------------------------*/
    if @mode = 0
      begin
        CLOSE @slst0
        deallocate @slst0
      end

    if @mode = 1
      begin
        CLOSE @slst1
        deallocate @slst1
      end

    if @mode = 2
      begin
        CLOSE @slst2
        deallocate @slst2
      end

    if @mode = 3
      begin
        CLOSE @slst3
        deallocate @slst3
      end

/*--------------------------------------------------------------------*
 *  Select the returned data, if any                                  *
 *--------------------------------------------------------------------*/
     select SCidName, SynName, OCidName, ObjName, ObjNum
        from #synlist
        order by SCidName, SynName
go


grant execute on ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNONYM to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM17V0100_CSSFINDSYNOBJECT to ~ALTGRANTAUTHID
go

grant execute on ~ALTSPQUALIFIER..PSTM17V0100_CSSGETSYNLIST to ~ALTGRANTAUTHID
go

set implicit_transactions on
go

set quoted_identifier on
go

