/*--------------------------------------------------------------------*
 *  Oracle8 package used by Catalog Services to access Column         *
 *  data from the Data Dictionary                                     *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO8IV0106_CSSCOLUMN AS

/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in               *
 *  this package                                                      *
 *--------------------------------------------------------------------*/
   TYPE t_datatype   IS TABLE OF CHAR(9)
         INDEX BY BINARY_INTEGER;
   TYPE t_nullmode IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_columnlength IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_columnnumber IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_segcolnumber IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_defaultvaluelength IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_numericprecision IS TABLE OF SMALLINT
         INDEX BY BINARY_INTEGER;
   TYPE t_numericscale IS TABLE OF SMALLINT
         INDEX BY BINARY_INTEGER;
   TYPE t_columnname IS TABLE OF SYS.COL$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_conname IS TABLE OF SYS.CON$.NAME%TYPE
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Column data from COL$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0101_CSSGETCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColLen               OUT t_columnlength,
    ColNum               OUT t_columnnumber,
    DefValLen            OUT t_defaultvaluelength,
    NumPrec              OUT t_numericprecision,
    NumScale             OUT t_numericscale,
    NullMode             OUT t_nullmode,
    DataType             OUT t_datatype,
    ColName              OUT t_columnname,
    CharLen              OUT t_columnlength);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column default data from COL$           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0101_CSSEXPCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER,
    DefValue             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Cluster Col Ids from COL$, etc..        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSCLSCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ClusterNumIn          IN INTEGER,
    ColNum               OUT t_columnnumber,
    SegCol               OUT t_segcolnumber);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column NOT Null constraint name         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSNNMCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColNum               OUT t_columnnumber,
    ConName              OUT t_conname);

 END PSTO8IV0106_CSSCOLUMN;
/

grant execute on ~ALTSPQUALIFIER..PSTO8IV0106_CSSCOLUMN to ~ALTGRANTAUTHID
/

