/*--------------------------------------------------------------------*
 *  Oracle8 package used by Catalog Services to access Relationship   *
 *  data from the Data Dictionary                                     *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO8IV0103_CSSRELCON AS

/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in               *
 *  this package                                                      *
 *--------------------------------------------------------------------*/
   TYPE t_depcid     IS TABLE OF SYS.USER$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_deptbl      IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_relname       IS TABLE OF SYS.CON$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_parcid     IS TABLE OF SYS.USER$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_partbl      IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_depcidid      IS TABLE OF SYS.OBJ$.OWNER#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_parcidid      IS TABLE OF SYS.OBJ$.OWNER#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_depconid      IS TABLE OF SYS.CDEF$.CON#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_parconid      IS TABLE OF SYS.CDEF$.RCON#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_enableid      IS TABLE OF SYS.CDEF$.ENABLED%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_deferflag     IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_deleterule    IS TABLE OF SYS.CDEF$.REFACT%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_conid         IS TABLE OF SYS.CCOL$.CON#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_colid         IS TABLE OF SYS.CCOL$.COL#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_colpos        IS TABLE OF SYS.CCOL$.POS#%TYPE
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire RelLinks for a Creator Id.              *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLINK
   (RowsToGet             IN INTEGER,
    CreatorNumIn          IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl,
    DepCidId             OUT t_depcidid,
    ParCidId             OUT t_parcidid,
    DepConId             OUT t_depconid,
    ParConId             OUT t_parconid,
    EnableId             OUT t_enableid,
    Deferable            OUT t_deferflag,
    DeferInit            OUT t_deferflag,
    Validated            OUT t_deferflag,
    DeleteRule           OUT t_deleterule);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Constraint details from CCOL$           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCONDETAIL
   (RowsToGet             IN INTEGER,
    ParConId              IN INTEGER,
    DepConId              IN INTEGER,
    ConId                OUT t_conid,
    ColId                OUT t_colid,
    ColPos               OUT t_colpos);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when all names are explicit values                       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when Creator is a LIKE value and others explicit         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when Table is a LIKE value and others explicit           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST2
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when Creator and Table values are LIKE values            *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST3
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when RelName is a LIKE value                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST4
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when Creator and RelName are LIKE values                 *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST5
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when Table and RelName are LIKE values                   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST6
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table/RelName   *
 *  patterns when all names are LIKE values                           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST7
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl);

 END PSTO8IV0103_CSSRELCON;
/

grant execute on ~ALTSPQUALIFIER..PSTO8IV0103_CSSRELCON to ~ALTGRANTAUTHID
/

