/*--------------------------------------------------------------------*
 *  Oracle8 package body for Catalog Services Space Management        *
 *  procedures.                                                       *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO8IV0103_CSSSPCMGT AS

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Tablespace name list                       *
 *--------------------------------------------------------------------*/
 CURSOR slst0 IS
 SELECT TS.NAME
       FROM SYS.TS$ TS
       where TS.ONLINE$ = 1
       ORDER BY TS.NAME;


/*--------------------------------------------------------------------*
 *  Procedure used to acquire Tablespace information from TS$         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLSPC
   (RowsToGet             IN INTEGER,
    SpcNameIn             IN VARCHAR2,
    SpcObjId             OUT INTEGER) is

 BEGIN

/*--------------------------------------------------------------------*
 *  Retrieve the data for the input Tablespace name                   *
 *--------------------------------------------------------------------*/
     select TS.TS#
       into SpcObjId
       from SYS.TS$ TS
      where TS.NAME = SpcNameIn;

 END PSTV0100_CSSGETTBLSPC;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Tablespace list                         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSPCLIST
   (RowsToGet             IN INTEGER,
    SpcName              OUT t_spcnametype) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT slst0%ISOPEN THEN
        OPEN slst0;
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH slst0 INTO SpcName(i);
        IF slst0%NOTFOUND THEN
           CLOSE slst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSPCLIST;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Database Signature Token                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSIGNATURE
   (RowsToGet             IN INTEGER,
    SignToken            OUT VARCHAR2) is

 LocalName     VARCHAR2(30);
 LocalTime     VARCHAR2(20);

 BEGIN

/*--------------------------------------------------------------------*
 *  Retrieve the data for the token                                   *
 *--------------------------------------------------------------------*/
     select NAME,TO_CHAR(CREATED,'MM-DD-YYYY-HH24:MI:SS')
       into LocalName, LocalTime
       from V$DATABASE;

     SignToken := LocalName || LocalTime;

 END PSTV0100_CSSGETSIGNATURE;
END PSTO8IV0103_CSSSPCMGT;
