/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Creator Names          *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO92V0100_CSSCID AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Creator Name List when Creator is Explicit *
 *--------------------------------------------------------------------*/
 CURSOR clst0 (CidPatternIn VARCHAR2) IS
 SELECT DISTINCT U.NAME, U.USER#
            FROM SYS.USER$ U, SYS.OBJ$ O
           WHERE O.TYPE# IN(2,4)
             AND O.OID$ IS NULL
             AND U.USER# = O.OWNER#
             AND U.NAME = CidPatternIn
           ORDER BY U.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Creator Name List when Creator is Generic  *
 *--------------------------------------------------------------------*/
 CURSOR clst1 (CidPatternIn VARCHAR2) IS
 SELECT DISTINCT U.NAME, U.USER#
            FROM SYS.USER$ U, SYS.OBJ$ O
           WHERE O.TYPE# IN(2,4)
             AND O.OID$ IS NULL
             AND U.USER# = O.OWNER#
             AND U.NAME LIKE CidPatternIn
           ORDER BY U.NAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Creator Name List for explicit names    *
 *  are explicit references.                                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCIDLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    CreatorNum           OUT t_creatornum) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT clst0%ISOPEN THEN
        OPEN clst0(CidPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH clst0 INTO CreatorName(i),CreatorNum(i);
        IF clst0%NOTFOUND THEN
           CLOSE clst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCIDLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Creator Name List when name is a        *
 *  generic LIKE pattern.                                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCIDLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    CreatorNum           OUT t_creatornum) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT clst1%ISOPEN THEN
        OPEN clst1(CidPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH clst1 INTO CreatorName(i),CreatorNum(i);
        IF clst1%NOTFOUND THEN
           CLOSE clst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCIDLIST1;
END PSTO92V0100_CSSCID;
