/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Check constraints      *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO92V0101_CSSCHECK AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire basic check attributes                     *
 *--------------------------------------------------------------------*/
 CURSOR krec (ObjectNumIn INTEGER) IS
 SELECT CO.NAME,
        CD.CON#,
        CD.COLS,
        NVL(CD.ENABLED,0),
        CD.CONDLENGTH,
        decode(bitand(CD.DEFER,1),1,'Y','N'),
        decode(bitand(CD.DEFER,2),2,'D','I'),
        decode(bitand(CD.DEFER,4),4,'Y','N')
       FROM SYS.CON$ CO, SYS.CDEF$ CD
       WHERE CD.OBJ# = ObjectNumIn
         AND CD.TYPE# = 1
         AND CD.CON# = CO.CON#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Supplemental Logging constraints           *
 *--------------------------------------------------------------------*/
 CURSOR lrec (ObjectNumIn INTEGER) IS
 SELECT CO.NAME,
        CO.CON#,
        CC.COL#,
        DECODE(BITAND(CD.DEFER,64),64,'Y','N')
       FROM SYS.CON$ CO, SYS.CDEF$ CD, SYS.CCOL$ CC
       WHERE CD.OBJ# = ObjectNumIn
         AND CD.TYPE# = 12
         AND CD.CON# = CO.CON#
         AND CC.CON# = CD.CON#
UNION ALL
 SELECT CO.NAME,
        CO.CON#,
        COUNT(*),
        'A'
       FROM SYS.CON$ CO, SYS.CDEF$ CD, SYS.CCOL$ CC
       WHERE CD.OBJ# = ObjectNumIn
         AND CD.TYPE# = 12
         AND CD.CON# = CO.CON#
         AND CC.CON# = CD.CON#
       GROUP BY CO.NAME,CO.CON#
       ORDER BY 1,4;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Check data from CON$,CDEF$,CCOL$  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCHECK
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ConName              OUT t_cnm,
    ConId                OUT t_int,
    ColId                OUT t_int,
    Enabled              OUT t_int,
    TextLen              OUT t_int,
    Deferable            OUT t_chr,
    DeferInit            OUT t_chr,
    Validated            OUT t_chr) is

   LocalColCount INTEGER;
   LocalConId    INTEGER;

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT krec%ISOPEN THEN
        OPEN krec(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH krec INTO ConName(i),
                        LocalConId,
                        LocalColCount,
                        Enabled(i),
                        TextLen(i),
                        Deferable(i),
                        DeferInit(i),
                        Validated(i);
        IF krec%NOTFOUND THEN
           CLOSE krec;
           EXIT;
        END IF;
        IF LocalColCount = 1 THEN
          SELECT CC.COL#
            INTO LocalColCount
            FROM SYS.CCOL$ CC
          WHERE CC.CON# = LocalConId
          and rownum <= 1;
        ELSE
           LocalColCount := 0;
        END IF;
        ConId(i) := LocalConId;
        ColId(i) := LocalColCount;
     END LOOP;
 END PSTV0100_CSSGETCHECK;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Check Text from CDEF$                   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSEXPCHECK
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER, /* not used */
    CheckText            OUT VARCHAR2) is

  csr INTEGER;
  rc  NUMBER;
  len INTEGER;
  cnk INTEGER := 4000;
 BEGIN
/*--------------------------------------------------------------------*
 *  Retrieve the Check text for the Constraint Id provided            *
 *--------------------------------------------------------------------*/
   csr := DBMS_SQL.OPEN_CURSOR;
   DBMS_SQL.PARSE(csr, 'SELECT CONDITION FROM SYS.CDEF$ WHERE CON# = ' ||
                                       ObjectNumIn, DBMS_SQL.NATIVE);
   DBMS_SQL.DEFINE_COLUMN_LONG(csr, 1);
   rc := DBMS_SQL.EXECUTE_AND_FETCH(csr);
   DBMS_SQL.COLUMN_VALUE_LONG(csr, 1, cnk, OffsetNumIn, CheckText, len);
   DBMS_SQL.CLOSE_CURSOR(csr);
 END PSTV0100_CSSEXPCHECK;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Supplemntal Log Groups                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSUPPL
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ConName              OUT t_cnm,
    ConId                OUT t_int,
    ColId                OUT t_int,
    DeferInit            OUT t_chr) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT lrec%ISOPEN THEN
        OPEN lrec(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH lrec INTO ConName(i),
                        ConId(i),
                        ColId(i),
                        DeferInit(i);
        IF lrec%NOTFOUND THEN
           CLOSE lrec;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSUPPL;
END PSTO92V0101_CSSCHECK;
