/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Table/View             *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO92V0101_CSSTABLE AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Partitioned Table Key Columns              *
 *--------------------------------------------------------------------*/
 CURSOR pkey (ObjectNumIn INTEGER) IS
 SELECT PC.COL#,
        PC.POS#
        FROM SYS.PARTCOL$ PC
        WHERE PC.OBJ# = ObjectNumIn;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire SubPartitioned Table Key Columns           *
 *--------------------------------------------------------------------*/
 CURSOR spkey (ObjectNumIn INTEGER) IS
 SELECT PC.COL#,
        PC.POS#
        FROM SYS.SUBPARTCOL$ PC
        WHERE PC.OBJ# = ObjectNumIn;

/*--------------------------------------------------------------------*
 * Cursor used to acquire non-COMPOSITE Partitioned Table Slot records*
 *--------------------------------------------------------------------*/
 CURSOR skey (ObjectNumIn INTEGER) IS
 SELECT TP.OBJ#,
        TP.PART#,
        TP.PCTFREE$,
        TP.PCTUSED$,
        TP.INITRANS,
        TP.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        S.GROUPS,
        NVL(TS.BLOCKSIZE,0),
        TP.HIBOUNDLEN,
        decode(mod(trunc(tp.flags / 4), 2), 0, 'Y', 'N'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(s.spare1,2048),2048, 'Y', 'N'),
        T.SUBNAME,
        TS.NAME,
        TP.HIBOUNDVAL
        FROM SYS.OBJ$ T, SYS.TABPART$ TP, SYS.TS$ TS, SYS.SEG$ S
        WHERE TP.BO# = ObjectNumIn
         AND  TP.OBJ# = T.OBJ#
         AND  TP.TS# = TS.TS#
         AND  TP.FILE# = S.FILE#
         AND  TP.BLOCK# = S.BLOCK#
         AND  TP.TS#    = S.TS#
         ORDER BY TP.PART#;

/*--------------------------------------------------------------------*
 * Cursor used to acquire COMPOSITE Partitioned Table Slot records*
 *--------------------------------------------------------------------*/
 CURSOR ckey (ObjectNumIn INTEGER) IS
  SELECT TC.OBJ#,
        TC.PART#,
        TC.DEFPCTFREE,
        TC.DEFPCTUSED,
        TC.DEFINITRANS,
        TC.DEFMAXTRANS,
        NVL(TC.DEFINIEXTS,0),
        NVL(TC.DEFEXTSIZE,0),
        TC.DEFMINEXTS,
        TC.DEFMAXEXTS,
        TC.DEFEXTPCT,
        TC.DEFLISTS,
        TC.DEFGROUPS,
        NVL(TS.BLOCKSIZE,0),
        TC.HIBOUNDLEN,
        decode(mod(trunc(tc.flags / 4), 2), 0, 'Y', 'N'),
        decode(TC.DEFBUFPOOL, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(mod(tc.spare2, 256), 1, 'Y', 2, 'N', 'U'),
        T.SUBNAME,
        TS.NAME,
        TC.HIBOUNDVAL,
        TC.SUBPARTCNT
        FROM SYS.OBJ$ T, SYS.TABCOMPART$ TC, SYS.TS$ TS
        WHERE TC.BO# = ObjectNumIn
         AND  TC.OBJ# = T.OBJ#
         AND  TC.DEFTS# = TS.TS#
         ORDER BY TC.PART#;

/*--------------------------------------------------------------------*
 * Cursor used to acquire Partitioned Table SubSlot records           *
 *--------------------------------------------------------------------*/
 CURSOR sskey (ObjectNumIn INTEGER) IS
 SELECT TP.OBJ#,
        TP.SUBPART#,
        TP.PCTFREE$,
        TP.PCTUSED$,
        TP.INITRANS,
        TP.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        S.GROUPS,
        NVL(TS.BLOCKSIZE,0),
        decode(mod(trunc(tp.flags / 4), 2), 0, 'Y', 'N'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        T.SUBNAME,
        TS.NAME,
        TP.HIBOUNDLEN,
        TP.HIBOUNDVAL
        FROM SYS.OBJ$ T, SYS.TABSUBPART$ TP, SYS.TS$ TS, SYS.SEG$ S
        WHERE TP.POBJ# = ObjectNumIn
         AND  TP.OBJ# = T.OBJ#
         AND  TP.TS# = TS.TS#
         AND  TP.FILE# = S.FILE# (+)                                  /*RTC57310*/
         AND  TP.BLOCK# = S.BLOCK# (+)                                /*RTC57310*/
         AND  TP.TS#    = S.TS# (+)
         ORDER BY TP.SUBPART#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Table LOB Segments                         *
 *--------------------------------------------------------------------*/
 CURSOR lkey (ObjectNumIn INTEGER) IS
 SELECT L.COL#,
        L.LOBJ#,
        L.IND#,
        NVL((L.CHUNK * LT.BLOCKSIZE),0),
        L.PCTVERSION$,
        NVL(LS.INIEXTS,0),
        NVL(LS.EXTSIZE,0),
        LS.MINEXTS,
        LS.MAXEXTS,
        LS.EXTPCT,
        LS.LISTS,
        LS.GROUPS,
        NVL(LT.BLOCKSIZE,0),
        I.INITRANS,
        I.MAXTRANS,
        NVL(IG.INIEXTS,0),
        NVL(IG.EXTSIZE,0),
        IG.MINEXTS,
        IG.MAXEXTS,
        IG.EXTPCT,
        IG.LISTS,
        IG.GROUPS,
        NVL(IT.BLOCKSIZE,0),
        decode(l.property, 0, 'N', 'Y'),
        l.flags,
        decode(ls.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(i.flags,4), 0, 'Y', 'N'),
        decode(ig.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(lo.flags,4), 4, 'Y', 'N'),
        decode(bitand(io.flags,4), 4, 'Y', 'N'),
        LO.NAME,
        LT.NAME,
        IO.NAME,
        IT.NAME,
        l.freepools
        FROM SYS.OBJ$ LO, SYS.LOB$ L, SYS.TS$ LT, SYS.SEG$ LS,
             SYS.OBJ$ IO, SYS.IND$ I, SYS.TS$ IT, SYS.SEG$ IG
        WHERE L.OBJ# = ObjectNumIn
         AND  LO.OBJ# = L.LOBJ#
         AND  L.TS# = LT.TS#
         AND  L.FILE# = LS.FILE#
         AND  L.BLOCK# = LS.BLOCK#
         AND  LT.TS#    = LS.TS#
         AND  IO.OBJ# = L.IND#
         AND  I.OBJ# = L.IND#
         AND  I.TS# = IT.TS#
         AND  I.FILE# = IG.FILE#
         AND  I.BLOCK# = IG.BLOCK#
         AND  IT.TS#    = IG.TS#
         ORDER BY L.COL#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire non-COMPOSITE Partion LOBs                 *
 *--------------------------------------------------------------------*/
 CURSOR plkey (ObjectNumIn INTEGER) IS
 SELECT LF.FRAGOBJ#,
        NVL((LF.CHUNK * LT.BLOCKSIZE),0),
        LF.PCTVERSION$,
        NVL(LS.INIEXTS,0),
        NVL(LS.EXTSIZE,0),
        LS.MINEXTS,
        LS.MAXEXTS,
        LS.EXTPCT,
        LS.LISTS,
        LS.GROUPS,
        NVL(LT.BLOCKSIZE,0),
        LL.COL#,
        decode(LF.FRAGPRO, 2, 'Y', 'N'),
        LF.FRAGFLAGS,
        decode(LS.CACHEHINT, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(LO.FLAGS,4), 4, 'Y', 'N'),
        LT.NAME,
        LO.SUBNAME
        FROM SYS.LOBFRAG$ LF, SYS.TS$ LT, SYS.SEG$ LS, SYS.OBJ$ LO,
        SYS.LOB$ LL
        WHERE LF.TABFRAGOBJ# = ObjectNumIn
          AND  LF.FRAGOBJ# = LO.OBJ#
          AND  LF.PARENTOBJ# = LL.LOBJ#
         AND  LF.TS# = LT.TS#
         AND  LF.FILE# = LS.FILE#
         AND  LF.BLOCK# = LS.BLOCK#
         AND  LF.TS#    = LS.TS# (+);

/*--------------------------------------------------------------------*
 *  Cursor used to acquire SubPartition LOBs                          *
 *--------------------------------------------------------------------*/
 CURSOR splkey (ObjectNumIn INTEGER) IS
 SELECT LF.FRAGOBJ#,
        NVL((LF.CHUNK * LT.BLOCKSIZE),0),
        LF.PCTVERSION$,
        NVL(LS.INIEXTS,0),
        NVL(LS.EXTSIZE,0),
        LS.MINEXTS,
        LS.MAXEXTS,
        LS.EXTPCT,
        LS.LISTS,
        LS.GROUPS,
        NVL(LT.BLOCKSIZE,0),
        LL.COL#,
        decode(LF.FRAGPRO, 2, 'Y', 'N'),
        LF.FRAGFLAGS,
        decode(LS.CACHEHINT, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(LO.FLAGS,4), 4, 'Y', 'N'),
        LT.NAME,
        LO.SUBNAME
        FROM SYS.LOBFRAG$ LF, SYS.TS$ LT, SYS.SEG$ LS, SYS.OBJ$ LO,
             SYS.LOBCOMPPART$ LC, SYS.LOB$ LL
        WHERE LF.TABFRAGOBJ# = ObjectNumIn
         AND  LF.FRAGOBJ# = LO.OBJ#
         AND  LF.PARENTOBJ# = LC.PARTOBJ#
         AND  LC.LOBJ# = LL.LOBJ#
         AND  LF.TS# = LT.TS#
         AND  LF.FILE# = LS.FILE#
         AND  LF.BLOCK# = LS.BLOCK#
         AND  LF.TS#    = LS.TS# (+);

/*--------------------------------------------------------------------*
 *  Cursor used to acquire COMPOSITE Partion LOB Segments             *
 *--------------------------------------------------------------------*/
 CURSOR cplkey (ObjectNumIn INTEGER) IS
 SELECT LC.PARTOBJ#,
        NVL((LC.DEFCHUNK * LT.BLOCKSIZE),0),
        LC.DEFPCTVER$,
        NVL(LC.DEFINIEXTS,0),
        NVL(LC.DEFEXTSIZE,0),
        LC.DEFMINEXTS,
        LC.DEFMAXEXTS,
        LC.DEFEXTPCT,
        LC.DEFLISTS,
        LC.DEFGROUPS,
        NVL(LT.BLOCKSIZE,0),
        LL.COL#,
        decode(LC.DEFPRO, 2, 'Y', 'N'),
        LC.DEFFLAGS,
        decode(LC.DEFBUFPOOL, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(LO.FLAGS,4), 4, 'Y', 'N'),
        LT.NAME,
        LO.SUBNAME
        FROM SYS.LOBCOMPPART$ LC, SYS.TS$ LT, SYS.OBJ$ LO, SYS.LOB$ LL
        WHERE LC.TABPARTOBJ# = ObjectNumIn
         AND  LC.PARTOBJ# = LO.OBJ#
         AND  LC.LOBJ# = LL.LOBJ#
         AND  LC.DEFTS# = LT.TS# (+);

/*--------------------------------------------------------------------*
 *  Cursor used to acquire default Partion LOB Segments               *
 *--------------------------------------------------------------------*/
 CURSOR pdlkey (ObjectNumIn INTEGER) IS
 SELECT NVL((PL.DEFCHUNK * LT.BLOCKSIZE),0),
        PL.DEFPCTVER$,
        NVL(PL.DEFINIEXTS,0),
        NVL(PL.DEFEXTSIZE,0),
        PL.DEFMINEXTS,
        PL.DEFMAXEXTS,
        PL.DEFEXTPCT,
        PL.DEFLISTS,
        PL.DEFGROUPS,
        NVL(LT.BLOCKSIZE,0),
        decode(PL.DEFPRO, 2, 'Y', 'N'),
        PL.DEFFLAGS,
        decode(PL.DEFBUFPOOL, 0, 'D', 1, 'K', 2, 'R', 'U'),
        LC.NAME,
        LT.NAME
        FROM SYS.PARTLOB$ PL, SYS.COL$ LC, SYS.TS$ LT
        WHERE PL.TABOBJ# = ObjectNumIn
          AND  PL.TABOBJ# = LC.OBJ#
          AND  PL.INTCOL# = LC.INTCOL#
          AND  PL.DEFTS#  = LT.TS# (+);

/*--------------------------------------------------------------------*
 *  Cursor used for Get Table List when CID Pattern is explicit       *
 *  and Table Pattern is explicit.                                    *
 *--------------------------------------------------------------------*/
 CURSOR tlst0 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               ObjType1     INTEGER,
               ObjType2     INTEGER,
               ObjType3     INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
        LEAST(NVL(T.ROWCNT,-1),2147483647)
        FROM SYS.USER$ U, SYS.OBJ$ O, SYS.TAB$ T
       WHERE U.NAME = CidPatternIn
         AND O.OWNER# = U.USER#
         AND O.NAME = TblPatternIn
         AND O.TYPE# IN(ObjType1, ObjType2, ObjType3)
         AND bitand(o.flags,4) = 0
         AND O.OID$ IS NULL
         AND O.OBJ# = T.OBJ# (+)
         AND NOT EXISTS (
             SELECT S.OBJ#
               FROM SYS.SYN$ S, SYS.USER$ R, SYS.OBJ$ J
              WHERE S.OBJ#  = O.OBJ#
                AND S.OWNER = R.NAME
                AND R.USER# = J.OWNER#
                AND S.NAME  = J.NAME
                AND J.TYPE# != 2
                AND J.TYPE# != 4)
       ORDER BY U.NAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Table List when CID Pattern is generic        *
 *  and Table Pattern is explicit.                                    *
 *--------------------------------------------------------------------*/
 CURSOR tlst1 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               ObjType1     INTEGER,
               ObjType2     INTEGER,
               ObjType3     INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
        LEAST(NVL(T.ROWCNT,-1),2147483647)
        FROM SYS.USER$ U, SYS.OBJ$ O, SYS.TAB$ T
       WHERE U.NAME LIKE CidPatternIn
         AND O.OWNER# = U.USER#
         AND O.NAME = TblPatternIn
         AND O.TYPE# IN(ObjType1, ObjType2, ObjType3)
         AND bitand(o.flags,4) = 0
         AND O.OID$ IS NULL
         AND O.OBJ# = T.OBJ# (+)
         AND NOT EXISTS (
             SELECT S.OBJ#
               FROM SYS.SYN$ S, SYS.USER$ R, SYS.OBJ$ J
              WHERE S.OBJ#  = O.OBJ#
                AND S.OWNER = R.NAME
                AND R.USER# = J.OWNER#
                AND S.NAME  = J.NAME
                AND J.TYPE# != 2
                AND J.TYPE# != 4)
       ORDER BY U.NAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Table List when CID Pattern is explicit       *
 *  and Table Pattern is generic.                                     *
 *--------------------------------------------------------------------*/
 CURSOR tlst2 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               ObjType1     INTEGER,
               ObjType2     INTEGER,
               ObjType3     INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
        LEAST(NVL(T.ROWCNT,-1),2147483647)
        FROM SYS.USER$ U, SYS.OBJ$ O, SYS.TAB$ T
       WHERE U.NAME = CidPatternIn
         AND O.OWNER# = U.USER#
         AND O.NAME LIKE TblPatternIn
         AND O.TYPE# IN(ObjType1, ObjType2, ObjType3)
         AND bitand(o.flags,4) = 0
         AND O.OID$ IS NULL
         AND O.OBJ# = T.OBJ# (+)
         AND NOT EXISTS (
             SELECT S.OBJ#
               FROM SYS.SYN$ S, SYS.USER$ R, SYS.OBJ$ J
              WHERE S.OBJ#  = O.OBJ#
                AND S.OWNER = R.NAME
                AND R.USER# = J.OWNER#
                AND S.NAME  = J.NAME
                AND J.TYPE# != 2
                AND J.TYPE# != 4)
       ORDER BY U.NAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Table List when CID Pattern is generic        *
 *  and Table Pattern is generic.                                     *
 *--------------------------------------------------------------------*/
 CURSOR tlst3 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               ObjType1     INTEGER,
               ObjType2     INTEGER,
               ObjType3     INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
        LEAST(NVL(T.ROWCNT,-1),2147483647)
        FROM SYS.USER$ U, SYS.OBJ$ O, SYS.TAB$ T
       WHERE U.NAME LIKE CidPatternIn
         AND O.OWNER# = U.USER#
         AND O.NAME LIKE TblPatternIn
         AND O.TYPE# IN(ObjType1, ObjType2, ObjType3)
         AND bitand(o.flags,4) = 0
         AND O.OID$ IS NULL
         AND O.OBJ# = T.OBJ# (+)
         AND NOT EXISTS (
             SELECT S.OBJ#
               FROM SYS.SYN$ S, SYS.USER$ R, SYS.OBJ$ J
              WHERE S.OBJ#  = O.OBJ#
                AND S.OWNER = R.NAME
                AND R.USER# = J.OWNER#
                AND S.NAME  = J.NAME
                AND J.TYPE# != 2
                AND J.TYPE# != 4)
       ORDER BY U.NAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire SubPartitioned Template Info               *
 *--------------------------------------------------------------------*/
 CURSOR spstl (ObjectNumIn INTEGER) IS
 SELECT TS.NAME,
        DS.SPART_NAME,
        DS.HIBOUNDVAL
        FROM SYS.DEFSUBPART$ DS, SYS.TS$ TS
        WHERE DS.BO# = ObjectNumIn
          AND DS.TS# = TS.TS# (+)
        ORDER BY DS.SPART_POSITION; 

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Object data from OBJ$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETOBJECT
   (RowsToGet             IN INTEGER,
    CreatorNumIn          IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    ObjectNameIn          IN VARCHAR2,
    ObjectType           OUT CHAR,
    ObjectStatus         OUT CHAR,
    RemoteType           OUT CHAR,
    SynonymType          OUT CHAR,
    CreatorNumId         OUT INTEGER,
    ObjectNumId          OUT INTEGER,
    TblProp              OUT INTEGER,
    RemoteCreator        OUT VARCHAR2,
    RemoteObject         OUT VARCHAR2,
    RemoteLink           OUT VARCHAR2) is

   LocalObjType  CHAR(1);
   LocalObjNumId INTEGER;
   LocalTblProp  INTEGER;
   LocalLink     VARCHAR2(128);

 BEGIN
   ObjectType    := 'X';
   ObjectStatus  := 'X';
   RemoteType    := 'N';
   SynonymType   := 'N';
   CreatorNumId  := 999;
   ObjectNumId   := 888;
   RemoteCreator := 'NoCreator';
   RemoteObject  := 'NoObject';
   RemoteLink    := 'NoLink';
   LocalTblProp  := 0;
/*--------------------------------------------------------------------*
 *  If The Owner Number value is known we can improve performance     *
 *  by not having to reference the USER$ table. Otherwise we must do  *
 *  a locate using the input Creator Name to acquire the Owner Id.    *
 *--------------------------------------------------------------------*/
   IF CreatorNumIn = 0 THEN
      SELECT DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
             DECODE(O.STATUS, 0, 'U', 1, 'N', 'X'),
             U.USER#, O.OBJ#
        INTO LocalObjType,
             ObjectStatus,
             CreatorNumId,
             LocalObjNumId
        FROM SYS.USER$ U, SYS.OBJ$ O
        WHERE U.NAME = CreatorNameIn
         AND  O.NAME = ObjectNameIn
         AND  O.OWNER# = U.USER#
         AND  O.TYPE# IN (2, 4, 5)
         AND bitand(o.flags,4) = 0
         AND  O.OID$ is null;
      IF (LocalObjType IS NULL) OR (LocalObjType = 'X') THEN
        RAISE NO_DATA_FOUND;
      END IF;
/*--------------------------------------------------------------------*
 *  The internal Owner Number value is available, use it              *
 *  directly to locate the Object directly                            *
 *--------------------------------------------------------------------*/
    ELSE
      SELECT DECODE(O.TYPE#, 2, 'T', 4, 'V', 5, 'S', 'X'),
             DECODE(O.STATUS, 0, 'U', 1, 'N', 'X'),
             O.OBJ#
        INTO LocalObjType,
             ObjectStatus,
             LocalObjNumId
        FROM SYS.OBJ$ O
        WHERE O.OWNER# = CreatorNumIn
         AND  O.NAME = ObjectNameIn
         AND  O.TYPE# IN (2, 4, 5);
      if (LocalObjType IS NULL) OR (LocalObjType = 'X') THEN
        RAISE NO_DATA_FOUND;
      END IF;
   END IF;
   ObjectType     := LocalObjType;
   ObjectNumId    := LocalObjNumId;
/*--------------------------------------------------------------------*
 *  If we retrieved information about a TABLE extract the Table       *
 *  Property field from TAB$.                                         *
 *--------------------------------------------------------------------*/
   IF LocalObjType = 'T' THEN
      SELECT T.PROPERTY
        INTO LocalTblProp
        FROM SYS.TAB$ T
        WHERE T.OBJ# = LocalObjNumId;
   END IF;
   TblProp := LocalTblProp;
/*--------------------------------------------------------------------*
 *  If we retrieved information about an Object check to see if it is *
 *  a SYNONYM. If so extract the Base information from SYS.SYN$.      *
 *--------------------------------------------------------------------*/
   IF LocalObjType = 'S' THEN
      SELECT RTRIM(S.OWNER),
             RTRIM(S.NAME),
             RTRIM(S.NODE),
             DECODE(O.OWNER#,1,'P','N')
        INTO RemoteCreator,
             RemoteObject,
             LocalLink,
             SynonymType
        FROM SYS.SYN$ S, SYS.OBJ$ O
        WHERE S.OBJ# = LocalObjNumId
          AND S.OBJ# = O.OBJ#;
/*--------------------------------------------------------------------*
 *  If a DBlink has been provided mark this as a Remote Object        *
 *--------------------------------------------------------------------*/
      IF LocalLink IS NULL THEN RemoteType := 'N';
      ELSE RemoteType := 'Y';
        RemoteLink    := LocalLink;
      END IF;
     ELSE
      SynonymType   := 'N';
      RemoteType    := 'N';
   END IF;
 END PSTV0100_CSSGETOBJECT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Extended Object data from TAB$, TS$     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSEXPOBJECT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    RowCount             OUT INTEGER,
    ColCount             OUT INTEGER,
    InsTrigCnt           OUT INTEGER,
    UpdTrigCnt           OUT INTEGER,
    DelTrigCnt           OUT INTEGER) is

 BEGIN
      SELECT LEAST(NVL(T.ROWCNT,-1),2147483647), T.COLS
        INTO RowCount,ColCount
        FROM SYS.TAB$ T
        WHERE T.OBJ# = ObjectNumIn;

/*--------------------------------------------------------------------*
 *  Retrieve the three descriptors for Trigger Counts                 *
 *--------------------------------------------------------------------*/
      SELECT SUM(T.INSERT$),SUM(T.UPDATE$),SUM(T.DELETE$)
        INTO InsTrigCnt,UpdTrigCnt,DelTrigCnt
        FROM SYS.TRIGGER$ T
       WHERE T.BASEOBJECT = ObjectNumIn;
 END PSTV0100_CSSEXPOBJECT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Object data from TAB$, TS$,SEG$     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLOBJECT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctUsed              OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    Parallel             OUT INTEGER,
    Instances            OUT INTEGER,
    CacheStat            OUT INTEGER,
    ClsObjId             OUT INTEGER,
    SpcObjId             OUT INTEGER,
    TblFlag              OUT INTEGER,
    ObjFlag              OUT INTEGER,
    ChkCount             OUT INTEGER,
    Spare1               OUT INTEGER,
    TableSpaceName       OUT VARCHAR2,
    ClsIotName           OUT VARCHAR2) is

 BEGIN
/*--------------------------------------------------------------------*
 *  Get DDL oriented Table attributes                                 *
 *--------------------------------------------------------------------*/
 SELECT DECODE(BITAND(T.PROPERTY,32),0,MOD(T.PCTFREE$,100), 0),
        DECODE(BITAND(T.PROPERTY,32),0,T.PCTUSED$, 0),
        DECODE(BITAND(T.PROPERTY,32),0,T.INITRANS, 0),
        DECODE(BITAND(T.PROPERTY,32),0,T.MAXTRANS, 0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.INIEXTS,0),0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.EXTSIZE,0),0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.MINEXTS,0), 0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.MAXEXTS,0), 0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.EXTPCT,0), 0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.LISTS,0), 0),
        DECODE(BITAND(T.PROPERTY,32),0,NVL(S.GROUPS,0), 0),
        NVL(TS.BLOCKSIZE,0),
        NVL(T.DEGREE,0),
        NVL(T.INSTANCES,0),
        NVL(S.CACHEHINT,0),
        T.BOBJ#,
        NVL(T.TS#,0),
        T.FLAGS,
        O.FLAGS,
        S.SPARE1,
        NVL(RTRIM(TS.NAME),null),
        NVL(RTRIM(CL.NAME),null)
        INTO PctgFree,
             PctUsed,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             Groups,
             TsBlkSize,
             Parallel,
             Instances,
             CacheStat,
             ClsObjId,
             SpcObjId,
             TblFlag,
             ObjFlag,
             Spare1,
             TableSpaceName,
             ClsIotName
        FROM SYS.TAB$ T, SYS.TS$ TS, SYS.OBJ$ CL, SYS.SEG$ S, SYS.OBJ$ O
        WHERE T.OBJ# = ObjectNumIn
         AND  O.OBJ# = T.OBJ#
         AND  T.BOBJ# = CL.OBJ# (+)
         AND  T.TS# = TS.TS# (+)
         AND  T.FILE# = S.FILE# (+)
         AND  T.BLOCK# = S.BLOCK# (+)
         AND  T.TS# = S.TS# (+);

/*--------------------------------------------------------------------*
 *  Get count of Table check constraints if any                       *
 *--------------------------------------------------------------------*/
 SELECT COUNT(*)
   INTO ChkCount
   FROM SYS.CDEF$
  WHERE OBJ# = ObjectNumIn
    AND TYPE# = 1;
 END PSTV0100_CSSDDLOBJECT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table PartBase from PARTOBJ$,TS$    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartCnt              OUT INTEGER,
    PartKeyCnt           OUT INTEGER,
    PartType             OUT INTEGER,
    PctgFree             OUT INTEGER,
    PctgUsed             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2,
    Spare2               OUT VARCHAR2) is

 BEGIN
 SELECT PO.PARTCNT,
        PO.PARTKEYCOLS,
        PO.PARTTYPE,
        PO.DEFPCTFREE,
        PO.DEFPCTUSED,
        PO.DEFINITRANS,
        PO.DEFMAXTRANS,
        decode(PO.DEFTINIEXTS,2147483647,0,PO.DEFTINIEXTS),
        decode(PO.DEFEXTSIZE,2147483647,0,PO.DEFEXTSIZE),
        decode(PO.DEFMINEXTS,2147483647,0,PO.DEFMINEXTS),
        decode(PO.DEFMAXEXTS,2147483647,0,PO.DEFMAXEXTS),
        decode(PO.DEFEXTPCT,2147483647,0,PO.DEFEXTPCT),
        PO.DEFLISTS,
        PO.DEFGROUPS,
        NVL(TS.BLOCKSIZE,0),
        decode(po.deflogging, 0, 'X', 1, 'Y', 2, 'N', 'U'),
        decode(po.spare1, 0, 'D', 1, 'K', 2, 'R', 'U'),
        TS.NAME,
        decode(PO.SPARE2, 0, NULL, to_char(PO.SPARE2, 'FM0xxxxxxxxxx'))
        INTO PartCnt,
             PartKeyCnt,
             PartType,
             PctgFree,
             PctgUsed,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             Groups,
             TsBlkSize,
             LogFlag,
             BPool,
             TSName,
             Spare2
        FROM SYS.PARTOBJ$ PO, SYS.TS$ TS
        WHERE PO.OBJ# = ObjectNumIn
         AND  PO.DEFTS# = TS.TS# (+);
 END PSTV0100_CSSDDLTBLPARTBASE;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table PartKeys from PARTCOL$        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_tblbbyte,
    KeyPos               OUT t_tblbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT pkey%ISOPEN THEN
        OPEN pkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH pkey INTO KeyNum(i),
                        KeyPos(i);
        IF pkey%NOTFOUND THEN
           CLOSE pkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSDDLTBLPARTKEYS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table SubPartKeys from SUBPARTCOL$  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLSUBPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_tblbbyte,
    KeyPos               OUT t_tblbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT spkey%ISOPEN THEN
        OPEN spkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH spkey INTO KeyNum(i),
                        KeyPos(i);
        IF spkey%NOTFOUND THEN
           CLOSE spkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSDDLTBLSUBPARTKEYS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table Partitions OBJ$,TABPARTS, etc *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_tblbbyte,
    PartNum              OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    HiBndLen             OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    Comp                 OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT skey%ISOPEN THEN
        OPEN skey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH skey INTO PartObjNum(i),
                        PartNum(i),
                        PctGFree(i),
                        PctGUsed(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        Groups(i),
                        TsBlkSize(i),
                        HiBndLen(i),
                        LogFlag(i),
                        BPool(i),
                        Comp(i),
                        PartName(i),
                        TSName(i),
                        HiBndVal(i);
        IF skey%NOTFOUND THEN
           CLOSE skey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSDDLTBLPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire COMPOSITE Partitions OBJ$,TABCOMPART    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLCOMPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_tblbbyte,
    PartNum              OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    HiBndLen             OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    Comp                 OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound,
    SubPartCnt           OUT t_tblbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ckey%ISOPEN THEN
        OPEN ckey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ckey INTO PartObjNum(i),
                        PartNum(i),
                        PctGFree(i),
                        PctGUsed(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        Groups(i),
                        TsBlkSize(i),
                        HiBndLen(i),
                        LogFlag(i),
                        BPool(i),
                        Comp(i),
                        PartName(i),
                        TSName(i),
                        HiBndVal(i),
                        SubPartCnt(i);
        IF ckey%NOTFOUND THEN
           CLOSE ckey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSDDLTBLCOMPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table SubPartitions OBJ$,TABSUBPART$ etc*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLSUBPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SubPartObjNum        OUT t_tblbbyte,
    SubPartNum           OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndLen             OUT t_tblbbyte,
    HiBndVal             OUT t_hibound) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT sskey%ISOPEN THEN
        OPEN sskey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH sskey INTO SubPartObjNum(i),
                        SubPartNum(i),
                        PctGFree(i),
                        PctGUsed(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        Groups(i),
                        TsBlkSize(i),
                        LogFlag(i),
                        BPool(i),
                        PartName(i),
                        TSName(i),
                        HiBndLen(i),
                        HiBndVal(i);
        IF sskey%NOTFOUND THEN
           CLOSE sskey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSDDLTBLSUBPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire IOT data from IND$,TS$,SEG$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLIOTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctgThres            OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    InclCol              OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2,
    CompCols             OUT INTEGER) is

 BEGIN
 SELECT I.PCTFREE$,
        I.PCTTHRES$,
        I.INITRANS,
        I.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        S.GROUPS,
        NVL(TS.BLOCKSIZE,0),
        I.TRUNCCNT,
        decode(bitand(i.flags,4), 0, 'Y', 'N'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        TS.NAME,
        decode(bitand(i.flags,32), 32, i.spare2, 0)
        INTO PctgFree,
             PctgThres,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             Groups,
             TsBlkSize,
             InclCol,
             LogFlag,
             BPool,
             TSName,
             CompCols
        FROM SYS.IND$ I, SYS.TS$ TS, SYS.SEG$ S
        WHERE I.BO# = ObjectNumIn
         AND  I.TYPE# = 4
         AND  I.TS# = TS.TS# (+)
         AND  i.FILE# = S.FILE# (+)
         AND  I.BLOCK# = S.BLOCK# (+)
         AND  I.TS# = S.TS# (+);
 END PSTV0100_CSSTBLIOTBASE;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire IOT data from IND$,TS$,SEG$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLIOTOVER
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctgUsed             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2) is

 BEGIN
 SELECT T.PCTFREE$,
        T.PCTUSED$,
        T.INITRANS,
        T.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        S.GROUPS,
        NVL(TS.BLOCKSIZE,0),
        decode(bitand(t.flags,32), 0, 'Y', 'N'),
        decode(NVL(S.CACHEHINT,3), 0, 'D', 1, 'K', 2, 'R', 'U'),
        TS.NAME
        INTO PctgFree,
             PctgUsed,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             Groups,
             TsBlkSize,
             LogFlag,
             BPool,
             TSName
        FROM SYS.TAB$ T, SYS.TS$ TS, SYS.SEG$ S
        WHERE T.BOBJ# = ObjectNumIn
         AND bitand(T.PROPERTY,512) = 512
         AND  T.TS# = TS.TS# (+)
         AND  T.FILE# = S.FILE# (+)
         AND  T.BLOCK# = S.BLOCK# (+)
         AND  T.TS# = S.TS# (+);
 END PSTV0100_CSSTBLIOTOVER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table LOBs from LOB$,IND$,TS$,SEG$      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLLOBBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    LobCol               OUT t_tblbbyte,
    LobObj               OUT t_tblbbyte,
    LobIdx               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    IInitExt             OUT t_tblbbyte,
    INextExt             OUT t_tblbbyte,
    IMinExt              OUT t_tblbbyte,
    IMaxExt              OUT t_tblbbyte,
    IPctIncr             OUT t_tblbbyte,
    ILists               OUT t_tblbbyte,
    IGroups              OUT t_tblbbyte,
    ITsBlkSize           OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    IdxLog               OUT t_tblcbyte,
    IdxBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    IdxSysName           OUT t_tblcbyte,
    SegName              OUT t_tablename,
    SegTSName            OUT t_tsname,
    IdxName              OUT t_tablename,
    IdxTSName            OUT t_tsname,
    Freepools            OUT t_tblbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT lkey%ISOPEN THEN
        OPEN lkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH lkey INTO LobCol(i),
                        LobObj(i),
                        LobIdx(i),
                        LobChunk(i),
                        PctVers(i),
                        SInitExt(i),
                        SNextExt(i),
                        SMinExt(i),
                        SMaxExt(i),
                        SPctIncr(i),
                        SLists(i),
                        SGroups(i),
                        STsBlkSize(i),
                        InitTran(i),
                        MaxTran(i),
                        IInitExt(i),
                        INextExt(i),
                        IMinExt(i),
                        IMaxExt(i),
                        IPctIncr(i),
                        ILists(i),
                        IGroups(i),
                        ITsBlksize(i),
                        RowStg(i),
                        LobFlags(i),
                        SegBPool(i),
                        IdxLog(i),
                        IdxBPool(i),
                        SegSysName(i),
                        IdxSysName(i),
                        SegName(i),
                        SegTSName(i),
                        IdxName(i),
                        IdxTSName(i),
                        Freepools(i);
        IF lkey%NOTFOUND THEN
           CLOSE lkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSTBLLOBBASE;

/*--------------------------------------------------------------------*
 *  Procedure to acquire Part LOBs from LOBFRAG$,TS$,SEG$,OBJ$        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT plkey%ISOPEN THEN
        OPEN plkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH plkey INTO SegObj(i),
                         LobChunk(i),
                         PctVers(i),
                         SInitExt(i),
                         SNextExt(i),
                         SMinExt(i),
                         SMaxExt(i),
                         SPctIncr(i),
                         SLists(i),
                         SGroups(i),
                         STsBlkSize(i),
                         ColNum(i),
                         RowStg(i),
                         LobFlags(i),
                         SegBPool(i),
                         SegSysName(i),
                         SegTSName(i),
                         SegName(i);
        IF plkey%NOTFOUND THEN
           CLOSE plkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSPARTLOB;

/*--------------------------------------------------------------------*
 *  Procedure to acquire SubPart LOBs from LOBFRAG$,TS$,SEG$,OBJ$     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSSUBPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT splkey%ISOPEN THEN
        OPEN splkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH splkey INTO SegObj(i),
                          LobChunk(i),
                          PctVers(i),
                          SInitExt(i),
                          SNextExt(i),
                          SMinExt(i),
                          SMaxExt(i),
                          SPctIncr(i),
                          SLists(i),
                          SGroups(i),
                          STsBlkSize(i),
                          ColNum(i),
                          RowStg(i),
                          LobFlags(i),
                          SegBPool(i),
                          SegSysName(i),
                          SegTSName(i),
                          SegName(i);
        IF splkey%NOTFOUND THEN
           CLOSE splkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSSUBPARTLOB;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Part LOBs from LOBCOMPART$,TS$,LOB$,OBJ$*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSCOMPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT cplkey%ISOPEN THEN
        OPEN cplkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH cplkey INTO SegObj(i),
                         LobChunk(i),
                         PctVers(i),
                         SInitExt(i),
                         SNextExt(i),
                         SMinExt(i),
                         SMaxExt(i),
                         SPctIncr(i),
                         SLists(i),
                         SGroups(i),
                         STsBlkSize(i),
                         ColNum(i),
                         RowStg(i),
                         LobFlags(i),
                         SegBPool(i),
                         SegSysName(i),
                         SegTSName(i),
                         SegName(i);
        IF cplkey%NOTFOUND THEN
           CLOSE cplkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSCOMPARTLOB;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire default Part LOBs from PARTLOB$,COL$,TS$*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSPARTDLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    ColName              OUT t_tablename,
    SegTSName            OUT t_tsname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT pdlkey%ISOPEN THEN
        OPEN pdlkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH pdlkey INTO LobChunk(i),
                          PctVers(i),
                          SInitExt(i),
                          SNextExt(i),
                          SMinExt(i),
                          SMaxExt(i),
                          SPctIncr(i),
                          SLists(i),
                          SGroups(i),
                          STsBlkSize(i),
                          RowStg(i),
                          LobFlags(i),
                          SegBPool(i),
                          ColName(i),
                          SegTSName(i);
        IF pdlkey%NOTFOUND THEN
           CLOSE pdlkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSPARTDLOB;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire View Extended Attributes                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSEXPVIEW
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ViewLen              OUT INTEGER,
    ChkName              OUT VARCHAR2) is

 BEGIN
   SELECT V.TEXTLENGTH
      INTO ViewLen
      FROM SYS.VIEW$ V
      WHERE V.OBJ# = ObjectNumIn;

/*--------------------------------------------------------------------*
 *  Execute The search for a Check Name as a sub-block so that        *
 *  we can explicitly catch the Not Found and set a Token Id          *
 *--------------------------------------------------------------------*/
   BEGIN
     SELECT CO.NAME
       INTO ChkName
       FROM SYS.CON$ CO, SYS.CDEF$ CD
      WHERE CD.OBJ#  = ObjectNumIn
        AND CD.TYPE# = 5
        AND CO.CON#  = CD.CON#;

     EXCEPTION
       WHEN NO_DATA_FOUND THEN ChkName := '~';
   END;
 END PSTV0100_CSSEXPVIEW;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Text of a View from VIEW$               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETVIEW
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER, /* not used */
    ViewText             OUT VARCHAR2) is

  csr INTEGER;
  rc  NUMBER;
  len INTEGER;
  cnk INTEGER := 4000;
 BEGIN
   csr := DBMS_SQL.OPEN_CURSOR;
   DBMS_SQL.PARSE(csr, 'SELECT TEXT FROM SYS.VIEW$ WHERE OBJ# = :N',
                  DBMS_SQL.NATIVE);
   DBMS_SQL.BIND_VARIABLE(csr, ':N', ObjectNumIn);
   DBMS_SQL.DEFINE_COLUMN_LONG(csr, 1);
   rc := DBMS_SQL.EXECUTE_AND_FETCH(csr);
   DBMS_SQL.COLUMN_VALUE_LONG(csr, 1, cnk, OffsetNumIn, ViewText, len);
   DBMS_SQL.CLOSE_CURSOR(csr);
 END PSTV0100_CSSGETVIEW;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List when Creator and Table names *
 *  are explicit references.                                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST0
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT tlst0%ISOPEN THEN
        OPEN tlst0(CidPatternIn,
                   TblPatternIn,
                   ObjType1,
                   ObjType2,
                   ObjType3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH tlst0 INTO CreatorName(i),
                        TableName(i),
                        TableType(i),
                        RowCount(i);
        IF tlst0%NOTFOUND THEN
           CLOSE tlst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETTBLLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List when Creator name is a       *
 *  generic LIKE pattern and Table name is an explicit reference.     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST1
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT tlst1%ISOPEN THEN
        OPEN tlst1(CidPatternIn,
                   TblPatternIn,
                   ObjType1,
                   ObjType2,
                   ObjType3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH tlst1 INTO CreatorName(i),
                        TableName(i),
                        TableType(i),
                        RowCount(i);
        IF tlst1%NOTFOUND THEN
           CLOSE tlst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETTBLLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List when Creator name is an      *
 *  explicit reference and Table name is a Generic LIKE pattern       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST2
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT tlst2%ISOPEN THEN
        OPEN tlst2(CidPatternIn,
                   TblPatternIn,
                   ObjType1,
                   ObjType2,
                   ObjType3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH tlst2 INTO CreatorName(i),
                        TableName(i),
                        TableType(i),
                        RowCount(i);
        IF tlst2%NOTFOUND THEN
           CLOSE tlst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETTBLLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List when Creator name is a       *
 *  Generic LIKE pattern andd Table name is a Generic LIKE pattern    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST3
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT tlst3%ISOPEN THEN
        OPEN tlst3(CidPatternIn,
                   TblPatternIn,
                   ObjType1,
                   ObjType2,
                   ObjType3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH tlst3 INTO CreatorName(i),
                        TableName(i),
                        TableType(i),
                        RowCount(i);
        IF tlst3%NOTFOUND THEN
           CLOSE tlst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETTBLLIST3;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire SubPartition Template Info              *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSUBTEMPLATELIST
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    TSName               OUT t_tsname,
    Name                 OUT t_subname,
    HiBndVal             OUT t_hibound) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT spstl%ISOPEN THEN
        OPEN spstl(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH spstl INTO TSName(i),
                         Name(i),
                         HiBndVal(i);
        IF spstl%NOTFOUND THEN
           CLOSE spstl;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSUBTEMPLATELIST;
END PSTO92V0101_CSSTABLE;