/*--------------------------------------------------------------------*
 *  Oracle9i package body for CheckNameSpace stored procedure.        *
 *--------------------------------------------------------------------*/
CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO01V0100_CSSCHECKNAMESPACE AS
CURSOR geterrmsg (CreatorName         IN VARCHAR2,
                  ObjectName          IN VARCHAR2,
                  ObjType             IN INTEGER)
IS
   select e.line, e.position#, e.sequence#, e.text
     from sys.obj$ o, sys.error$ e, sys.user$ u
    where o.obj# = e.obj#
      and o.owner# = u.user#
      and o.type# = ObjType
      and o.name = ObjectName
      and u.name = CreatorName
    order by e.sequence#;


PROCEDURE PSTV0100_CSSCHECKNAMESPACE
   (RowsToGet           IN INTEGER,
    CreatorName         IN VARCHAR2,
    ObjectName          IN VARCHAR2,
    QualifierName       IN VARCHAR2,
    QualifierCreator    IN VARCHAR2,
    ObjType             IN INTEGER,
    FoundObjType       OUT INTEGER,
    ConflictCreator    OUT VARCHAR2,
    ConflictName       OUT VARCHAR2
   ) AS
BEGIN
 DECLARE
     PkgBody INTEGER;
 BEGIN
   FoundObjType    := 0;
   PkgBody         := 0;
   ConflictCreator := '?';
   ConflictName    := '?';

 IF    (ObjType = 21) THEN /*cluster*/
   SELECT 21
    INTO  FoundObjType
    FROM  SYS.USER$ U, SYS.OBJ$ O
    WHERE U.NAME = CreatorName
     AND  O.NAME = ObjectName
     AND  O.OWNER# = U.USER#
     AND  O.TYPE# = 3; /*cluster*/
 ELSIF (ObjType = 12) THEN /*trigger*/
   SELECT 12+256*(T.TYPE#*8+T.INSERT$*4+T.UPDATE$*2+T.DELETE$), TABUSER.NAME, TABOBJ.NAME
    INTO  FoundObjType, ConflictCreator, ConflictName
    FROM SYS.OBJ$ TRIGOBJ, SYS.OBJ$ TABOBJ, SYS.TRIGGER$ T,
         SYS.USER$ TABUSER, SYS.USER$ TRIGUSER
    WHERE TRIGOBJ.OBJ#   = T.OBJ#
      AND TABOBJ.OBJ#    = T.BASEOBJECT
      AND TRIGOBJ.OWNER# = TRIGUSER.USER#
      AND TABOBJ.OWNER#  = TABUSER.USER#
      AND TRIGUSER.NAME  = QualifierCreator
      AND TRIGOBJ.NAME   = QualifierName;
 ELSIF (ObjType = 18) THEN /*tablespace*/
   SELECT 18
    INTO  FoundObjType
    FROM  SYS.TS$ TS
    WHERE TS.NAME = ObjectName
     AND  TS.ONLINE$ !=3;
 ELSIF ((ObjType = 6) OR /*datatype*/
        (ObjType = 1) OR /*table*/
        (ObjType = 2) OR /*view*/
        (ObjType = 3) OR /*sequence*/
        (ObjType = 14)OR /*synonym*/
        (ObjType = 15)OR /*function*/
        (ObjType = 16)OR /*procedure*/
        (ObjType = 17)) /*package*/
  THEN
    SELECT decode(O.TYPE#,
                     2,1,
                     4,2,
                     6,3,
                     5,14,
                     8,15,
                     7,16,
                     9,17), O.TYPE#
     INTO  FoundObjType, PkgBody
     FROM  SYS.USER$ U, SYS.OBJ$ O
     WHERE U.NAME = CreatorName
      AND  O.NAME = ObjectName
      AND  O.OWNER# = U.USER#
      AND  O.TYPE#  IN (2,4,5,6,7,8,9,13);
    IF(ObjType = 17) AND (PkgBody > 0)THEN
      BEGIN
        SELECT 256
          INTO PkgBody
          FROM  SYS.USER$ U, SYS.OBJ$ O
         WHERE U.NAME = CreatorName
           AND  O.NAME = ObjectName
           AND  O.OWNER# = U.USER#
           AND  O.TYPE# = 11;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          PkgBody := 0;
      END;
      FoundObjType := 17 + PkgBody;
    END IF;
 ELSIF (ObjType = 27)  /*package body*/
  THEN
    SELECT decode(O.TYPE#,
                     2,1,
                     4,2,
                     6,3,
                     5,14,
                     8,15,
                     7,16,
                    11,27)
     INTO  FoundObjType
     FROM  SYS.USER$ U, SYS.OBJ$ O
     WHERE U.NAME = CreatorName
      AND  O.NAME = ObjectName
      AND  O.OWNER# = U.USER#
      AND  O.TYPE#  IN (2,4,5,6,7,8,11,13);
 ELSIF (ObjType = 8) THEN /*index*/
   SELECT 8, IU.NAME, IO.NAME
    INTO  FoundObjType, ConflictCreator, ConflictName
    FROM  SYS.USER$ U, SYS.OBJ$ O, SYS.IND$ I, SYS.USER$ IU, SYS.OBJ$ IO
    WHERE U.NAME = QualifierCreator
     AND  O.NAME = QualifierName
     AND  O.OWNER# = U.USER#
     AND  O.OBJ# = I.OBJ#
     AND  I.BO# = IO.OBJ#
     AND  IO.OWNER# = IU.USER#;
 ELSIF ((ObjType = 7) OR /*CHECK*/
        (ObjType = 9) OR /*PK*/
        (ObjType = 10)OR /*FK*/
        (ObjType = 11))  /*UNIQUE*/
  THEN
      SELECT decode(CDEF.TYPE#,
                        1,7, 7,7,
                        2,9,
                        3,11,
                        4,10,
                        -1), /* for others, like 5, 'V', 6, 'O'*/
                            OU.NAME,         O.NAME
        INTO  FoundObjType, ConflictCreator, ConflictName
        FROM  SYS.USER$ U, SYS.CON$ CON, SYS.CDEF$ CDEF, SYS.OBJ$ O, SYS.USER$ OU
        WHERE U.NAME = QualifierCreator
         AND  CON.NAME = QualifierName
         AND  CON.OWNER# = U.USER#
         AND  CON.CON# = CDEF.CON#
         AND  CDEF.OBJ# = O.OBJ#
         AND  O.OWNER# = OU.USER#;
END  IF;
END;
END;

  PROCEDURE PSTV0100_CSSGETERRMSG
   (RowsToGet           IN INTEGER,
    CreatorName         IN VARCHAR2,
    ObjectName          IN VARCHAR2,
    ObjType             IN INTEGER,
    LineNo             OUT t_line,
    Position           OUT t_position,
    SeqNo              OUT t_seqno,
    ErrMsg             OUT t_text
   ) AS
  BEGIN
     IF NOT geterrmsg %ISOPEN THEN
        OPEN geterrmsg (CreatorName,
                        ObjectName,
                        ObjType);
     END IF;

     FOR i IN 1..RowsToGet LOOP
        FETCH geterrmsg  INTO LineNo(i), Position(i), SeqNo(i), ErrMsg(i);
        IF geterrmsg%NOTFOUND THEN
           CLOSE geterrmsg;
           EXIT;
        END IF;
     END LOOP;
  END;
END PSTO01V0100_CSSCHECKNAMESPACE;
