/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Execute Services       *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO01V0100_CSSEXECUTE AS

/*--------------------------------------------------------------------*
 *  Cursor used to acquire valid dependencies used by CSS             *
 *--------------------------------------------------------------------*/
 CURSOR drec (DepCid INTEGER) IS
  SELECT PU.USER#,
         DU.USER#,
         DECODE(PO.TYPE#,11,9,PO.TYPE#),
         DECODE(DO.TYPE#,11,9,DO.TYPE#),
         NVL(AC.TYPES,99),
         PU.NAME,
         PO.NAME,
         DU.NAME,
         DO.NAME
    FROM SYS.USER$ PU, SYS.OBJ$ PO,
         SYS.USER$ DU, SYS.OBJ$ DO,
         SYS.DEPENDENCY$ DP, SYS.ACCESS$ AC
   WHERE DO.OBJ# = DP.D_OBJ#
     AND DO.OWNER# != 0
     AND DO.TYPE# IN (2,4,5,6,7,8,9,11,12)
     AND DO.NAME NOT LIKE('V$%')
     AND PO.OBJ# = DP.P_OBJ#
     AND PO.OWNER# != 0
     AND PO.TYPE# IN (2,4,5,6,7,8,9,11,12)
     AND PO.NAME NOT LIKE('V$%')
     AND NOT (((PO.TYPE# = 9) AND (DO.TYPE# = 11)) AND (PO.NAME = DO.NAME))
     AND (DO.OWNER# = DepCid OR PO.OWNER# = DepCid)
     AND DU.USER# = DO.OWNER#
     AND PU.USER# = PO.OWNER#
     AND AC.D_OBJ#(+) = DP.D_OBJ#
     AND AC.ORDER#(+) = DP.ORDER#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire valid synonyms used by CSS                 *
 *--------------------------------------------------------------------*/
 CURSOR srec (DepCid INTEGER) IS
  SELECT PU.USER#,
         DU.USER#,
         DECODE(PO.TYPE#,11,9,PO.TYPE#),
         5,
         99,
         PU.NAME,
         PO.NAME,
         DU.NAME,
         DO.NAME
    FROM SYS.USER$ PU, SYS.USER$ DU,
         SYS.OBJ$ PO, SYS.OBJ$ DO,
         SYS.SYN$ SY
   WHERE DO.TYPE# = 5
     AND DO.Owner# != 0
     AND DU.USER# = DO.OWNER#
     AND SY.OBJ# = DO.OBJ#
     AND SY.NODE IS NULL
     AND SY.NAME NOT LIKE('V$%')
     AND PO.NAME(+) = SY.NAME
     AND PO.TYPE#(+) < 12
     AND PO.Owner#(+) != 0
     AND PU.USER#(+) = PO.OWNER#
     AND PU.NAME = SY.OWNER
     AND (DO.OWNER# = DepCid OR PO.OWNER# = DepCid);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Dependencies for CSS                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETDEPENDS
   (RowsToGet             IN INTEGER,
    CreatorNum            IN INTEGER,
    CreatorName           IN VARCHAR2,
    ReqCNum              OUT t_dbmsint,
    RefCNum              OUT t_dbmsint,
    ReqOType             OUT t_dbmsint,
    RefOType             OUT t_dbmsint,
    DepMode              OUT t_dbmsint,
    ReqCName             OUT t_creatorname,
    ReqOName             OUT t_objectname,
    RefCName             OUT t_creatorname,
    RefOName             OUT t_objectname) is

   LclROType     INTEGER;
   LclFOType     INTEGER;
   DepCid        INTEGER;

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call perform setup.                            *
 *    1. If Depend Owner number not input locate it                   *
 *    2. Open query result cursor                                     *
 *--------------------------------------------------------------------*/
     IF NOT drec%ISOPEN THEN
       DepCid := CreatorNum;
       IF (DepCid = 0) THEN
         SELECT U.USER#
           INTO DepCid
           FROM SYS.USER$ U
          WHERE U.Name = CreatorName;
         IF (DepCid IS NULL) OR (DepCid = 0) THEN
           RAISE NO_DATA_FOUND;
         END IF;
       END IF;
       OPEN drec(DepCid);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH drec INTO ReqCNum(i),RefCNum(i),
                        LclROType, LclFOType, DepMode(i),
                        ReqCName(i),ReqOName(i),
                        RefCName(i),RefOName(i);
        IF drec%NOTFOUND THEN
           CLOSE drec;
           EXIT;
        END IF;
/*--------------------------------------------------------------------*
 *  Mark 1st return record with Dep Owner id flag                     *
 *--------------------------------------------------------------------*/
        IF (drec%ROWCOUNT = 1) THEN
          IF (LclROType = DepCid) THEN
            LclROType := LclROType + 256;
          ELSE
            LclFOType := LclFOType + 256;
          END IF;
        END IF;
        ReqOType(i) := LclROType;
        RefOType(i) := LclFOType;
     END LOOP;
 END PSTV0100_CSSGETDEPENDS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonyms for CSS                        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNS
   (RowsToGet             IN INTEGER,
    CreatorNum            IN INTEGER,
    CreatorName           IN VARCHAR2,
    ReqCNum              OUT t_dbmsint,
    RefCNum              OUT t_dbmsint,
    ReqOType             OUT t_dbmsint,
    RefOType             OUT t_dbmsint,
    DepMode              OUT t_dbmsint,
    ReqCName             OUT t_creatorname,
    ReqOName             OUT t_objectname,
    RefCName             OUT t_creatorname,
    RefOName             OUT t_objectname) is

   LclROType     INTEGER;
   LclFOType     INTEGER;
   DepCid        INTEGER;

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call perform setup.                            *
 *    1. If Synonym Owner number not input locate it                  *
 *    2. Open query result cursor                                     *
 *--------------------------------------------------------------------*/
     IF NOT srec%ISOPEN THEN
       DepCid := CreatorNum;
       IF (DepCid = 0) THEN
         SELECT U.USER#
           INTO DepCid
           FROM SYS.USER$ U
          WHERE U.Name = CreatorName;
         IF (DepCid IS NULL) OR (DepCid = 0) THEN
           RAISE NO_DATA_FOUND;
         END IF;
       END IF;
       OPEN srec(DepCid);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH srec INTO ReqCNum(i),RefCNum(i),
                        LclROType, LclFOType, DepMode(i),
                        ReqCName(i),ReqOName(i),
                        RefCName(i),RefOName(i);
        IF srec%NOTFOUND THEN
           CLOSE srec;
           EXIT;
        END IF;
/*--------------------------------------------------------------------*
 *  Mark 1st return record with Dep Owner id flag                     *
 *--------------------------------------------------------------------*/
        IF (srec%ROWCOUNT = 1) THEN
          IF (LclROType = DepCid) THEN
            LclROType := LclROType + 256;
          ELSE
            LclFOType := LclFOType + 256;
          END IF;
        END IF;
        ReqOType(i) := LclROType;
        RefOType(i) := LclFOType;
     END LOOP;
 END PSTV0100_CSSGETSYNS;
END PSTO01V0100_CSSEXECUTE;
