/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Synonyms               *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO01V0100_CSSSYNONYM AS
/*--------------------------------------------------------------------*
 *  Cursor used for Get Synonym List when CID Pattern is explicit     *
 *  and Name Pattern is explicit.                                     *
 *  SP Name = PSTV0100_CSSSYNPRCLIST0                                 *
 *--------------------------------------------------------------------*/
 CURSOR synlst0 (CidPattern VARCHAR2,
                 SynPattern VARCHAR2) IS
 SELECT DECODE(SU.NAME, 'PUBLIC', 'Y', 'N'),
        DECODE(NVL(SD.NODE,'-1'),'-1','N','Y'),
        SU.NAME, SO.NAME, SD.OWNER,SD.NAME
   FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
  WHERE SO.TYPE# = 5
    AND SO.NAME  = SynPattern
    AND SU.USER# = SO.OWNER#
    AND SU.NAME  = CidPattern
    AND SD.OBJ#  = SO.OBJ#
  ORDER BY SU.NAME, SO.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Synonym List when CID Pattern is generic      *
 *  and Synonym Pattern is explicit.                                  *
 *  SP Name = PSTV0100_CSSGETSYNLIST1                                 *
 *--------------------------------------------------------------------*/
 CURSOR synlst1 (CidPattern VARCHAR2,
                 SynPattern VARCHAR2) IS
 SELECT DECODE(SU.NAME, 'PUBLIC', 'Y', 'N'),
        DECODE(NVL(SD.NODE,'-1'),'-1','N','Y'),
        SU.NAME, SO.NAME, SD.OWNER,SD.NAME
   FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
  WHERE SO.TYPE# = 5
    AND SO.NAME  = SynPattern
    AND SU.USER# = SO.OWNER#
    AND SU.NAME  LIKE CidPattern
    AND SD.OBJ#  = SO.OBJ#
   ORDER BY SU.NAME, SO.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Synonym List when CID Pattern is explicit     *
 *  and Synonym Pattern is generic.                                   *
 *  SP Name = PSTV0100_CSSGETSYNLIST2                                 *
 *--------------------------------------------------------------------*/
 CURSOR synlst2 (CidPattern VARCHAR2,
                 SynPattern VARCHAR2) IS
 SELECT DECODE(SU.NAME, 'PUBLIC', 'Y', 'N'),
        DECODE(NVL(SD.NODE,'-1'),'-1','N','Y'),
        SU.NAME, SO.NAME, SD.OWNER,SD.NAME
   FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
  WHERE SO.TYPE# = 5
    AND SO.NAME  LIKE SynPattern
    AND SU.USER# = SO.OWNER#
    AND SU.NAME  = CidPattern
    AND SD.OBJ#  = SO.OBJ#
   ORDER BY SU.NAME, SO.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Synonym List when CID Pattern is generic      *
 *  and Synonym Pattern is generic.                                   *
 *  SP Name = PSTV0100_CSSGETSYNLIST3                                 *
 *--------------------------------------------------------------------*/
 CURSOR synlst3 (CidPattern VARCHAR2,
                 SynPattern VARCHAR2) IS
 SELECT DECODE(SU.NAME, 'PUBLIC', 'Y', 'N'),
        DECODE(NVL(SD.NODE,'-1'),'-1','N','Y'),
        SU.NAME, SO.NAME, SD.OWNER,SD.NAME
   FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
  WHERE SO.TYPE# = 5
    AND SO.NAME  LIKE SynPattern
    AND SU.USER# = SO.OWNER#
    AND SU.NAME  LIKE CidPattern
    AND SD.OBJ#  = SO.OBJ#
   ORDER BY SU.NAME, SO.NAME;

/*--------------------------------------------------------------------*
 *  Retrieve the attributes of a Synonym                              *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    SynName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    CidNum               OUT INTEGER,
    RefNum               OUT INTEGER,
    RefType              OUT INTEGER,
    OPublic              OUT CHAR,
    Owner                OUT VARCHAR2,
    SynmName             OUT VARCHAR2,
    RefOwner             OUT VARCHAR2,
    RefName              OUT VARCHAR2,
    RefLink              OUT VARCHAR2) is

 LclROwner   VARCHAR2(30);
 LclRName    VARCHAR2(30);
 LclLink     VARCHAR2(128);
 ObjCount    NUMBER;
 BEGIN
/*--------------------------------------------------------------------*
 *  Retrieve the data for the Synonym                                 *
 *--------------------------------------------------------------------*/
  SELECT COUNT(*)
    INTO ObjCount
    FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
   WHERE SO.TYPE# = 5
     AND SO.NAME  = SynName
     AND SU.USER# = SO.OWNER#
     AND SU.NAME  = CidName
     AND SD.OBJ#  = SO.OBJ#;

  IF (ObjCount = 1) THEN
    SELECT SO.OBJ#,SO.OWNER#,DECODE(SU.NAME,'PUBLIC','Y','N'),
           SU.NAME,SO.NAME,
           SD.OWNER,SD.NAME,SD.NODE
      INTO ObjectNum,CidNum,OPublic,
           Owner,SynmName,
           LclROwner,LclRName,LclLink
      FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
     WHERE SO.TYPE# = 5
       AND SO.NAME  = SynName
       AND SU.USER# = SO.OWNER#
       AND SU.NAME  = CidName
       AND SD.OBJ#  = SO.OBJ#;
  ELSE
    SELECT SO.OBJ#,SO.OWNER#,DECODE(SU.NAME,'PUBLIC','Y','N'),
           SU.NAME,SO.NAME,
           SD.OWNER,SD.NAME,SD.NODE
      INTO ObjectNum,CidNum,OPublic,
           Owner,SynmName,
           LclROwner,LclRName,LclLink
      FROM SYS.USER$ SU, SYS.OBJ$ SO, SYS.SYN$ SD
     WHERE SO.TYPE# = 5
       AND SO.NAME  = SynName
       AND SU.USER# = SO.OWNER#
       AND SU.NAME  = CidName
       AND SD.OBJ#  = SO.OBJ#
       AND SD.NODE IS NULL;
  END IF;

  RefOwner := LclROwner;
  RefName  := LclRName;

  IF (LclLink IS NULL) THEN
    RefLink := '~';
    SELECT MIN(RO.OBJ#),MIN(RO.TYPE#)
      INTO RefNum,RefType
      FROM SYS.OBJ$ RO, SYS.USER$ RU
     WHERE RO.TYPE# IN (2,4,5,6,7,8,9)
       AND RO.NAME  = LclRName
       AND RU.USER# = RO.OWNER#
       AND RU.NAME  = LclROwner;
  ELSE
    RefNum  := 0;
    RefType := 0;
    RefLink := LclLink;
  END IF;
 END PSTV0100_CSSGETSYNDATA;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonym List when Creator and           *
 *  Synonym are explicit references.                                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNLIST0
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    SynPattern            IN VARCHAR2,
    OPublic              OUT t_char,
    ORemote              OUT t_char,
    CidName              OUT t_ownername,
    SynName              OUT t_objectname,
    RefOwner             OUT t_ownername,
    RefName              OUT t_objectname) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT synlst0%ISOPEN THEN
        OPEN synlst0(CidPattern,SynPattern);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH synlst0 INTO OPublic(i),ORemote(i),
                           CidName(i),SynName(i),
                           RefOwner(i),RefName(i);
        IF synlst0%NOTFOUND THEN
           CLOSE synlst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSYNLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonym List when Creator name is a     *
 *  generic LIKE pattern and Synonym name is an explicit reference.   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNLIST1
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    SynPattern            IN VARCHAR2,
    OPublic              OUT t_char,
    ORemote              OUT t_char,
    CidName              OUT t_ownername,
    SynName              OUT t_objectname,
    RefOwner             OUT t_ownername,
    RefName              OUT t_objectname) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT synlst1%ISOPEN THEN
        OPEN synlst1(CidPattern,SynPattern);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH synlst1 INTO OPublic(i),ORemote(i),
                           CidName(i),SynName(i),
                           RefOwner(i),RefName(i);
        IF synlst1%NOTFOUND THEN
           CLOSE synlst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSYNLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonym List when Creator name is an    *
 *  explicit reference and Synonym name is a Generic LIKE pattern     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNLIST2
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    SynPattern            IN VARCHAR2,
    OPublic              OUT t_char,
    ORemote              OUT t_char,
    CidName              OUT t_ownername,
    SynName              OUT t_objectname,
    RefOwner             OUT t_ownername,
    RefName              OUT t_objectname) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT synlst2%ISOPEN THEN
        OPEN synlst2(CidPattern,SynPattern);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH synlst2 INTO OPublic(i),ORemote(i),
                           CidName(i),SynName(i),
                           RefOwner(i),RefName(i);
        IF synlst2%NOTFOUND THEN
           CLOSE synlst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSYNLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonym List when Creator name is a     *
 *  Generic LIKE pattern and Synonym name is a Generic LIKE pattern   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNLIST3
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    SynPattern            IN VARCHAR2,
    OPublic              OUT t_char,
    ORemote              OUT t_char,
    CidName              OUT t_ownername,
    SynName              OUT t_objectname,
    RefOwner             OUT t_ownername,
    RefName              OUT t_objectname) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT synlst3%ISOPEN THEN
        OPEN synlst3(CidPattern,SynPattern);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH synlst3 INTO OPublic(i),ORemote(i),
                           CidName(i),SynName(i),
                           RefOwner(i),RefName(i);
        IF synlst3%NOTFOUND THEN
           CLOSE synlst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSYNLIST3;
END PSTO01V0100_CSSSYNONYM;
