/*--------------------------------------------------------------------*
 *  Oracle 11.1 package body Catalog Services Indexes                 *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO11V0100_CSSINDEX AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Index entries                              *
 *  N.B ignore BITMAP JOIN index entries                              *
 *--------------------------------------------------------------------*/
 CURSOR ikey (ObjectNumIn INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        IC.POS#,
        X.OBJ#,
        X.PROPERTY,
        C.PROPERTY,
        NVL(C.DEFLENGTH,0),
        C.NAME,
        C.DEFAULT$,
        bitand(X.FLAGS,2147483647),
        (select OT.type from SYS.OPQTYPE$ OT
         where OT.OBJ#=ObjectNumIn AND OT.INTCOL# = IC.INTCOL#)
   FROM SYS.IND$ X,
        SYS.OBJ$ O,
        SYS.USER$ U,
        SYS.ICOL$ IC,
        SYS.COL$ C
	WHERE X.BO#    = ObjectNumIn
    AND (BITAND(X.PROPERTY,1024) = 0)        /* Not BITMAP JOIN INDEX */
    AND O.OBJ#   = X.OBJ#
    AND U.USER#  = O.OWNER#
    AND IC.OBJ#  = X.OBJ#
    AND IC.BO#   = ObjectNumIn
    AND C.INTCOL# = IC.INTCOL#
    AND C.OBJ#   = ObjectNumIn
     ORDER BY U.NAME, O.NAME, IC.POS#;
 
/*--------------------------------------------------------------------*
 *  Cursor used to count BITMAP JOIN Index elelements                 *
 *  N.B ignore all but BITMAP JOIN index entries                      *
 *--------------------------------------------------------------------*/
 CURSOR jcnt (ObjectNumIn INTEGER) IS
 SELECT I.OBJ#,COUNT(IC.COL#),'C'
   FROM SYS.IND$ I, SYS.ICOL$ IC
  WHERE (BITAND(I.PROPERTY,1024) = 1024)
    AND I.BO# = ObjectNumIn
    AND IC.OBJ# = I.OBJ#
  GROUP BY I.OBJ#
 UNION ALL
 SELECT I.OBJ#,COUNT(JP.OBJ#),'P'
  FROM SYS.IND$ I, SYS.JIJOIN$ JP
 WHERE JP.OBJ# = I.OBJ#
   AND I.BO# = ObjectNumIn
 GROUP BY I.OBJ#
ORDER BY 1,3;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire BITMAP JOIN Columns for 1 Index            *
 *  N.B ObjectNumIn is the BITMAP JOIN INDEX Object Id                *
 *--------------------------------------------------------------------*/
 CURSOR jkey (ObjectNumIn INTEGER) IS
 SELECT U.NAME,
        O.NAME,
        JU.NAME,
        JO.NAME,
        IC.POS#,
        X.OBJ#,
        C.PROPERTY,
        C.NAME
   FROM SYS.IND$ X,
        SYS.OBJ$ O,
        SYS.USER$ U,
        SYS.OBJ$ JO,
        SYS.USER$ JU,
        SYS.ICOL$ IC,
        SYS.COL$ C
  WHERE X.OBJ#   = ObjectNumIn
    AND (BITAND(X.PROPERTY,1024) = 1024)     /* BITMAP JOIN INDEX */
    AND O.OBJ#   = X.OBJ#
    AND U.USER#  = O.OWNER#
    AND IC.OBJ#  = X.OBJ#
    AND JO.OBJ#  = IC.BO#                    /* May not be ObjectNumIn */
    AND JU.USER# = JO.OWNER#
    AND C.OBJ#   = JO.OBJ#
    AND C.INTCOL# = IC.SPARE2
  ORDER BY U.NAME, O.NAME, IC.POS#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire BITMAP JOIN Predicates for 1 Index         *
 *  N.B ObjectNumIn is the BITMAP JOIN INDEX Object Id                *
 *--------------------------------------------------------------------*/
 CURSOR jpkey (ObjectNumIn INTEGER) IS
 SELECT T1U.NAME,
        T1O.NAME,
        T1C.NAME,
        T2U.NAME,
        T2O.NAME,
        T2C.NAME,
        JP.JOINOP,
        JP.TAB1INST#,
        JP.TAB2INST#
   FROM SYS.OBJ$ T1O,
        SYS.USER$ T1U,
        SYS.COL$ T1C,
        SYS.OBJ$ T2O,
        SYS.USER$ T2U,
        SYS.COL$ T2C,
        SYS.JIJOIN$ JP
  WHERE JP.OBJ#      = ObjectNumIn
    AND T1O.OBJ#     = JP.TAB1OBJ#
    AND T1U.USER#    = T1O.OWNER#
    AND T2O.OBJ#     = JP.TAB2OBJ#
    AND T2U.USER#    = T2O.OWNER#
    AND T1C.OBJ#     = T1O.OBJ#
    AND T1C.INTCOL#  = JP.TAB1COL#
    AND T2C.OBJ#     = T2O.OBJ#
    AND T2C.INTCOL#  = JP.TAB2COL#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire UnqRel entries related to Table Indexes    *
 *--------------------------------------------------------------------*/
 CURSOR ukey (ObjectNumIn INTEGER) IS
 SELECT CO.NAME,
        CD.CON#,
        CD.ENABLED,
        'ColName',
        0,
        decode(bitand(CD.DEFER,1),1,'Y','N'),
        decode(bitand(CD.DEFER,2),2,'D','I'),
        decode(bitand(CD.DEFER,4),4,'Y','N')
   FROM SYS.CDEF$ CD, SYS.CON$ CO
  WHERE CD.OBJ# = ObjectNumIn
    AND CD.TYPE# = 3
    AND CD.CON# = CO.CON#
    AND CD.ENABLED IS NOT NULL
 UNION ALL
 SELECT CO.NAME,
        CD.CON#,
        0,
        CL.NAME,
        CC.POS#,
        decode(bitand(CD.DEFER,1),1,'Y','N'),
        decode(bitand(CD.DEFER,2),2,'D','I'),
        decode(bitand(CD.DEFER,4),4,'Y','N')
   FROM SYS.CON$ CO, SYS.CDEF$ CD, SYS.COL$ CL, SYS.CCOL$ CC
  WHERE CD.OBJ# = ObjectNumIn
    AND CD.TYPE# = 3
    AND CD.ENABLED IS NULL
    AND CO.CON# = CD.CON#
    AND CC.CON# = CD.CON#
    AND CC.OBJ# = ObjectNumIn
    AND CL.OBJ# = ObjectNumIn
    AND CL.COL# = CC.COL#
  ORDER BY 2,5;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Partitioned Index Key Columns              *
 *--------------------------------------------------------------------*/
 CURSOR pkey (ObjectNumIn INTEGER) IS
 SELECT PC.COL#,
        PC.POS#
        FROM SYS.PARTCOL$ PC
        WHERE PC.OBJ# = ObjectNumIn;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Partitioned Index Slot records             *
 *--------------------------------------------------------------------*/
 CURSOR skey (ObjectNumIn INTEGER) IS
 SELECT IP.OBJ#,
        IP.PART#,
        IP.PCTFREE$,
        IP.INITRANS,
        IP.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        NVL(TS.BLOCKSIZE,0),
        IP.HIBOUNDLEN,
        decode(mod(trunc(ip.flags / 4), 2), 0, 'Y', 'N'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(ip.flags,1024), 1024, 'Y', 'N'),
        I.SUBNAME,
        TS.NAME,
        IP.HIBOUNDVAL
        FROM SYS.OBJ$ I, SYS.INDPART$ IP, SYS.TS$ TS, SYS.SEG$ S
        WHERE IP.BO# = ObjectNumIn
         AND  IP.OBJ# = I.OBJ#
         AND  IP.TS# = TS.TS#
         AND  IP.FILE# = S.FILE# (+)
         AND  IP.BLOCK# = S.BLOCK# (+)
         AND  IP.TS#    = S.TS# (+)
         ORDER BY IP.PART#;

/*--------------------------------------------------------------------*
 * Cursor used to acquire COMPOSITE Partitioned Index Slot records    *
 *--------------------------------------------------------------------*/
 CURSOR ckey (ObjectNumIn INTEGER) IS
  SELECT IC.OBJ#,
        IC.PART#,
        IC.DEFPCTFREE,
        IC.DEFINITRANS,
        IC.DEFMAXTRANS,
        NVL(IC.DEFINIEXTS,0),
        NVL(IC.DEFEXTSIZE,0),
        IC.DEFMINEXTS,
        IC.DEFMAXEXTS,
        IC.DEFEXTPCT,
        IC.DEFLISTS,
        NVL(TS.BLOCKSIZE,0),
        IC.HIBOUNDLEN,
        decode(mod(trunc(ic.flags / 4), 2), 0, 'Y', 'N'),
        decode(IC.DEFBUFPOOL, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(ic.flags,1024), 1024, 'Y', 'N'),
        T.SUBNAME,
        TS.NAME,
        IC.HIBOUNDVAL,
        IC.SUBPARTCNT
        FROM SYS.OBJ$ T, SYS.INDCOMPART$ IC, SYS.TS$ TS
        WHERE IC.BO# = ObjectNumIn
         AND  IC.OBJ# = T.OBJ#
         AND  IC.DEFTS# = TS.TS# (+)
         ORDER BY IC.PART#;

/*--------------------------------------------------------------------*
 * Cursor used to acquire Partitioned Index SubSlot records           *
 *--------------------------------------------------------------------*/
 CURSOR sskey (ObjectNumIn INTEGER) IS
 SELECT IP.OBJ#,
        IP.SUBPART#,
        IP.PCTFREE$,
        IP.INITRANS,
        IP.MAXTRANS,
        NVL(S.INIEXTS,0),
        NVL(S.EXTSIZE,0),
        S.MINEXTS,
        S.MAXEXTS,
        S.EXTPCT,
        S.LISTS,
        S.GROUPS,
        NVL(TS.BLOCKSIZE,0),
        decode(mod(trunc(ip.flags / 4), 2), 0, 'Y', 'N'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        T.SUBNAME,
        TS.NAME
        FROM SYS.OBJ$ T, SYS.INDSUBPART$ IP, SYS.TS$ TS, SYS.SEG$ S
        WHERE IP.POBJ# = ObjectNumIn
         AND  IP.OBJ# = T.OBJ#
         AND  IP.TS# = TS.TS#
         AND  IP.FILE# = S.FILE# (+)
         AND  IP.BLOCK# = S.BLOCK# (+)
         AND  IP.TS#    = S.TS# (+)
         ORDER BY IP.SUBPART#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Oracle Index entries                       *
 *  All tables included.                                              *
 *--------------------------------------------------------------------*/
 CURSOR ilist0 IS
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          0
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND NOT EXISTS ( select cd.con#
                         from sys.cdef$ cd
                        where cd.obj# = X.BO#
                          and cd.type# = 2)
 UNION ALL
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          CD.TYPE#
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C,
          SYS.CDEF$ CD
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND CD.OBJ#  = X.BO#
      AND CD.TYPE# = 2
    ORDER BY 1,2,3,4,9;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Oracle Index entries                       *
 *  Exclude System Tables                                             *
 *--------------------------------------------------------------------*/
 CURSOR ilist1 IS
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          0
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND U.NAME   != 'SYS'
      AND IU.NAME   != 'SYS'
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND NOT EXISTS ( select cd.con#
                         from sys.cdef$ cd
                        where cd.obj# = X.BO#
                          and cd.type# = 2)
     UNION ALL
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          CD.TYPE#
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C,
          SYS.CDEF$ CD
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND U.NAME   != 'SYS'
      AND IU.NAME   != 'SYS'
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND CD.OBJ#  = X.BO#
      AND CD.TYPE# = 2
    ORDER BY 1,2,3,4,9;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Oracle Index entries                       *
 *  Exclude Tables with Primary Keys                                  *
 *--------------------------------------------------------------------*/
 CURSOR ilist2 IS
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          0
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND NOT EXISTS ( select cd.con#
                         from sys.cdef$ cd
                        where cd.obj# = X.BO#
                         and cd.type# = 2)
    ORDER BY 1,2,3,4,9;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Oracle Index entries                       *
 *  Exclude System Tables and Tables with Primary Keys                *
 *--------------------------------------------------------------------*/
 CURSOR ilist3 IS
   SELECT U.NAME,
          O.NAME,
          IU.NAME,
          I.NAME,
          X.PROPERTY,
          C.PROPERTY,
          C.NAME,
          X.COLS,
          IC.POS#,
          0
     FROM SYS.IND$ X,
          SYS.OBJ$ O,
          SYS.OBJ$ I,
          SYS.USER$ U,
          SYS.USER$ IU,
          SYS.ICOL$ IC,
          SYS.COL$ C
    WHERE X.TYPE#  < 3
      AND (BITAND(X.PROPERTY,1024) = 0)  /* Exclude BITMAP JOIN */
      AND I.OBJ#   = X.OBJ#
      AND O.OBJ#   = X.BO#
      AND U.USER#  = O.OWNER#
      AND IU.USER#  = I.OWNER#
      AND U.NAME   != 'SYS'
      AND IU.NAME   != 'SYS'
      AND IC.OBJ#  = X.OBJ#
      AND IC.BO#   = X.BO#
      AND C.INTCOL# = IC.INTCOL#
      AND C.OBJ#   = X.BO#
      AND NOT EXISTS ( select cd.con#
                         from sys.cdef$ cd
                        where cd.obj# = X.BO#
                          and cd.type# = 2)
    ORDER BY 1,2,3,4,9;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Normal Index entries                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETINDEX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxCid               OUT t_creator,
    IdxName              OUT t_idxname,
    KeyPos               OUT t_idxbbyte,
    IdxObjId             OUT t_idxobj,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColDefLen            OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColDef               OUT t_idxcdef,
    IdxFlags             OUT t_idxflags,
    IdxType              OUT t_idxtype) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ikey%ISOPEN THEN
        OPEN ikey(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ikey INTO IdxCid(i),
                        IdxName(i),
                        KeyPos(i),
                        IdxObjId(i),
                        IdxProp(i),
                        ColProp(i),
                        ColDefLen(i),
                        ColName(i),
                        ColDef(i),
				IdxFlags(i),
                        IdxType(i);
        IF ikey%NOTFOUND THEN
           CLOSE ikey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETINDEX;

/*--------------------------------------------------------------------*
 *  Procedure used to count BITMAP JOIN Index entries                 *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJCNT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxObjId             OUT t_idxobj,
    RecCnt               OUT t_idxbbyte,
    Type                 OUT t_idxcbyte) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT jcnt%ISOPEN THEN
        OPEN jcnt(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH jcnt INTO IdxObjId(i),
                        RecCnt(i),
                        Type(i);
        IF jcnt%NOTFOUND THEN
           CLOSE jcnt;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETBMJCNT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire BITMAP JOIN Index entries               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJIDX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxCid               OUT t_creator,
    IdxName              OUT t_idxname,
    JtblCid              OUT t_creator,
    JtblName             OUT t_idxname,
    IdxObjId             OUT t_idxobj,
    KeyPos               OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT jkey%ISOPEN THEN
        OPEN jkey(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH jkey INTO IdxCid(i),
                        IdxName(i),
                        JtblCid(i),
                        JtblName(i),
                        IdxObjId(i),
                        KeyPos(i),
                        ColProp(i),
                        ColName(i);
        IF jkey%NOTFOUND THEN
           CLOSE jkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETBMJIDX;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire BITMAP JOIN Predicates                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJCOL
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    Tbl1Cid              OUT t_creator,
    Tbl1Name             OUT t_idxname,
    Tbl1Col              OUT t_colname,
    Tbl2Cid              OUT t_creator,
    Tbl2Name             OUT t_idxname,
    Tbl2Col              OUT t_colname,
    JoinOper             OUT t_idxbbyte,
    Tbl1Inst             OUT t_idxbbyte,
    Tbl2Inst             OUT t_idxbbyte) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT jpkey%ISOPEN THEN
        OPEN jpkey(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH jpkey INTO Tbl1Cid(i),
                        Tbl1Name(i),
                        Tbl1Col(i),
                        Tbl2Cid(i),
                        Tbl2Name(i),
                        Tbl2Col(i),
                        JoinOper(i),
                        Tbl1Inst(i),
                        Tbl2Inst(i);
        IF jpkey%NOTFOUND THEN
           CLOSE jpkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETBMJCOL;

/*--------------------------------------------------------------------*
 *  Procedure to acquire Unique Rel Index Entries                     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETUNQREL
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ConName              OUT t_conname,
    ConId                OUT t_idxbbyte,
    Enabled              OUT t_idxbbyte,
    ColName              OUT t_colname,
    KeyPos               OUT t_idxbbyte,
    Deferable            OUT t_idxcbyte,
    DeferInit            OUT t_idxcbyte,
    Validated            OUT t_idxcbyte) is
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ukey%ISOPEN THEN
        OPEN ukey(ObjectNumIn);
     END IF;
/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ukey INTO ConName(i),
                        ConId(i),
                        Enabled(i),
                        ColName(i),
                        KeyPos(i),
                        Deferable(i),
                        DeferInit(i),
                        Validated(i);
        IF ukey%NOTFOUND THEN
           CLOSE ukey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETUNQREL;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index data                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLINDEX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    ParaDegree           OUT INTEGER,
    ParaInst             OUT INTEGER,
    CompCols             OUT INTEGER,
    LogFlag              OUT CHAR,
    PartFlag             OUT CHAR,
    Type                 OUT CHAR,
    BPool                OUT CHAR,
    RevFlag              OUT CHAR,
    TSName               OUT VARCHAR2) is
 BEGIN
 SELECT decode(bitand(i.property,2),0,I.PCTFREE$,0),
        decode(bitand(i.property,2),0,I.INITRANS,0),
        decode(bitand(i.property,2),0,I.MAXTRANS,0),
        decode(bitand(i.property,2),0,NVL(S.INIEXTS,0),0),
        decode(bitand(i.property,2),0,NVL(S.EXTSIZE,0),0),
        decode(bitand(i.property,2),0,S.MINEXTS,0),
        decode(bitand(i.property,2),0,S.MAXEXTS,0),
        decode(bitand(i.property,2),0,S.EXTPCT,0),
        decode(bitand(i.property,2),0,S.LISTS,0),
        decode(bitand(i.property,2),0,S.GROUPS,0),
        NVL(TS.BLOCKSIZE,0),
        NVL(I.DEGREE,0),
        NVL(I.INSTANCES,0),
        decode(bitand(i.flags,32), 32, i.spare2, 0),
        decode(bitand(i.property,2), 2, 'X',
               decode(bitand(i.flags,4), 0, 'Y', 'N')),
        decode(bitand(i.property,2), 2, 'Y', 'N'),
        decode(i.type#, 1, 'N', 2, 'B', 3, 'C', 4, 'I',
                        5, 'O', 6, 'S', 7, 'A', 8, 'L', 9, 'M', 'U'),
        decode(s.cachehint, 0, 'D', 1, 'K', 2, 'R', 'U'),
        decode(bitand(i.property,4), 4, 'Y', 'N'),
        decode(bitand(i.property,2), 0, TS.NAME, null)
        INTO PctgFree,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             Groups,
             TsBlkSize,
             ParaDegree,
             ParaInst,
             CompCols,
             LogFlag,
             PartFlag,
             Type,
             BPool,
             RevFlag,
             TSName
        FROM SYS.IND$ I, SYS.TS$ TS, SYS.SEG$ S
        WHERE I.OBJ# = ObjectNumIn
         AND  I.TS# = TS.TS# (+)
         AND  i.FILE# = S.FILE# (+)
         AND  I.BLOCK# = S.BLOCK# (+)
         AND  I.TS#    = S.TS# (+);
 END PSTV0100_CSSDDLINDEX;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index PartBase from PARTOBJ$,TS$    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartCnt              OUT INTEGER,
    PartKeyCnt           OUT INTEGER,
    PctgFree             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    PartType             OUT INTEGER,
    SubPartType          OUT INTEGER,
    SubPartKeyCols       OUT INTEGER,
    DefSubPartCnt        OUT INTEGER,
    PartLoc              OUT CHAR,
    PartAlign            OUT CHAR,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2) is

 BEGIN
 SELECT PO.PARTCNT,
        PO.PARTKEYCOLS,
        PO.DEFPCTFREE,
        PO.DEFINITRANS,
        PO.DEFMAXTRANS,
        NVL(PO.DEFTINIEXTS,0),
        NVL(PO.DEFEXTSIZE,0),
        NVL(PO.DEFMINEXTS,0),
        NVL(PO.DEFMAXEXTS,0),
        NVL(PO.DEFEXTPCT,0),
        PO.DEFLISTS,
        NVL(TS.BLOCKSIZE,0),
        PO.PARTTYPE,
        mod(PO.SPARE2, 256),
        floor(mod(PO.SPARE2,65536) / 256),
        floor(PO.SPARE2 / 65536),
        decode(bitand(po.flags,1), 1, 'L', 'G'),
        decode(bitand(po.flags,2), 2, 'P', 'N'),
        decode(po.deflogging, 0, 'X', 1, 'Y', 2, 'N', 'U'),
        decode(po.spare1, 0, 'D', 1, 'K', 2, 'R', 'U'),
        TS.NAME
        INTO PartCnt,
             PartKeyCnt,
             PctgFree,
             InitTran,
             MaxTran,
             InitExt,
             NextExt,
             MinExt,
             MaxExt,
             PctIncr,
             Lists,
             TsBlkSize,
             PartType,
             SubPartType,
             SubPartKeyCols,
             DefSubPartCnt,
             PartLoc,
             PartAlign,
             LogFlag,
             BPool,
             TSName
        FROM SYS.PARTOBJ$ PO, SYS.TS$ TS
        WHERE PO.OBJ# = ObjectNumIn
         AND  PO.DEFTS# = TS.TS# (+);

 END PSTV0100_CSSDDLIDXPARTBASE;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index PartKeys from PARTCOL$        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT pkey%ISOPEN THEN
        OPEN pkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH pkey INTO KeyNum(i),
                        KeyPos(i);
        IF pkey%NOTFOUND THEN
           CLOSE pkey;
           EXIT;
        END IF;
     END LOOP;

 END PSTV0100_CSSDDLIDXPARTKEYS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index Partitions OBJ$,INDPART$, etc *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_idxbbyte,
    PartNum              OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    HiBndLen             OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartComp             OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT skey%ISOPEN THEN
        OPEN skey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH skey INTO PartObjNum(i),
                        PartNum(i),
                        PctGfree(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        TsBlkSize(i),
                        HiBndLen(i),
                        LogFlag(i),
                        BPool(i),
                        PartComp(i),
                        PartName(i),
                        TSName(i),
                        HiBndVal(i);
        IF skey%NOTFOUND THEN
           CLOSE skey;
           EXIT;
        END IF;
        /* Optim doesn't need the actual catalog value for PartNum.     RTC51183*/
        /* To prevent a possible ORA-01455 overflow error with very     RTC51183*/
        /* values in this column, just pass back the loop variable.     RTC51183*/
        PartNum(i) := i;                                              /*RTC51183*/
     END LOOP;
 END PSTV0100_CSSDDLIDXPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire COMPOSITE Index Part INDCOMPART$, etc   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXCOMPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_idxbbyte,
    PartNum              OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    HiBndLen             OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartComp             OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound,
    SubPartCnt           OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ckey%ISOPEN THEN
        OPEN ckey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ckey INTO PartObjNum(i),
                        PartNum(i),
                        PctGfree(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        TsBlkSize(i),
                        HiBndLen(i),
                        LogFlag(i),
                        BPool(i),
                        PartComp(i),
                        PartName(i),
                        TSName(i),
                        HiBndVal(i),
                        SubPartCnt(i);
        IF ckey%NOTFOUND THEN
           CLOSE ckey;
           EXIT;
        END IF;
        /* Optim doesn't need the actual catalog value for PartNum.     RTC51183*/
        /* To prevent a possible ORA-01455 overflow error with very     RTC51183*/
        /* values in this column, just pass back the loop variable.     RTC51183*/
        PartNum(i) := i;                                              /*RTC51183*/
     END LOOP;
 END PSTV0100_CSSDDLIDXCOMPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Index SubPartitions OBJ$,INDSUBPART$ etc*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXSUBPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SubPartObjNum        OUT t_idxbbyte,
    SubPartNum           OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    Groups               OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT sskey%ISOPEN THEN
        OPEN sskey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number of records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH sskey INTO SubPartObjNum(i),
                        SubPartNum(i),
                        PctGFree(i),
                        InitTran(i),
                        MaxTran(i),
                        InitExt(i),
                        NextExt(i),
                        MinExt(i),
                        MaxExt(i),
                        PctIncr(i),
                        Lists(i),
                        Groups(i),
                        TsBlkSize(i),
                        LogFlag(i),
                        BPool(i),
                        PartName(i),
                        TSName(i);
        IF sskey%NOTFOUND THEN
           CLOSE sskey;
           EXIT;
        END IF;
        /* Optim doesn't need the actual catalog value for SubPartNum.  RTC51183*/
        /* To prevent a possible ORA-01455 overflow error with very     RTC51183*/
        /* values in this column, just pass back the loop variable.     RTC51183*/
        SubPartNum(i) := i;                                           /*RTC51183*/
     END LOOP;
 END PSTV0100_CSSDDLIDXSUBPARTSLOT;

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List  USER$,OBJ$,COL$,IND$,ICOL$,CDEF$   *
 *  Include both System and Primary Key Indexes                       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST0
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ilist0%ISOPEN THEN
        OPEN ilist0;
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ilist0 INTO IdxCid(i),
                        IdxTable(i),
                        IdxDef(i),
                        IdxName(i),
                        IdxProp(i),
                        ColProp(i),
                        ColName(i),
                        ColCnt(i),
                        KeyPos(i),
                        PKFlag(i);
        IF ilist0%NOTFOUND THEN
           CLOSE ilist0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSINDEXLIST0;

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List  USER$,OBJ$,COL$,IND$,ICOL$,CDEF$   *
 *  Exclude System Tables                                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST1
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ilist1%ISOPEN THEN
        OPEN ilist1;
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ilist1 INTO IdxCid(i),
                        IdxTable(i),
                        IdxDef(i),
                        IdxName(i),
                        IdxProp(i),
                        ColProp(i),
                        ColName(i),
                        ColCnt(i),
                        KeyPos(i),
                        PKFlag(i);
        IF ilist1%NOTFOUND THEN
           CLOSE ilist1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSINDEXLIST1;

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List  USER$,OBJ$,COL$,IND$,ICOL$,CDEF$   *
 *  Exclude Tables with Primary Keys                                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST2
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ilist2%ISOPEN THEN
        OPEN ilist2;
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ilist2 INTO IdxCid(i),
                        IdxTable(i),
                        IdxDef(i),
                        IdxName(i),
                        IdxProp(i),
                        ColProp(i),
                        ColName(i),
                        ColCnt(i),
                        KeyPos(i),
                        PKFlag(i);
        IF ilist2%NOTFOUND THEN
           CLOSE ilist2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSINDEXLIST2;

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List  USER$,OBJ$,COL$,IND$,ICOL$,CDEF$   *
 *  Exclude System Tables and Tables with Primary Keys                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST3
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT ilist3%ISOPEN THEN
        OPEN ilist3;
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH ilist3 INTO IdxCid(i),
                        IdxTable(i),
                        IdxDef(i),
                        IdxName(i),
                        IdxProp(i),
                        ColProp(i),
                        ColName(i),
                        ColCnt(i),
                        KeyPos(i),
                        PKFlag(i);
        IF ilist3%NOTFOUND THEN
           CLOSE ilist3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSINDEXLIST3;
 
##/*--------------------------------------------------------------------*
## *  Procedure used to acquire XML Index Parameter values                *
## *--------------------------------------------------------------------*/
## PROCEDURE PSTV0100_CSSXMLINDEX
##   (RowsToGet             IN INTEGER,
##    CreatorNameIn         IN VARCHAR2,
##    TableNameIn           IN VARCHAR2,
##    IdxNameIn             IN VARCHAR2,
##    Paths                OUT VARCHAR2,
##    NSMap                OUT VARCHAR2,
##    Async                OUT VARCHAR2,
##    JobName              OUT VARCHAR2,
##    Interval             OUT VARCHAR2,
##    ExclIncl             OUT VARCHAR2,
##    PathTblObjNum        OUT INTEGER,
##    PathTblName          OUT VARCHAR2,
##    PathIdxObjNum        OUT INTEGER,
##    PathIdxName          OUT VARCHAR2,
##    ValueIdxObjNum       OUT INTEGER,
##    ValueIdxName         OUT VARCHAR2,
##    OrderIdxObjNum       OUT INTEGER,
##    OrderIdxName         OUT VARCHAR2) is
## 
## BEGIN
##     SELECT nvl2(extract(PARAMETERS, '/parameters/paths/path'),
##                 extract(PARAMETERS, '/parameters/paths/path').getStringVal(),NULL),
##            nvl2(extractvalue(PARAMETERS, '/parameters/paths/nsmap'),
##                 extractvalue(PARAMETERS, '/parameters/paths/nsmap'),NULL),
##            nvl2(extract(PARAMETERS, '/parameters/async/job/name'),
##                 extract(PARAMETERS, '/parameters/async/job/name').getStringVal(),NULL),
##            nvl2(extractvalue(PARAMETERS, '/parameters/async/job/interval'),
##                 extractvalue(PARAMETERS, '/parameters/async/job/interval'),NULL),
##            PATH_TABLE_NAME,
##            EX_OR_INCLUDE,
##            ASYNC     
##       INTO Paths, 
##            NSMap,
##            JobName,
##            Interval,
##            PathTblName,
##            ExclIncl,
##            Async    
##       FROM ALL_XML_INDEXES
##      WHERE INDEX_OWNER = CreatorNameIn
##        AND TABLE_NAME  = TableNameIn
##        AND INDEX_NAME  = IdxNameIn;
##
##     SELECT O.OBJ#
##       INTO PathTblObjNum 
##       FROM SYS.USER$ U, SYS.OBJ$ O
##      WHERE U.NAME = CreatorNameIn
##        AND O.NAME = PathTblName
##        AND O.OWNER# = U.USER#
##        AND O.TYPE# = 2;
##
##     SELECT INDEX_NAME
##       INTO PathIdxName   
##       FROM USER_IND_COLUMNS
##      WHERE TABLE_NAME = PathTblName AND COLUMN_NAME='PATHID';
##
##     SELECT O.OBJ#
##       INTO PathIdxObjNum 
##       FROM SYS.USER$ U, SYS.OBJ$ O
##      WHERE U.NAME   = CreatorNameIn
##        AND O.NAME   = PathIdxName
##        AND O.OWNER# = U.USER#
##        AND O.TYPE#  = 1;
##
##     SELECT INDEX_NAME
##       INTO ValueIdxName   
##       FROM USER_IND_COLUMNS
##       WHERE TABLE_NAME = PathTblName AND COLUMN_NAME='VALUE';
##
##     SELECT O.OBJ#
##       INTO ValueIdxObjNum 
##       FROM SYS.USER$ U, SYS.OBJ$ O
##      WHERE U.NAME   = CreatorNameIn
##        AND O.NAME   = ValueIdxName
##        AND O.OWNER# = U.USER#
##        AND O.TYPE#  = 1;
##
##     SELECT INDEX_NAME
##       INTO OrderIdxName   
##       FROM USER_IND_COLUMNS
##      WHERE TABLE_NAME = PathTblName AND COLUMN_NAME='ORDER_KEY';
##
##     SELECT O.OBJ#
##       INTO OrderIdxObjNum 
##       FROM SYS.USER$ U, SYS.OBJ$ O
##      WHERE U.NAME   = CreatorNameIn
##        AND O.NAME   = OrderIdxName
##        AND O.OWNER# = U.USER#
##        AND O.TYPE#  = 1;
##
## END PSTV0100_CSSXMLINDEX;

 
END PSTO11V0100_CSSINDEX;
