/*
    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Creator Names          *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO1IV0100_CSSCID AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Creator Name List when Creator is Explicit *
 *--------------------------------------------------------------------*/
 CURSOR clst0 (CidPatternIn VARCHAR2) IS
 SELECT DISTINCT U.USERNAME, U.USER_ID
            FROM SYS.DBA_USERS U, SYS.OBJ$ O
           WHERE O.TYPE# IN(2,4)
             AND O.OID$ IS NULL
             AND U.USER_ID = O.OWNER#
             AND U.USERNAME = CidPatternIn
           ORDER BY U.USERNAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Creator Name List when Creator is Generic  *
 *--------------------------------------------------------------------*/
 CURSOR clst1 (CidPatternIn VARCHAR2) IS
 SELECT DISTINCT U.USERNAME, U.USER_ID
            FROM SYS.DBA_USERS U, SYS.OBJ$ O
           WHERE O.TYPE# IN(2,4)
             AND O.OID$ IS NULL
             AND U.USER_ID = O.OWNER#
             AND U.USERNAME LIKE CidPatternIn
           ORDER BY U.USERNAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Creator Name List for explicit names    *
 *  are explicit references.                                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCIDLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    CreatorNum           OUT t_creatornum) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT clst0%ISOPEN THEN
        OPEN clst0(CidPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH clst0 INTO CreatorName(i),CreatorNum(i);
        IF clst0%NOTFOUND THEN
           CLOSE clst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCIDLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Creator Name List when name is a        *
 *  generic LIKE pattern.                                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCIDLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    CreatorNum           OUT t_creatornum) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT clst1%ISOPEN THEN
        OPEN clst1(CidPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH clst1 INTO CreatorName(i),CreatorNum(i);
        IF clst1%NOTFOUND THEN
           CLOSE clst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCIDLIST1;
END PSTO1IV0100_CSSCID;
