/*--------------------------------------------------------------------*
 *  Oracle11g package body Catalog Services Columns                   *
 *  WI 46805 Assign OBJECT to UNDEFINED                               *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO1IV0100_CSSCOLUMN AS
/*--------------------------------------------------------------------*
 *  Cursor used to acquire basic column attributes                    *
 *--------------------------------------------------------------------*/
 CURSOR crec (ObjectNumIn INTEGER) IS
 SELECT C.LENGTH,
        C.COL#,
        NVL(C.DEFLENGTH,0),
        NVL(C.PRECISION#,0),
        NVL(C.SCALE,0),
        DECODE(SIGN(C.NULL$),-1, 'D', 0, 'Y', 'N'),
        decode(c.type#, 1, decode(c.charsetform, 2, 'NVARCHAR2', 'VARCHAR2'),
                        2, decode(c.scale, null,
                                  decode(c.precision#, null, 'NUMBER', 'FLOAT'),
                                  'NUMBER'),
                        8, 'LONG',
                        9, decode(c.charsetform, 2, 'NVARCHAR', 'VARCHAR'),
                        12, 'DATE',
                        23, 'RAW',
                        24, 'LONG RAW',
                        58, 'XML',
                        69, 'ROWID',
                        96, decode(c.charsetform, 2, 'NCHAR', 'CHAR'),
                        100, 'BFLOAT',
                        101, 'BDOUBLE',
                        105, 'MLSLABEL',
                        106, 'MLSLABEL',
                        110, 'REF',
                        111, 'REF',
                        112, decode(c.charsetform, 2, 'NCLOB', 'CLOB'),
                        113, 'BLOB',
                        114, 'BFILE',
                        115, 'CFILE',
                     -- 121, 'OBJECT',
                        122, 'TABLE',
                        123, 'VARRAY',
                        178, 'TIME',
                        179, 'TIME_TZ',
                        180, 'TSTMP',
                        181, 'TSTMP_TZ',
                        182, 'INTVL_YY',
                        183, 'INTVL_DD',
                        208, 'UROWID',
                        231, 'TSTMP_LZ',
                        'UNDEFINED'),
        C.NAME,
        decode(bitand(C.PROPERTY,8388608), 8388608, C.SPARE3, 0),
        bitand(C.PROPERTY,2147483647)
       FROM SYS.COL$ C
       WHERE C.OBJ# = ObjectNumIn
         AND C.COL# > 0
      -- AND C.TYPE# <> 121
         AND bitand(C.PROPERTY,32) = 0
       ORDER BY C.COL#;
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Cluster Table Column identifiers           *
 *--------------------------------------------------------------------*/
 CURSOR cseg (ObjectNumIn  INTEGER,
              ClusterNumIn INTEGER) IS
 SELECT TC.COL#,
        CC.COL#
   FROM SYS.COL$ CC, SYS.COL$ TC
  WHERE TC.OBJ# = ObjectNumIn
    AND CC.OBJ# = ClusterNumIn
    AND TC.SEGCOL# = CC.SEGCOL#
  ORDER BY TC.COL#;
/*--------------------------------------------------------------------*
 *  Cursor used to acquire column NOT NULL constraint names           *
 *--------------------------------------------------------------------*/
 CURSOR cnul (ObjectNumIn INTEGER) IS
 SELECT CC.COL#, CO.NAME
       FROM SYS.CON$ CO, SYS.CDEF$ CD, SYS.CCOL$ CC
       WHERE CD.OBJ# = ObjectNumIn
         AND CD.TYPE# = 7
         AND BITAND(CD.DEFER,8) = 0
         AND CO.CON# = CD.CON#
         AND CC.CON# = CD.CON#
       ORDER BY CC.COL#;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Column data from COL$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColLen               OUT t_columnlength,
    ColNum               OUT t_columnnumber,
    DefValLen            OUT t_defaultvaluelength,
    NumPrec              OUT t_numericprecision,
    NumScale             OUT t_numericscale,
    NullMode             OUT t_nullmode,
    DataType             OUT t_datatype,
    ColName              OUT t_columnname,
    CharLen              OUT t_columnlength,
    Properties           OUT t_prop) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT crec%ISOPEN THEN
        OPEN crec(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH crec INTO ColLen(i), ColNum(i), DefValLen(i),
              NumPrec(i), NumScale(i), NullMode(i),
              DataType(i), ColName(i), CharLen(i), Properties(i);
        IF crec%NOTFOUND THEN
           CLOSE crec;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCOLUMN;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column default data from COL$           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0101_CSSEXPCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER,
    DefValue             OUT VARCHAR2) is

  csr INTEGER;
  rc  NUMBER;
  len INTEGER;
  cnk INTEGER := 4000;
 BEGIN
   csr := DBMS_SQL.OPEN_CURSOR;
   DBMS_SQL.PARSE(csr, 'SELECT DEFAULT$ FROM SYS.COL$ WHERE OBJ# = ' ||
                                       ObjectNumIn || ' AND COL# = ' || 
                                       ColumnNumIn, DBMS_SQL.NATIVE);
   DBMS_SQL.DEFINE_COLUMN_LONG(csr, 1);
   rc := DBMS_SQL.EXECUTE_AND_FETCH(csr);
   DBMS_SQL.COLUMN_VALUE_LONG(csr, 1, cnk, OffsetNumIn, DefValue, len);
   DBMS_SQL.CLOSE_CURSOR(csr);
 END PSTV0101_CSSEXPCOLUMN;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Cluster Col Ids from COL$, etc..        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSCLSCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ClusterNumIn          IN INTEGER,
    ColNum               OUT t_columnnumber,
    SegCol               OUT t_segcolnumber) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT cseg%ISOPEN THEN
        OPEN cseg(ObjectNumIn,ClusterNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH cseg INTO ColNum(i), SegCol(i);
        IF cseg%NOTFOUND THEN
           CLOSE cseg;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSCLSCOLUMN;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column NOT Null constraint name         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSNNMCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColNum               OUT t_columnnumber,
    ConName              OUT t_conname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT cnul%ISOPEN THEN
        OPEN cnul(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH cnul INTO ColNum(i), ConName(i);
        IF cnul%NOTFOUND THEN
           CLOSE cnul;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSNNMCOLUMN;

##/*--------------------------------------------------------------------*
## *  Procedure used to acquire XML column schema values                *
## *--------------------------------------------------------------------*/
## PROCEDURE PSTV0100_CSSXMLCOLUMN
##   (RowsToGet             IN INTEGER,
##    CreatorNameIn         IN VARCHAR2,
##    TableNameIn           IN VARCHAR2,
##    ColumnNameIn          IN VARCHAR2,
##    Schema               OUT VARCHAR2,
##    Element              OUT VARCHAR2,
##    StorageType          OUT VARCHAR2) is
##
## BEGIN
##     SELECT XMLSCHEMA, ELEMENT_NAME, STORAGE_TYPE
##       INTO Schema, Element, StorageType 
##       FROM ALL_XML_TAB_COLS
##      WHERE OWNER = CreatorNameIn
##        AND TABLE_NAME = TableNameIn
##        AND COLUMN_NAME = ColumnNameIn;
## END PSTV0100_CSSXMLCOLUMN;

END PSTO1IV0100_CSSCOLUMN;
