/*
    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Oracle9i package body for Catalog Services Execute Services       *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO1IV0100_CSSEXECUTE AS

/*--------------------------------------------------------------------*
 *  Cursor used to acquire valid dependencies used by CSS             *
 *--------------------------------------------------------------------*/
 CURSOR drec (DepCid INTEGER) IS
  SELECT PU.USER_ID,
         DU.USER_ID,
         DECODE(PO.TYPE#,11,9,PO.TYPE#),
         DECODE(DO.TYPE#,11,9,DO.TYPE#),
         NVL(AC.TYPES,99),
         PU.USERNAME,
         PO.NAME,
         DU.USERNAME,
         DO.NAME
    FROM SYS.DBA_USERS PU, SYS.OBJ$ PO,
         SYS.DBA_USERS DU, SYS.OBJ$ DO,
         SYS.DEPENDENCY$ DP, SYS.ACCESS$ AC
   WHERE DO.OBJ# = DP.D_OBJ#
     AND DO.OWNER# != 0
     AND DO.TYPE# IN (2,4,5,6,7,8,9,11,12)
     AND DO.NAME NOT LIKE('V$%')
     AND PO.OBJ# = DP.P_OBJ#
     AND PO.OWNER# != 0
     AND PO.TYPE# IN (2,4,5,6,7,8,9,11,12)
     AND PO.NAME NOT LIKE('V$%')
     AND NOT (((PO.TYPE# = 9) AND (DO.TYPE# = 11)) AND (PO.NAME = DO.NAME))
     AND (DO.OWNER# = DepCid OR PO.OWNER# = DepCid)
     AND DU.USER_ID = DO.OWNER#
     AND PU.USER_ID = PO.OWNER#
     AND AC.D_OBJ#(+) = DP.D_OBJ#
     AND AC.ORDER#(+) = DP.ORDER#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire valid synonyms used by CSS                 *
 *--------------------------------------------------------------------*/
 CURSOR srec (DepCid INTEGER) IS
  SELECT PU.USER_ID,
         DU.USER_ID,
         DECODE(PO.TYPE#,11,9,PO.TYPE#),
         5,
         99,
         PU.USERNAME,
         PO.NAME,
         DU.USERNAME,
         DO.NAME
    FROM SYS.DBA_USERS PU, SYS.DBA_USERS DU,
         SYS.OBJ$ PO, SYS.OBJ$ DO,
         SYS.SYN$ SY
   WHERE DO.TYPE# = 5
     AND DO.Owner# != 0
     AND DU.USER_ID = DO.OWNER#
     AND SY.OBJ# = DO.OBJ#
     AND SY.NODE IS NULL
     AND SY.NAME NOT LIKE('V$%')
     AND PO.NAME(+) = SY.NAME
     AND PO.TYPE#(+) < 12
     AND PO.Owner#(+) != 0
     AND PU.USER_ID(+) = PO.OWNER#
     AND PU.USERNAME = SY.OWNER
     AND (DO.OWNER# = DepCid OR PO.OWNER# = DepCid);
     
/*--------------------------------------------------------------------*
 *  Cursor used to acquire system partition names                     *
 *--------------------------------------------------------------------*/
 CURSOR cname (ObjectNumIn INTEGER) IS
 SELECT PO.SUBNAME 
        FROM SYS.OBJ$ O, SYS.OBJ$ PO
       WHERE O.OBJ# = ObjectNumIn
         AND PO.NAME = O.NAME
         AND PO.TYPE# = 19
       ORDER BY PO.SUBNAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Dependencies for CSS                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETDEPENDS
   (RowsToGet             IN INTEGER,
    CreatorNum            IN INTEGER,
    CreatorName           IN VARCHAR2,
    ReqCNum              OUT t_dbmsint,
    RefCNum              OUT t_dbmsint,
    ReqOType             OUT t_dbmsint,
    RefOType             OUT t_dbmsint,
    DepMode              OUT t_dbmsint,
    ReqCName             OUT t_creatorname,
    ReqOName             OUT t_objectname,
    RefCName             OUT t_creatorname,
    RefOName             OUT t_objectname) is

   LclROType     INTEGER;
   LclFOType     INTEGER;
   DepCid        INTEGER;

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call perform setup.                            *
 *    1. If Depend Owner number not input locate it                   *
 *    2. Open query result cursor                                     *
 *--------------------------------------------------------------------*/
     IF NOT drec%ISOPEN THEN
       DepCid := CreatorNum;
       IF (DepCid = 0) THEN
         SELECT U.USER_ID
           INTO DepCid
           FROM SYS.DBA_USERS U
          WHERE U.UserName = CreatorName;
         IF (DepCid IS NULL) OR (DepCid = 0) THEN
           RAISE NO_DATA_FOUND;
         END IF;
       END IF;
       OPEN drec(DepCid);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH drec INTO ReqCNum(i),RefCNum(i),
                        LclROType, LclFOType, DepMode(i),
                        ReqCName(i),ReqOName(i),
                        RefCName(i),RefOName(i);
        IF drec%NOTFOUND THEN
           CLOSE drec;
           EXIT;
        END IF;
/*--------------------------------------------------------------------*
 *  Mark 1st return record with Dep Owner id flag                     *
 *--------------------------------------------------------------------*/
        IF (drec%ROWCOUNT = 1) THEN
          IF (LclROType = DepCid) THEN
            LclROType := LclROType + 256;
          ELSE
            LclFOType := LclFOType + 256;
          END IF;
        END IF;
        ReqOType(i) := LclROType;
        RefOType(i) := LclFOType;
     END LOOP;
 END PSTV0100_CSSGETDEPENDS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Synonyms for CSS                        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSYNS
   (RowsToGet             IN INTEGER,
    CreatorNum            IN INTEGER,
    CreatorName           IN VARCHAR2,
    ReqCNum              OUT t_dbmsint,
    RefCNum              OUT t_dbmsint,
    ReqOType             OUT t_dbmsint,
    RefOType             OUT t_dbmsint,
    DepMode              OUT t_dbmsint,
    ReqCName             OUT t_creatorname,
    ReqOName             OUT t_objectname,
    RefCName             OUT t_creatorname,
    RefOName             OUT t_objectname) is

   LclROType     INTEGER;
   LclFOType     INTEGER;
   DepCid        INTEGER;

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call perform setup.                            *
 *    1. If Synonym Owner number not input locate it                  *
 *    2. Open query result cursor                                     *
 *--------------------------------------------------------------------*/
     IF NOT srec%ISOPEN THEN
       DepCid := CreatorNum;
       IF (DepCid = 0) THEN
         SELECT U.USER_ID
           INTO DepCid
           FROM SYS.DBA_USERS U
          WHERE U.UserName = CreatorName;
         IF (DepCid IS NULL) OR (DepCid = 0) THEN
           RAISE NO_DATA_FOUND;
         END IF;
       END IF;
       OPEN srec(DepCid);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH srec INTO ReqCNum(i),RefCNum(i),
                        LclROType, LclFOType, DepMode(i),
                        ReqCName(i),ReqOName(i),
                        RefCName(i),RefOName(i);
        IF srec%NOTFOUND THEN
           CLOSE srec;
           EXIT;
        END IF;
/*--------------------------------------------------------------------*
 *  Mark 1st return record with Dep Owner id flag                     *
 *--------------------------------------------------------------------*/
        IF (srec%ROWCOUNT = 1) THEN
          IF (LclROType = DepCid) THEN
            LclROType := LclROType + 256;
          ELSE
            LclFOType := LclFOType + 256;
          END IF;
        END IF;
        ReqOType(i) := LclROType;
        RefOType(i) := LclFOType;
     END LOOP;
 END PSTV0100_CSSGETSYNS;
/*--------------------------------------------------------------------*
 *  Procedure used to acquire system partition counts                 *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCOUNTS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColNum               OUT INTEGER,
    SegCol               OUT INTEGER) is

 BEGIN
      SELECT COUNT(PO.SUBNAME),SUM(LENGTH(PO.SUBNAME))
        INTO ColNum,SegCol 
        FROM SYS.OBJ$ O, SYS.OBJ$ PO
       WHERE O.OBJ# = ObjectNumIn
         AND PO.NAME = O.NAME
         AND PO.TYPE# = 19;
 END PSTV0100_CSSGETCOUNTS;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire system partition names                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETNAME
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SpcName              OUT t_objectname) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT cname%ISOPEN THEN
        OPEN cname(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH cname INTO SpcName(i);
        IF cname%NOTFOUND THEN
           CLOSE cname;
           EXIT;
        END IF;
     END LOOP;
END PSTV0100_CSSGETNAME;
END PSTO1IV0100_CSSEXECUTE;
