/*
    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Oracle9i package used by Catalog Services Sequences               *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO1IV0100_CSSSEQUENCE AS
/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in this Package  *
 *--------------------------------------------------------------------*/
   TYPE t_creatorname   IS TABLE OF SYS.DBA_USERS.USERNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_sequencename  IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_integer       IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_varchar2      IS TABLE OF VARCHAR2(30)
         INDEX BY BINARY_INTEGER;
   TYPE t_bool          IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence Attributes                     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    SeqName               IN VARCHAR2,
    ObjNum               OUT INTEGER,
    CidNum               OUT INTEGER,
    Cache                OUT INTEGER,
    Incr                 OUT VARCHAR2,
    MinValue             OUT VARCHAR2,
    MaxValue             OUT VARCHAR2,
    Cycle                OUT CHAR,
    Ordering             OUT CHAR,
    NoMin                OUT CHAR,
    NoMax                OUT CHAR,
    Owner                OUT VARCHAR2,
    Name                 OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List from Creator/Sequence     *
 *  patterns when both names are explicit values                      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List from Creator/Sequence     *
 *  when Creator is a LIKE value and Sequence is explicit             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List from Creator/Sequence     *
 *  when Creator is explicit and Sequence is a LIKE value             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST2
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List from Creator/Sequence     *
 *  when both names are LIKE values                                   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST3
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename);
 END PSTO1IV0100_CSSSEQUENCE;
/

grant execute on ~ALTSPQUALIFIER..PSTO1IV0100_CSSSEQUENCE to ~ALTGRANTAUTHID
/

