/*
    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Oracle9i package used by Catalog Services for Table/View          *
 *--------------------------------------------------------------------*/
 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO1IV0100_CSSTABLE AS
/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in this Package  *
 *--------------------------------------------------------------------*/
   TYPE t_creatorname   IS TABLE OF SYS.DBA_USERS.USERNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_tablename     IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_tblcbyte     IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_tblbbyte          IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_subname  IS TABLE OF SYS.OBJ$.SUBNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_tsname       IS TABLE OF SYS.TS$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_hibound           IS TABLE OF VARCHAR2(1024)
         INDEX BY BINARY_INTEGER;
   TYPE t_colname           IS TABLE OF VARCHAR2(4000)
      INDEX BY BINARY_INTEGER;
   TYPE t_segcre           IS TABLE OF VARCHAR2(1024)
      INDEX BY BINARY_INTEGER;    

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Object data from OBJ$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETOBJECT
   (RowsToGet             IN INTEGER,
    CreatorNumIn          IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    ObjectNameIn          IN VARCHAR2,
    ObjectType           OUT CHAR,
    ObjectStatus         OUT CHAR,
    RemoteType           OUT CHAR,
    SynonymType          OUT CHAR,
    CreatorNumId         OUT INTEGER,
    ObjectNumId          OUT INTEGER,
    TblProp              OUT INTEGER,
    RemoteCreator        OUT VARCHAR2,
    RemoteObject         OUT VARCHAR2,
    RemoteLink           OUT VARCHAR2,
    ReadOnlyT             OUT CHAR);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Extended Object data from TAB$, TS$     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSEXPOBJECT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    RowCount             OUT INTEGER,
    ColCount             OUT INTEGER,
    InsTrigCnt           OUT INTEGER,
    UpdTrigCnt           OUT INTEGER,
    DelTrigCnt           OUT INTEGER);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Object data from TAB$,TS$,SEG$      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLOBJECT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctUsed              OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    Parallel             OUT INTEGER,
    Instances            OUT INTEGER,
    CacheStat            OUT INTEGER,
    ClsObjId             OUT INTEGER,
    SpcObjId             OUT INTEGER,
    TblFlag              OUT INTEGER,
    ObjFlag              OUT INTEGER,
    ChkCount             OUT INTEGER,
    Spare1               OUT INTEGER,
    TableSpaceName       OUT VARCHAR2,
    ClsIotName           OUT VARCHAR2,    
    SegmentCre			 OUT VARCHAR2,
    TblProperty			 OUT VARCHAR2,
    FlashbackStr         OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table PartBase from PARTOBJ$,TS$    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartCnt              OUT INTEGER,
    PartKeyCnt           OUT INTEGER,
    PartType             OUT INTEGER,
    PctgFree             OUT INTEGER,
    PctgUsed             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2,
    Spare2               OUT VARCHAR2,
    IntervalStr          OUT VARCHAR2,
    ReferenceStr         OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table PartKeys from PARTCOL$        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_tblbbyte,
    KeyPos               OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table SubPartKeys from SUBPARTCOL$  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLSUBPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_tblbbyte,
    KeyPos               OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Table Partitions OBJ$,TABPARTS, etc *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_tblbbyte,
    PartNum              OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    HiBndLen             OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    Comp                 OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire COMPOSITE Partitions OBJ$,TABCOMPART    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLCOMPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_tblbbyte,
    PartNum              OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    HiBndLen             OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    Comp                 OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound,
    SubPartCnt           OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table SubPartitions OBJ$,TABSUBPART$ etc*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLTBLSUBPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SubPartObjNum        OUT t_tblbbyte,
    SubPartNum           OUT t_tblbbyte,
    PctgFree             OUT t_tblbbyte,
    PctgUsed             OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    InitExt              OUT t_tblbbyte,
    NextExt              OUT t_tblbbyte,
    MinExt               OUT t_tblbbyte,
    MaxExt               OUT t_tblbbyte,
    PctIncr              OUT t_tblbbyte,
    Lists                OUT t_tblbbyte,
    Groups               OUT t_tblbbyte,
    TsBlkSize            OUT t_tblbbyte,
    LogFlag              OUT t_tblcbyte,
    BPool                OUT t_tblcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndLen             OUT t_tblbbyte,
    HiBndVal             OUT t_hibound);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire IOT data from IND$,TS$,SEG$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLIOTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctgThres            OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    InclCol              OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2,
    CompCols             OUT INTEGER);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire IOT data from IND$,TS$,SEG$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLIOTOVER
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    PctgUsed             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table LOBs from LOB$,IND$,TS$,SEG$      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSTBLLOBBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    LobCol               OUT t_tblbbyte,
    LobObj               OUT t_tblbbyte,
    LobIdx               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    InitTran             OUT t_tblbbyte,
    MaxTran              OUT t_tblbbyte,
    IInitExt             OUT t_tblbbyte,
    INextExt             OUT t_tblbbyte,
    IMinExt              OUT t_tblbbyte,
    IMaxExt              OUT t_tblbbyte,
    IPctIncr             OUT t_tblbbyte,
    ILists               OUT t_tblbbyte,
    IGroups              OUT t_tblbbyte,
    ITsBlkSize           OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    IdxLog               OUT t_tblcbyte,
    IdxBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    IdxSysName           OUT t_tblcbyte,
    SegName              OUT t_tablename,
    SegTSName            OUT t_tsname,
    IdxName              OUT t_tablename,
    IdxTSName            OUT t_tsname,
    Freepools            OUT t_tblbbyte,
    SecureFile           OUT t_tblcbyte,
    SegCre				 OUT t_segcre);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Part LOBs from LOBFRAG$,TS$,SEG$,OBJ$   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire SubPart LOBs from LOBFRAG$,TS$,SEG$,OBJ$*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSSUBPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Part LOBs from LOBCOMPART$,TS$,LOB$,OBJ$*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSCOMPARTLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SegObj               OUT t_tblbbyte,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    ColNum               OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    SegSysName           OUT t_tblcbyte,
    SegTSName            OUT t_tsname,
    SegName              OUT t_subname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire default Part LOBs from PARTLOB$,COL$,TS$*
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSPARTDLOB
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    LobChunk             OUT t_tblbbyte,
    PctVers              OUT t_tblbbyte,
    SInitExt             OUT t_tblbbyte,
    SNextExt             OUT t_tblbbyte,
    SMinExt              OUT t_tblbbyte,
    SMaxExt              OUT t_tblbbyte,
    SPctIncr             OUT t_tblbbyte,
    SLists               OUT t_tblbbyte,
    SGroups              OUT t_tblbbyte,
    STsBlkSize           OUT t_tblbbyte,
    RowStg               OUT t_tblcbyte,
    LobFlags             OUT t_tblbbyte,
    SegBPool             OUT t_tblcbyte,
    ColName              OUT t_tablename,
    SegTSName            OUT t_tsname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Extended Attributes of View             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSEXPVIEW
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ViewLen              OUT INTEGER,
    ChkName              OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Text of a View from VIEW$               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETVIEW
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER, /* not used */
    ViewText             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table patterns  *
 *  when both names are explicit values                               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST0
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table patterns  *
 *  when Creator is a LIKE value and Table is explicit                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST1
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table patterns  *
 *  when Creator is explicit and Table is a LIKE value                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST2
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Table List from Creator/Table patterns  *
 *  when both names are LIKE values                                   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTBLLIST3
   (RowsToGet             IN INTEGER,
    ObjType1              IN INTEGER,
    ObjType2              IN INTEGER,
    ObjType3              IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename,
    TableType            OUT t_tblcbyte,
    RowCount             OUT t_tblbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire SubPartition Template Info              *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSUBTEMPLATELIST
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    TSName               OUT t_tsname,
    Name                 OUT t_subname,
    HiBndVal             OUT t_hibound);
 END PSTO1IV0100_CSSTABLE;
/

grant execute on ~ALTSPQUALIFIER..PSTO1IV0100_CSSTABLE to ~ALTGRANTAUTHID
/

