 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO12V0100_CSSCOLUMN AS
/*
    Oracle12C package used by Catalog Services for Columns

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in this Package  *
 *--------------------------------------------------------------------*/
   TYPE t_datatype   IS TABLE OF CHAR(9)
         INDEX BY BINARY_INTEGER;
   TYPE t_nullmode IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_columnlength IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_columnnumber IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_segcolnumber IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_defaultvaluelength IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_numericprecision IS TABLE OF SMALLINT
         INDEX BY BINARY_INTEGER;
   TYPE t_numericscale IS TABLE OF SMALLINT
         INDEX BY BINARY_INTEGER;
   TYPE t_columnname IS TABLE OF SYS.COL$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_conname IS TABLE OF SYS.CON$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_prop IS TABLE OF NUMBER
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Basic Column data from COL$             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColLen               OUT t_columnlength,
    ColNum               OUT t_columnnumber,
    DefValLen            OUT t_defaultvaluelength,
    NumPrec              OUT t_numericprecision,
    NumScale             OUT t_numericscale,
    NullMode             OUT t_nullmode,
    DataType             OUT t_datatype,
    ColName              OUT t_columnname,
    CharLen              OUT t_columnlength,
    Properties           OUT t_prop);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column default data from COL$           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0101_CSSEXPCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER,
    DefValue             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Cluster Col Ids from COL$, etc..        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSCLSCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ClusterNumIn          IN INTEGER,
    ColNum               OUT t_columnnumber,
    SegCol               OUT t_segcolnumber);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Column NOT Null constraint name         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSNNMCOLUMN
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ColNum               OUT t_columnnumber,
    ConName              OUT t_conname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire XML column schema values                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSXMLCOLUMN
   (RowsToGet             IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    TableNameIn           IN VARCHAR2,
    ColumnNameIn          IN VARCHAR2,
    Schema               OUT VARCHAR2,
    Element              OUT VARCHAR2,
    StorageType          OUT VARCHAR2);

 END PSTO12V0100_CSSCOLUMN;
/

grant execute on ~ALTSPQUALIFIER..PSTO12V0100_CSSCOLUMN to ~ALTGRANTAUTHID
/

