 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO12V0100_CSSRELCON AS
/*
    Oracle12C package body for Catalog Services Relationships

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Cursor used to get all RelLinks for a given Creator Id            *
 *--------------------------------------------------------------------*/
 CURSOR rlink (CidIntId     INTEGER) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME,
        OD.OWNER#,
        OP.OWNER#,
        CD.CON#,
        CD.RCON#,
        NVL(CD.ENABLED,0),
        decode(bitand(CD.DEFER,1),1,'Y','N'),
        decode(bitand(CD.DEFER,2),2,'D','I'),
        decode(bitand(CD.DEFER,4),4,'Y','N'),
        CD.REFACT
   FROM SYS.DBA_USERS UD,
        SYS.DBA_USERS UR,
        SYS.OBJ$ OD,
        SYS.OBJ$ OP,
        SYS.CON$ CND,
        SYS.CDEF$ CD,
        SYS.CDEF$ CR
   WHERE CD.TYPE# = 4
     AND OD.OBJ# = CD.OBJ#
     AND OD.OID$ IS NULL
     AND OP.OBJ# = CD.ROBJ#
     AND OP.OID$ IS NULL
     AND (OD.OWNER# = CidIntId OR OP.OWNER# = CidIntId)
     AND UD.USER_ID = OD.OWNER#
     AND UR.USER_ID = OP.OWNER#
     AND CND.CON# = CD.CON#
     AND CR.CON# = CD.RCON#
     AND (CR.TYPE# = 2 OR CR.TYPE# = 3);

/*--------------------------------------------------------------------*
 *  Cursor used to get Column details for a given constraint          *
 *--------------------------------------------------------------------*/
 CURSOR concl (DepConId     INTEGER,
               ParConId     INTEGER) IS
 SELECT CC.CON#, CC.COL#, CC.POS#
   FROM SYS.CCOL$ CC
  WHERE CC.CON# = DepConId OR CC.CON# = ParConId;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when all values are explicit          *
 *  SP Name = PSTV0100_CSSGETRELLIST0                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst0 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME = RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME = CidPatternIn
    AND OD.NAME = TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when CID Pattern is generic           *
 *  and other names explicit                                          *
 *  SP Name = PSTV0100_CSSGETRELLIST1                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst1 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME = RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME LIKE CidPatternIn
    AND OD.NAME = TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when Table pattern is generic         *
 *  and the others explicit                                           *
 *  SP Name = PSTV0100_CSSGETRELLIST2                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst2 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME = RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME = CidPatternIn
    AND OD.NAME LIKE TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when Creator/Table patterns generic   *
 *  SP Name = PSTV0100_CSSGETRELLIST3                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst3 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME = RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME LIKE CidPatternIn
    AND OD.NAME LIKE TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when RelName pattern generic          *
 *  and the others explicit                                           *
 *  SP Name = PSTV0100_CSSGETRELLIST4                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst4 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME LIKE RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME = CidPatternIn
    AND OD.NAME = TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when Creator/RelName patterns generic *
 *  SP Name = PSTV0100_CSSGETRELLIST5                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst5 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME LIKE RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME LIKE CidPatternIn
    AND OD.NAME = TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when Table/RelName patterns generic   *
 *  SP Name = PSTV0100_CSSGETRELLIST6                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst6 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME LIKE RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME = CidPatternIn
    AND OD.NAME LIKE TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get FK List when all input patterns generic       *
 *  SP Name = PSTV0100_CSSGETRELLIST6                                 *
 *--------------------------------------------------------------------*/
 CURSOR rlst7 (CidPatternIn VARCHAR2,
               TblPatternIn VARCHAR2,
               RelPatternIn VARCHAR2) IS
 SELECT UD.USERNAME,
        OD.NAME,
        CND.NAME,
        UR.USERNAME,
        OP.NAME
   FROM SYS.DBA_USERS UD, SYS.DBA_USERS UR, SYS.OBJ$ OD, SYS.OBJ$ OP,
        SYS.CON$ CND, SYS.CDEF$ CD, SYS.CDEF$ CR
  WHERE CD.TYPE# = 4
    AND CND.CON# = CD.CON#
    AND CND.NAME LIKE RelPatternIn
    AND OD.OBJ# = CD.OBJ#
    AND OD.OID$ IS NULL
    AND UD.USER_ID = OD.OWNER#
    AND UD.USERNAME LIKE CidPatternIn
    AND OD.NAME LIKE TblPatternIn
    AND OP.OBJ# = CD.ROBJ#
    AND OP.OID$ IS NULL
    AND CR.CON# = CD.RCON#
    AND (CR.TYPE# = 2 OR CR.TYPE# = 3)
    AND UR.USER_ID = OP.OWNER#
  ORDER BY UD.USERNAME, OD.NAME, CND.NAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire RelLinks for a Creator Id.              *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLINK
   (RowsToGet             IN INTEGER,
    CreatorNumIn          IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl,
    DepCidId             OUT t_depcidid,
    ParCidId             OUT t_parcidid,
    DepConId             OUT t_depconid,
    ParConId             OUT t_parconid,
    EnableId             OUT t_enableid,
    Deferable            OUT t_deferflag,
    DeferInit            OUT t_deferflag,
    Validated            OUT t_deferflag,
    DeleteRule           OUT t_deleterule) is

   LocalCidId    INTEGER;

 BEGIN
   LocalCidId := CreatorNumIn;

/*--------------------------------------------------------------------*
 *  If The Owner Number value is not known we must first locate       *
 *  it using the input Creator Name.                                  *
 *  An input value of -1 indicates an unknown value.                  *
 *--------------------------------------------------------------------*/
   IF CreatorNumIn = -1 THEN
      SELECT U.USER_ID
        INTO LocalCidId
        FROM SYS.DBA_USERS U
        WHERE U.USERNAME = CreatorNameIn;
      END IF;

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlink%ISOPEN THEN
        OPEN rlink(LocalCidId);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlink INTO DepCidName(i), DepTblName(i),
              RelName(i), ParCidName(i), ParTblName(i),
              DepCidId(i), ParCidId(i), DepConId(i), ParConId(i),
              EnableId(i), Deferable(i), DeferInit(i), Validated(i),
              DeleteRule(i);
        IF rlink%NOTFOUND THEN
           CLOSE rlink;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLINK;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Constraint details from CCOL$           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETCONDETAIL
   (RowsToGet             IN INTEGER,
    ParConId              IN INTEGER,
    DepConId              IN INTEGER,
    ConId                OUT t_conid,
    ColId                OUT t_colid,
    ColPos               OUT t_colpos) IS

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT concl%ISOPEN THEN
        OPEN concl(DepConId,ParConId);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number records requested by the caller               *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH concl INTO ConId(i), ColId(i), ColPos(i);
        IF concl%NOTFOUND THEN
           CLOSE concl;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETCONDETAIL;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when all names are explicit values                       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst0%ISOPEN THEN
        OPEN rlst0(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst0 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst0%NOTFOUND THEN
           CLOSE rlst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when Creator is Generic                                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst1%ISOPEN THEN
        OPEN rlst1(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst1 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst1%NOTFOUND THEN
           CLOSE rlst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when Table is Generic                                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST2
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst2%ISOPEN THEN
        OPEN rlst2(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst2 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst2%NOTFOUND THEN
           CLOSE rlst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when Creator/Table Generic                               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST3
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst3%ISOPEN THEN
        OPEN rlst3(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst3 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst3%NOTFOUND THEN
           CLOSE rlst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST3;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when RelName value generic                               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST4
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst4%ISOPEN THEN
        OPEN rlst4(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst4 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst4%NOTFOUND THEN
           CLOSE rlst4;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST4;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when Creator and RelName names generic                   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST5
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst5%ISOPEN THEN
        OPEN rlst5(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst5 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst5%NOTFOUND THEN
           CLOSE rlst5;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST5;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when Table and RelName names generic                     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST6
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst6%ISOPEN THEN
        OPEN rlst6(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst6 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst6%NOTFOUND THEN
           CLOSE rlst6;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST6;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire FK List from Creator/Table/RelName      *
 *  patterns when all names are generic                               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETRELLIST7
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    RelPatternIn          IN VARCHAR2,
    DepCidName           OUT t_depcid,
    DepTblName           OUT t_deptbl,
    RelName              OUT t_relname,
    ParCidName           OUT t_parcid,
    ParTblName           OUT t_partbl) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT rlst7%ISOPEN THEN
        OPEN rlst7(CidPatternIn,
                   TblPatternIn,
                   RelPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH rlst7 INTO DepCidName(i), DepTblName(i), RelName(i),
                         ParCidName(i), ParTblName(i);
        IF rlst7%NOTFOUND THEN
           CLOSE rlst7;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETRELLIST7;
END PSTO12V0100_CSSRELCON;
