 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO12V0100_CSSINDEX AS
/*
    Oracle12C package Catalog Services Indexes

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in this Package  *
 *--------------------------------------------------------------------*/
   TYPE t_creator  IS TABLE OF SYS.DBA_USERS.USERNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_idxname  IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_conname  IS TABLE OF SYS.CON$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_subname  IS TABLE OF SYS.OBJ$.SUBNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_idxobj   IS TABLE OF SYS.IND$.OBJ#%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_colname   IS TABLE OF SYS.COL$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_tsname       IS TABLE OF SYS.TS$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_idxcbyte     IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_idxbbyte          IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_hibound           IS TABLE OF VARCHAR2(1024)
         INDEX BY BINARY_INTEGER;
   TYPE t_idxcdef           IS TABLE OF VARCHAR2(2000)
         INDEX BY BINARY_INTEGER;
   TYPE t_idxflags     IS TABLE OF SYS.IND$.FLAGS%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_idxtype     IS TABLE OF SYS.IND$.TYPE#%TYPE
         INDEX BY BINARY_INTEGER;
    TYPE t_idxsegcre   IS TABLE OF VARCHAR2(1024)
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Indices from USER$,OBJ$,COL$,IND$,ICOL$ *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETINDEX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxCid               OUT t_creator,
    IdxName              OUT t_idxname,
    KeyPos               OUT t_idxbbyte,
    IdxObjId             OUT t_idxobj,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColDefLen            OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColDef               OUT t_idxcdef,
    IdxFlags             OUT t_idxflags,
    IdxType              OUT t_idxtype,
    SegCre               OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure used to count BITMAP JOIN Index entries                 *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJCNT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxObjId             OUT t_idxobj,
    RecCnt               OUT t_idxbbyte,
    Type                 OUT t_idxcbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire BITMAP JOIN Index entries               *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJIDX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    IdxCid               OUT t_creator,
    IdxName              OUT t_idxname,
    JtblCid              OUT t_creator,
    JtblName             OUT t_idxname,
    IdxObjId             OUT t_idxobj,
    KeyPos               OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire BITMAP JOIN Predicates                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETBMJCOL
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    Tbl1Cid              OUT t_creator,
    Tbl1Name             OUT t_idxname,
    Tbl1Col              OUT t_colname,
    Tbl2Cid              OUT t_creator,
    Tbl2Name             OUT t_idxname,
    Tbl2Col              OUT t_colname,
    JoinOper             OUT t_idxbbyte,
    Tbl1Inst             OUT t_idxbbyte,
    Tbl2Inst             OUT t_idxbbyte);

/*--------------------------------------------------------------------*
 *  Procedure to acquire UnqRel Index data                            *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETUNQREL
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ConName              OUT t_conname,
    ConId                OUT t_idxbbyte,
    Enabled              OUT t_idxbbyte,
    ColName              OUT t_colname,
    KeyPos               OUT t_idxbbyte,
    Deferable            OUT t_idxcbyte,
    DeferInit            OUT t_idxcbyte,
    Validated            OUT t_idxcbyte,
    SegCre         OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Object data                         *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLINDEX
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PctgFree             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    Groups               OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    ParaDegree           OUT INTEGER,
    ParaInst             OUT INTEGER,
    CompCols             OUT INTEGER,
    LogFlag              OUT CHAR,
    PartFlag             OUT CHAR,
    Type                 OUT CHAR,
    BPool                OUT CHAR,
    RevFlag              OUT CHAR,
    TSName               OUT VARCHAR2,
    SegCre         OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index PartBase                      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTBASE
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartCnt              OUT INTEGER,
    PartKeyCnt           OUT INTEGER,
    PctgFree             OUT INTEGER,
    InitTran             OUT INTEGER,
    MaxTran              OUT INTEGER,
    InitExt              OUT INTEGER,
    NextExt              OUT INTEGER,
    MinExt               OUT INTEGER,
    MaxExt               OUT INTEGER,
    PctIncr              OUT INTEGER,
    Lists                OUT INTEGER,
    TsBlkSize            OUT INTEGER,
    PartType             OUT INTEGER,
    SubPartType          OUT INTEGER,
    SubPartKeyCols       OUT INTEGER,
    DefSubPartCnt        OUT INTEGER,
    PartLoc              OUT CHAR,
    PartAlign            OUT CHAR,
    LogFlag              OUT CHAR,
    BPool                OUT CHAR,
    TSName               OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index PartKeys                      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTKEYS
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    KeyNum               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire DDL Index Partitions                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_idxbbyte,
    PartNum              OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    HiBndLen             OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartComp             OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire COMPOSITE Index Part                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXCOMPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PartObjNum           OUT t_idxbbyte,
    PartNum              OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    HiBndLen             OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartComp             OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname,
    HiBndVal             OUT t_hibound,
    SubPartCnt           OUT t_idxbbyte);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Index SubPartitions                     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSDDLIDXSUBPARTSLOT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    SubPartObjNum        OUT t_idxbbyte,
    SubPartNum           OUT t_idxbbyte,
    PctgFree             OUT t_idxbbyte,
    InitTran             OUT t_idxbbyte,
    MaxTran              OUT t_idxbbyte,
    InitExt              OUT t_idxbbyte,
    NextExt              OUT t_idxbbyte,
    MinExt               OUT t_idxbbyte,
    MaxExt               OUT t_idxbbyte,
    PctIncr              OUT t_idxbbyte,
    Lists                OUT t_idxbbyte,
    Groups               OUT t_idxbbyte,
    TsBlkSize            OUT t_idxbbyte,
    LogFlag              OUT t_idxcbyte,
    BPool                OUT t_idxcbyte,
    PartName             OUT t_subname,
    TSName               OUT t_tsname);

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List                                     *
 *  Include both System and Primary Key Indexes                       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST0
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte,
    SegCre               OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List                                     *
 *  Exclude System Tables                                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST1
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte,
    SegCre               OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List                                     *
 *  Exclude Tables with Primary Keys                                  *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST2
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte,
    SegCre               OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure for DBMS Index List                                     *
 *  Exclude System Tables and Tables with Primary Keys                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSINDEXLIST3
   (RowsToGet             IN INTEGER,
    IdxCid               OUT t_creator,
    IdxTable             OUT t_idxname,
    IdxDef               OUT t_creator,
    IdxName              OUT t_idxname,
    IdxProp              OUT t_idxbbyte,
    ColProp              OUT t_idxbbyte,
    ColName              OUT t_colname,
    ColCnt               OUT t_idxbbyte,
    KeyPos               OUT t_idxbbyte,
    PKFlag               OUT t_idxbbyte,
    SegCre               OUT t_idxsegcre);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire XML Index Parameter values                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSXMLINDEX
   (RowsToGet             IN INTEGER,
    CreatorNameIn         IN VARCHAR2,
    TableNameIn           IN VARCHAR2,
    IdxNameIn             IN VARCHAR2,
    Paths                OUT VARCHAR2,
    NSMap                OUT VARCHAR2,
    Async                OUT VARCHAR2,
    JobName              OUT VARCHAR2,
    Interval             OUT VARCHAR2,
    ExclIncl             OUT VARCHAR2,
    PathTblObjNum        OUT INTEGER,
    PathTblName          OUT VARCHAR2,
    PathIdxObjNum        OUT INTEGER,
    PathIdxName          OUT VARCHAR2,
    ValueIdxObjNum       OUT INTEGER,
    ValueIdxName         OUT VARCHAR2,
    OrderIdxObjNum       OUT INTEGER,
    OrderIdxName         OUT VARCHAR2);


 END PSTO12V0100_CSSINDEX;
/

grant execute on ~ALTSPQUALIFIER..PSTO12V0100_CSSINDEX to ~ALTGRANTAUTHID
/

