 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO12V0100_CSSPKDEF AS
/*
    Oracle12C package body for Catalog Services PKDEFs

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Cursor used to acquire Primary Key values                         *
 *--------------------------------------------------------------------*/
 CURSOR pkey (ObjectNumIn INTEGER) IS
 SELECT CO.NAME,
        CD.CON#,
        NVL(CD.ENABLED,0),
        COL.NAME,
        CC.POS#,
        decode(bitand(CD.DEFER,1),1,'Y','N'),
        decode(bitand(CD.DEFER,2),2,'D','I'),
        decode(bitand(CD.DEFER,4),4,'Y','N'),
        NVL((select UI.SEGMENT_CREATED from SYS.USER_INDEXES UI where CO.NAME = UI.INDEX_NAME),null)
       FROM SYS.CON$ CO, SYS.CDEF$ CD, SYS.CCOL$ CC, SYS.COL$ COL
       WHERE CD.OBJ#  = ObjectNumIn
         AND CD.TYPE#  = 2
         AND CO.CON# = CD.CON#
         AND CC.CON#  = CD.CON#
         AND CC.OBJ#  = ObjectNumIn
         AND COL.OBJ# = ObjectNumIn
         AND COL.COL# = CC.COL#
       ORDER BY CC.POS#;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Primary Key List when Creator is Explicit  *
 *  and Table is explicit.                                            *
 *--------------------------------------------------------------------*/
 CURSOR plst0 (CidPatternIn VARCHAR2, TblPatternIn VARCHAR2) IS
 SELECT U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.CDEF$ CD
       WHERE U.USERNAME = CidPatternIn
         AND O.NAME = TblPatternIn
         AND O.OWNER# = U.USER_ID
         AND O.TYPE# = 2
         AND O.OID$ IS NULL
         AND CD.OBJ#  = O.OBJ#
         AND CD.TYPE#  = 2
       ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Primary Key List when Creator is Generic   *
 *  and Table is explicit.                                            *
 *--------------------------------------------------------------------*/
 CURSOR plst1 (CidPatternIn VARCHAR2, TblPatternIn VARCHAR2) IS
 SELECT U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.CDEF$ CD
       WHERE U.USERNAME LIKE CidPatternIn
         AND O.NAME = TblPatternIn
         AND O.OWNER# = U.USER_ID
         AND O.TYPE# = 2
         AND O.OID$ IS NULL
         AND CD.OBJ#  = O.OBJ#
         AND CD.TYPE#  = 2
       ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Primary Key List when Creator is Explicit  *
 *  and Table is generic                                              *
 *--------------------------------------------------------------------*/
 CURSOR plst2 (CidPatternIn VARCHAR2, TblPatternIn VARCHAR2) IS
 SELECT U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.CDEF$ CD
       WHERE U.USERNAME = CidPatternIn
         AND O.NAME LIKE TblPatternIn
         AND O.OWNER# = U.USER_ID
         AND O.TYPE# = 2
         AND O.OID$ IS NULL
         AND CD.OBJ#  = O.OBJ#
         AND CD.TYPE#  = 2
       ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used to acquire Primary Key List when Creator is Generic   *
 *  and Table is generic                                              *
 *--------------------------------------------------------------------*/
 CURSOR plst3 (CidPatternIn VARCHAR2, TblPatternIn VARCHAR2) IS
 SELECT U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.CDEF$ CD
       WHERE U.USERNAME LIKE CidPatternIn
         AND O.NAME LIKE TblPatternIn
         AND O.OWNER# = U.USER_ID
         AND O.TYPE# = 2
         AND O.OID$ IS NULL
         AND CD.OBJ#  = O.OBJ#
         AND CD.TYPE#  = 2
       ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Primary Key Data from COL$ and CCOL$    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKDEF
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PkDName              OUT t_pknametype,
    PkDObjId             OUT t_pkobjtype,
    PkDIdxObjId          OUT t_pkidxobjtype,
    ColName              OUT t_colnametype,
    KeyPos               OUT t_keypostype,
    Deferable            OUT t_deferflag,
    DeferInit            OUT t_deferflag,
    Validated            OUT t_deferflag,
    SegCre               OUT t_idxsegcre) is

 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT pkey%ISOPEN THEN
        OPEN pkey(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH pkey INTO PkDName(i),
                        PkDObjId(i),
                        PkdIdxObjId(i),
                        ColName(i),
                        KeyPos(i),
                        Deferable(i),
                        DeferInit(i),
                        Validated(i),
                        SegCre(i);
        IF pkey%NOTFOUND THEN
           CLOSE pkey;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPKDEF;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire PK List when Creator and Table names    *
 *  are explicit references.                                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKDLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT plst0%ISOPEN THEN
        OPEN plst0(CidPatternIn,TblPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH plst0 INTO CreatorName(i),TableName(i);
        IF plst0%NOTFOUND THEN
           CLOSE plst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPKDLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire PK List when Creator name is a          *
 *  generic LIKE pattern and Table name is an explicit reference.     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKDLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT plst1%ISOPEN THEN
        OPEN plst1(CidPatternIn,TblPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH plst1 INTO CreatorName(i),TableName(i);
        IF plst1%NOTFOUND THEN
           CLOSE plst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPKDLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire PK List when Creator name is an         *
 *  explicit reference and Table name is a Generic LIKE pattern       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKDLIST2
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT plst2%ISOPEN THEN
        OPEN plst2(CidPatternIn,TblPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH plst2 INTO CreatorName(i),TableName(i);
        IF plst2%NOTFOUND THEN
           CLOSE plst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPKDLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire PK List when Creator name is a          *
 *  Generic LIKE pattern andd Table name is a Generic LIKE pattern    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKDLIST3
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    TblPatternIn          IN VARCHAR2,
    CreatorName          OUT t_creatorname,
    TableName            OUT t_tablename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT plst3%ISOPEN THEN
        OPEN plst3(CidPatternIn,TblPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH plst3 INTO CreatorName(i),TableName(i);
        IF plst3%NOTFOUND THEN
           CLOSE plst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPKDLIST3;
END PSTO12V0100_CSSPKDEF;
