 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO12V0100_CSSSEQUENCE AS
/*
    Oracle12C package body for Catalog Services Sequences

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Cursor used for Get Sequence List when CID Pattern is explicit    *
 *  and Table Pattern is explicit.                                    *
 *  SP Name = PSTV0100_CSSGETSEQLIST0                                 *
 *--------------------------------------------------------------------*/
 CURSOR seqlst0 (CidPatternIn VARCHAR2,
                 SeqPatternIn VARCHAR2) IS
 SELECT S.INCREMENT$, S.MINVALUE, S.MAXVALUE, S.CYCLE#, S.ORDER$,
        S.CACHE, U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.SEQ$ S
      WHERE U.USERNAME = CidPatternIn
        AND O.OWNER# = U.USER_ID
        AND O.NAME = SeqPatternIn
        AND O.TYPE# = 6
        AND O.OBJ# = S.OBJ#
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Sequence List when CID Pattern is generic     *
 *  and Sequence Pattern is explicit.                                 *
 *  SP Name = PSTV0100_CSSGETSEQLIST1                                 *
 *--------------------------------------------------------------------*/
 CURSOR seqlst1 (CidPatternIn VARCHAR2,
                 SeqPatternIn VARCHAR2) IS
 SELECT S.INCREMENT$, S.MINVALUE, S.MAXVALUE, S.CYCLE#, S.ORDER$,
        S.CACHE, U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.SEQ$ S
      WHERE U.USERNAME LIKE CidPatternIn
        AND O.OWNER# = U.USER_ID
        AND O.NAME = SeqPatternIn
        AND O.TYPE# = 6
        AND O.OBJ# = S.OBJ#
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Sequence List when CID Pattern is explicit    *
 *  and Sequence Pattern is generic.                                  *
 *  SP Name = PSTV0100_CSSGETSEQLIST2                                 *
 *--------------------------------------------------------------------*/
 CURSOR seqlst2 (CidPatternIn VARCHAR2,
                 SeqPatternIn VARCHAR2) IS
 SELECT S.INCREMENT$, S.MINVALUE, S.MAXVALUE, S.CYCLE#, S.ORDER$,
        S.CACHE, U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.SEQ$ S
      WHERE U.USERNAME = CidPatternIn
        AND O.OWNER# = U.USER_ID
        AND O.NAME LIKE SeqPatternIn
        AND O.TYPE# = 6
        AND O.OBJ# = S.OBJ#
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Table List when CID Pattern is generic        *
 *  and Table Pattern is generic.                                     *
 *  SP Name = PSTV0100_CSSGETTBLLIST3                                 *
 *--------------------------------------------------------------------*/
 CURSOR seqlst3 (CidPatternIn VARCHAR2,
                 SeqPatternIn VARCHAR2) IS
 SELECT S.INCREMENT$, S.MINVALUE, S.MAXVALUE, S.CYCLE#, S.ORDER$,
        S.CACHE, U.USERNAME, O.NAME
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.SEQ$ S
      WHERE U.USERNAME LIKE CidPatternIn
        AND O.OWNER# = U.USER_ID
        AND O.NAME LIKE SeqPatternIn
        AND O.TYPE# = 6
        AND O.OBJ# = S.OBJ#
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence Attributes                     *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    SeqName               IN VARCHAR2,
    ObjNum               OUT INTEGER,
    CidNum               OUT INTEGER,
    Cache                OUT INTEGER,
    Incr                 OUT VARCHAR2,
    MinValue             OUT VARCHAR2,
    MaxValue             OUT VARCHAR2,
    Cycle                OUT CHAR,
    Ordering             OUT CHAR,
    NoMin                OUT CHAR,
    NoMax                OUT CHAR,
    Owner                OUT VARCHAR2,
    Name                 OUT VARCHAR2) is

 BEGIN

/*--------------------------------------------------------------------*
 *  Retrieve the data for the Input Sequence name                     *
 *--------------------------------------------------------------------*/
     SELECT O.OBJ#,
            O.OWNER#,
            S.CACHE,
            S.INCREMENT$,
            S.MINVALUE,
            S.MAXVALUE,
            DECODE(S.CYCLE#,0,'N','Y'),
            DECODE(S.ORDER$,0,'N','Y'),
            DECODE(SIGN(s.INCREMENT$),
                  -1,DECODE(S.MINVALUE,TO_NUMBER('-99999999999999999999999999'),'Y','N'),
                   1,DECODE(S.MINVALUE,1,'Y','N'),
                   'N'),
            DECODE(SIGN(S.INCREMENT$),
                  -1,DECODE(S.MAXVALUE,-1,'Y','N'),
                   1,DECODE(S.MAXVALUE,TO_NUMBER('999999999999999999999999999'),'Y','N'),
                  'N'),
            U.USERNAME,
            O.NAME
       INTO ObjNum,CidNum,Cache,Incr,MinValue,MaxValue,Cycle,Ordering,NoMin,NoMax,Owner,Name
       FROM SYS.OBJ$ O, SYS.DBA_USERS U, SYS.SEQ$ S
      WHERE O.TYPE# = 6
        AND O.NAME  = SeqName
        AND U.USER_ID = O.OWNER#
        AND U.USERNAME  = CidName
        AND O.OBJ#  = S.OBJ#;
 END PSTV0100_CSSGETSEQDATA;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List when Creator and Sequence *
 *  are explicit references.                                          *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST0
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT seqlst0%ISOPEN THEN
        OPEN seqlst0(CidPatternIn, SeqPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH seqlst0 INTO Increment(i), MinValue(i),
                           MaxValue(i), Cycle(i), Ordering(i), Cache(i),
                           CreatorName(i), SequenceName(i);
        IF seqlst0%NOTFOUND THEN
           CLOSE seqlst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSEQLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List when Creator name is a    *
 *  generic LIKE pattern and Sequnce name is an explicit reference.   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST1
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT seqlst1%ISOPEN THEN
        OPEN seqlst1(CidPatternIn, SeqPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH seqlst1 INTO Increment(i), MinValue(i),
                           MaxValue(i), Cycle(i), Ordering(i), Cache(i),
                           CreatorName(i), SequenceName(i);
        IF seqlst1%NOTFOUND THEN
           CLOSE seqlst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSEQLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List when Creator name is an   *
 *  explicit reference and Sequence name is a Generic LIKE pattern    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST2
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT seqlst2%ISOPEN THEN
        OPEN seqlst2(CidPatternIn, SeqPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH seqlst2 INTO Increment(i), MinValue(i),
                           MaxValue(i), Cycle(i), Ordering(i), Cache(i),
                           CreatorName(i), SequenceName(i);
        IF seqlst2%NOTFOUND THEN
           CLOSE seqlst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSEQLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Sequence List when Creator name is a    *
 *  Generic LIKE pattern andd Sequence name is a Generic LIKE pattern *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETSEQLIST3
   (RowsToGet             IN INTEGER,
    CidPatternIn          IN VARCHAR2,
    SeqPatternIn          IN VARCHAR2,
    Increment            OUT t_varchar2,
    MinValue             OUT t_varchar2,
    MaxValue             OUT t_varchar2,
    Cycle                OUT t_bool,
    Ordering             OUT t_bool,
    Cache                OUT t_integer,
    CreatorName          OUT t_creatorname,
    SequenceName         OUT t_sequencename) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT seqlst3%ISOPEN THEN
        OPEN seqlst3(CidPatternIn, SeqPatternIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH seqlst3 INTO Increment(i), MinValue(i),
                           MaxValue(i), Cycle(i), Ordering(i), Cache(i),
                           CreatorName(i), SequenceName(i);
        IF seqlst3%NOTFOUND THEN
           CLOSE seqlst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETSEQLIST3;
END PSTO12V0100_CSSSEQUENCE;
