 CREATE OR REPLACE PACKAGE BODY ~ALTSPQUALIFIER..PSTO12V0100_CSSTRIGGER AS
/*
    Oracle12C package body for Catalog Services Triggers

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Cursor used for Triggers.                                         *
 *--------------------------------------------------------------------*/
 CURSOR trig0 (TblNum INTEGER) IS
 SELECT T.OBJ#,
        O.OWNER#,
        T.ACTIONSIZE,
        DECODE(T.ENABLED,0,'N','Y'),
        DECODE(T.INSERT$,0,'N','Y'),
        DECODE(T.UPDATE$,0,'N','Y'),
        DECODE(T.DELETE$,0,'N','Y'),
        DECODE(T.TYPE#,0,'B',1,'B',2,'A',3,'A',4,'I''X'),
        DECODE(T.TYPE#,0,'S',1,'R',2,'S',3,'R',4,'R''X'),
        U.USERNAME,
        O.NAME
   FROM SYS.TRIGGER$ T,
        SYS.OBJ$ O,
        SYS.DBA_USERS U
  WHERE T.BASEOBJECT = TblNum
    AND O.OBJ#   = T.OBJ#
    AND U.USER_ID  = O.OWNER#
  ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for text.                                             *
 *--------------------------------------------------------------------*/
 CURSOR text0 (PrcNum INTEGER) IS
 SELECT S.SOURCE
   FROM SYS.SOURCE$ S
  WHERE S.OBJ# = PrcNum
  ORDER BY S.LINE;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Procedure List when CID Pattern is explicit   *
 *  and Procedure Pattern is explicit.                                *
 *--------------------------------------------------------------------*/
 CURSOR prclst0 (CidPattern VARCHAR2,
                 PrcPattern VARCHAR2,
                 TypVar1 INTEGER,
                 TypVar2 INTEGER,
                 TypVar3 INTEGER) IS
 SELECT U.USERNAME, O.NAME, DECODE(O.TYPE#, 7, 'P', 8, 'F', 9, 'O', 'X')
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE U.USERNAME = CidPattern
        AND O.OWNER# = U.USER_ID
        AND O.NAME = PrcPattern
        AND O.TYPE# IN (TypVar1, TypVar2, TypVar3)
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Procedure List when CID Pattern is generic    *
 *  and Procedure Pattern is explicit.                                *
 *--------------------------------------------------------------------*/
 CURSOR prclst1 (CidPattern VARCHAR2,
                 PrcPattern VARCHAR2,
                 TypVar1 INTEGER,
                 TypVar2 INTEGER,
                 TypVar3 INTEGER) IS
 SELECT U.USERNAME, O.NAME, DECODE(O.TYPE#, 7, 'P', 8, 'F', 9, 'O', 'X')
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE U.USERNAME like CidPattern
        AND O.OWNER# = U.USER_ID
        AND O.NAME = PrcPattern
        AND O.TYPE# IN (TypVar1, TypVar2, TypVar3)
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Procedure List when CID Pattern is explicit   *
 *  and Procedure Pattern is generic.                                 *
 *--------------------------------------------------------------------*/
 CURSOR prclst2 (CidPattern VARCHAR2,
                 PrcPattern VARCHAR2,
                 TypVar1 INTEGER,
                 TypVar2 INTEGER,
                 TypVar3 INTEGER) IS
 SELECT U.USERNAME, O.NAME, DECODE(O.TYPE#, 7, 'P', 8, 'F', 9, 'O', 'X')
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE U.USERNAME = CidPattern
        AND O.OWNER# = U.USER_ID
        AND O.NAME like PrcPattern
        AND O.TYPE# IN (TypVar1, TypVar2, TypVar3)
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Cursor used for Get Procedure List when CID Pattern is generic    *
 *  and Procedure Pattern is generic.                                 *
 *--------------------------------------------------------------------*/
 CURSOR prclst3 (CidPattern VARCHAR2,
                 PrcPattern VARCHAR2,
                 TypVar1 INTEGER,
                 TypVar2 INTEGER,
                 TypVar3 INTEGER) IS
 SELECT U.USERNAME, O.NAME, DECODE(O.TYPE#, 7, 'P', 8, 'F', 9, 'O', 'X')
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE U.USERNAME like CidPattern
        AND O.OWNER# = U.USER_ID
        AND O.NAME like PrcPattern
        AND O.TYPE# IN (TypVar1, TypVar2, TypVar3)
   ORDER BY U.USERNAME, O.NAME;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Triggers for a Table                    *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTRIGGER
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ObjectNum            OUT t_integer,
    CidNum               OUT t_integer,
    TxtLen               OUT t_integer,
    Enabled              OUT t_char,
    Ins                  OUT t_char,
    Upd                  OUT t_char,
    Del                  OUT t_char,
    TrgTime              OUT t_char,
    TrgMode              OUT t_char,
    OwnerName            OUT t_ownername,
    TrgName              OUT t_objectname) is

 LclEna  CHAR(1);
 LclIns  CHAR(1);
 LclUpd  CHAR(1);
 LclDel  CHAR(1);
 LclTim  CHAR(1);
 LclMod  CHAR(1);
 BEGIN
/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT trig0%ISOPEN THEN
        OPEN trig0(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH trig0 INTO ObjectNum(i),
                         CidNum(i),
                         TxtLen(i),
                         LclEna,
                         LclIns,
                         LclUpd,
                         LclDel,
                         LclTim,
                         LclMod,
                         OwnerName(i),
                         TrgName(i);
        IF trig0%NOTFOUND THEN
           CLOSE trig0;
           EXIT;
        END IF;
        Enabled(i) := LclEna;
        Ins(i) := LclIns;
        Upd(i) := LclUpd;
        Del(i) := LclDel;
        TrgTime(i) := LclTim;
        TrgMode(i) := LclMod;
     END LOOP;
 END PSTV0100_CSSGETTRIGGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Trigger Text for a known trigger        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTRGTEXT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER, /* not used */
    TrgText1             OUT VARCHAR2,
    TrgText2             OUT VARCHAR2) is

  csr INTEGER;
  rc  NUMBER;
  len INTEGER;
  cnk INTEGER := 4000;
 BEGIN
  IF OffsetNumIn = -1 THEN
/*--------------------------------------------------------------------*
 *  Get the Definition and WHEN clauses                               *
 *--------------------------------------------------------------------*/
   SELECT LTRIM(RTRIM(DEFINITION)),
          LTRIM(RTRIM(WHENCLAUSE))
     INTO TrgText1, TrgText2
     FROM SYS.TRIGGER$
    WHERE OBJ# = ObjectNumIn;
  ELSE
/*--------------------------------------------------------------------*
 *  Get a couple of text chunks                                       *
 *--------------------------------------------------------------------*/
   csr := DBMS_SQL.OPEN_CURSOR;
   DBMS_SQL.PARSE(csr, 'SELECT ACTION# FROM SYS.TRIGGER$ WHERE OBJ# = :N',
                  DBMS_SQL.NATIVE);
   DBMS_SQL.BIND_VARIABLE(csr, ':N', ObjectNumIn);
   DBMS_SQL.DEFINE_COLUMN_LONG(csr, 1);
   rc := DBMS_SQL.EXECUTE_AND_FETCH(csr);
   DBMS_SQL.COLUMN_VALUE_LONG(csr, 1, cnk, OffsetNumIn, TrgText1, len);
   DBMS_SQL.COLUMN_VALUE_LONG(csr, 1, cnk, OffsetNumIn+cnk, TrgText2, len);
   DBMS_SQL.CLOSE_CURSOR(csr);
  END IF;
 END PSTV0100_CSSGETTRGTEXT;

/*--------------------------------------------------------------------*
 *  Retrieve the attributes of a Procedure                            *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    PrcName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    CidNum               OUT INTEGER,
    PrcSize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    ProcName             OUT VARCHAR2) is

 LclObj  INTEGER;
 BEGIN
/*--------------------------------------------------------------------*
 *  Retrieve the data for the Procedure                               *
 *--------------------------------------------------------------------*/
     SELECT O.OBJ#, O.OWNER#, U.USERNAME, O.NAME
       INTO LclObj,CidNum,Owner,ProcName
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE O.TYPE# = 7
        AND O.NAME  = PrcName
        AND U.USER_ID = O.OWNER#
        AND U.USERNAME  = CidName;

/*--------------------------------------------------------------------*
 *  Get the total length of the Procedure Text                        *
 *--------------------------------------------------------------------*/
     ObjectNum := LclObj;
     SELECT SUM(LENGTH(S.SOURCE))
       INTO PrcSize
       FROM SYS.SOURCE$ S
      WHERE S.OBJ# = LclObj;
 END PSTV0100_CSSGETPRCDATA;

/*--------------------------------------------------------------------*
 *  Retrieve the attributes of a Function                             *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETFUNDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    FunName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    CidNum               OUT INTEGER,
    FunSize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    FuncName             OUT VARCHAR2) is

 LclObj  INTEGER;
 BEGIN
/*--------------------------------------------------------------------*
 *  Retrieve the data for the Function                                *
 *--------------------------------------------------------------------*/
     SELECT O.OBJ#, O.OWNER#, U.USERNAME, O.NAME
       INTO LclObj,CidNum,Owner,FuncName
       FROM SYS.DBA_USERS U, SYS.OBJ$ O
      WHERE O.TYPE# = 8
        AND O.NAME  = FunName
        AND U.USER_ID = O.OWNER#
        AND U.USERNAME  = CidName;

/*--------------------------------------------------------------------*
 *  Get the total length of the Function Text                         *
 *--------------------------------------------------------------------*/
     ObjectNum := LclObj;
     SELECT SUM(LENGTH(S.SOURCE))
       INTO FunSize
       FROM SYS.SOURCE$ S
      WHERE S.OBJ# = LclObj;
 END PSTV0100_CSSGETFUNDATA;

/*--------------------------------------------------------------------*
 *  Retrieve the attributes of a Package and its Body                 *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKGDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    PkgName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    BodyNum              OUT INTEGER,
    CidNum               OUT INTEGER,
    PkgSize              OUT INTEGER,
    BdySize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    PkgBName             OUT VARCHAR2) is

 LclObj  INTEGER;
 LclBdy  INTEGER;
 BEGIN
     LclBdy := 0;
/*--------------------------------------------------------------------*
 *  Retrieve the data for the Package and Package Body                *
 *--------------------------------------------------------------------*/
     SELECT O.OBJ#, B.OBJ#, O.OWNER#, U.USERNAME, O.NAME
       INTO LclObj,LclBdy,CidNum,Owner,PkgBName
       FROM SYS.DBA_USERS U, SYS.OBJ$ O, SYS.OBJ$ B
      WHERE O.TYPE# = 9
        AND O.NAME  = PkgName
        AND U.USER_ID = O.OWNER#
        AND U.USERNAME  = CidName
        AND B.TYPE# (+) = 11
        AND B.NAME (+) = O.NAME
        AND B.OWNER# (+) = O.OWNER#;

/*--------------------------------------------------------------------*
 *  Get the total length of the Package Text                          *
 *--------------------------------------------------------------------*/
     ObjectNum := LclObj;
     SELECT SUM(LENGTH(S.SOURCE))
       INTO PkgSize
       FROM SYS.SOURCE$ S
      WHERE S.OBJ# = LclObj;

/*--------------------------------------------------------------------*
 *  Get the total length of the Package Body                          *
 *--------------------------------------------------------------------*/
     IF LclBdy IS NULL THEN
       BodyNum := -1;
       BdySize := 0;
     ELSE
       BodyNum := LclBdy;
       SELECT SUM(LENGTH(S.SOURCE))
         INTO BdySize
         FROM SYS.SOURCE$ S
        WHERE S.OBJ# = LclBdy;
     END IF;
 END PSTV0100_CSSGETPKGDATA;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Text for a Proc,Func,Pkg,PkgBody        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCTEXT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PrcText1             OUT t_proctext,
    PrcText2             OUT t_proctext) is

 LclText varchar2(4000);
 BEGIN
/*--------------------------------------------------------------------*
 *  Open the cursor on the source elements                            *
 *--------------------------------------------------------------------*/
     IF NOT text0%ISOPEN THEN
        OPEN text0(ObjectNumIn);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH text0 INTO LclText;
        IF text0%NOTFOUND THEN
           CLOSE text0;
           EXIT;
        END IF;
     IF LENGTH(LclText) > 2000 THEN
        PrcText1(i) := SUBSTR(LclText,1,2000);
        PrcText2(i) := SUBSTR(LclText,2001);
        ELSE
        PrcText1(i) := LclText;
        PrcText2(i) := NULL;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPRCTEXT;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Procedure List when Creator and         *
 *  Procedure are explicit references.                                *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST0
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT prclst0%ISOPEN THEN
        OPEN prclst0(CidPattern,PrcPattern,TypVar1,TypVar2,TypVar3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH prclst0 INTO CreatorName(i),ProcedureName(i),SubType(i);
        IF prclst0%NOTFOUND THEN
           CLOSE prclst0;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPRCLIST0;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Procedure List when Creator name is a   *
 *  generic LIKE pattern and Procedure name is an explicit reference. *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST1
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT prclst1%ISOPEN THEN
        OPEN prclst1(CidPattern,PrcPattern,TypVar1,TypVar2,TypVar3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH prclst1 INTO CreatorName(i),ProcedureName(i),SubType(i);
        IF prclst1%NOTFOUND THEN
           CLOSE prclst1;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPRCLIST1;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Procedure List when Creator name is an  *
 *  explicit reference and Procedure name is a Generic LIKE pattern   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST2
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT prclst2%ISOPEN THEN
        OPEN prclst2(CidPattern,PrcPattern,TypVar1,TypVar2,TypVar3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH prclst2 INTO CreatorName(i),ProcedureName(i),SubType(i);
        IF prclst2%NOTFOUND THEN
           CLOSE prclst2;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPRCLIST2;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Procedure List when Creator name is a   *
 *  Generic LIKE pattern and Procedure name is a Generic LIKE pattern *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST3
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char) is

 BEGIN

/*--------------------------------------------------------------------*
 *  If this is initial call open query cursor                         *
 *--------------------------------------------------------------------*/
     IF NOT prclst3%ISOPEN THEN
        OPEN prclst3(CidPattern,PrcPattern,TypVar1,TypVar2,TypVar3);
     END IF;

/*--------------------------------------------------------------------*
 *  Retrieve the number OF records requested by the caller            *
 *--------------------------------------------------------------------*/
     FOR i IN 1..RowsToGet LOOP
        FETCH prclst3 INTO CreatorName(i),ProcedureName(i),SubType(i);
        IF prclst3%NOTFOUND THEN
           CLOSE prclst3;
           EXIT;
        END IF;
     END LOOP;
 END PSTV0100_CSSGETPRCLIST3;
END PSTO12V0100_CSSTRIGGER;
