 CREATE OR REPLACE PACKAGE ~ALTSPQUALIFIER..PSTO12V0100_CSSTRIGGER AS
/*
    Oracle12C package Catalog Services Triggers,Functions,Procedures

    Licensed Materials - Property of IBM

    "Restricted Materials of IBM"

    5724-U38, 5724-U39, 5724-U48

     Copyright IBM Corp. 2017 All Rights Reserved

     Copyright 2017 UNICOM Systems, Inc. - All Rights Reserved

    US Government Users Restricted Rights - Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with
    IBM Corp.
*/
/*--------------------------------------------------------------------*
 *  Declare the PL/SQL Tables used by the Procedures in this package  *
 *--------------------------------------------------------------------*/
   TYPE t_ownername     IS TABLE OF SYS.DBA_USERS.USERNAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_objectname       IS TABLE OF SYS.OBJ$.NAME%TYPE
         INDEX BY BINARY_INTEGER;
   TYPE t_integer       IS TABLE OF INTEGER
         INDEX BY BINARY_INTEGER;
   TYPE t_char          IS TABLE OF CHAR(1)
         INDEX BY BINARY_INTEGER;
   TYPE t_proctext      IS TABLE OF VARCHAR2(2000)
         INDEX BY BINARY_INTEGER;

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Trigger List from Table Object Number   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTRIGGER
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    ObjectNum            OUT t_integer,
    CidNum               OUT t_integer,
    TxtLen               OUT t_integer,
    Enabled              OUT t_char,
    Ins                  OUT t_char,
    Upd                  OUT t_char,
    Del                  OUT t_char,
    TrgTime              OUT t_char,
    TrgMode              OUT t_char,
    OwnerName            OUT t_ownername,
    TrgName              OUT t_objectname);

/*--------------------------------------------------------------------*
 *  Procedure used to acquire Trigger Text for a known trigger        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETTRGTEXT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    OffsetNumIn           IN INTEGER,
    ColumnNumIn           IN INTEGER, /* not used */
    TrgText1             OUT VARCHAR2,
    TrgText2             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to get Extended Data for a specific Procedure      *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    PrcName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    CidNum               OUT INTEGER,
    PrcSize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    ProcName             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to get Extended data for a specific Function       *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETFUNDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    FunName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    CidNum               OUT INTEGER,
    FunSize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    FuncName             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to get Extended data for a specific Package        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPKGDATA
   (RowsToGet             IN INTEGER,
    CidName               IN VARCHAR2,
    PkgName               IN VARCHAR2,
    ObjectNum            OUT INTEGER,
    BodyNum              OUT INTEGER,
    CidNum               OUT INTEGER,
    PkgSize              OUT INTEGER,
    BdySize              OUT INTEGER,
    Owner                OUT VARCHAR2,
    PkgBName             OUT VARCHAR2);

/*--------------------------------------------------------------------*
 *  Procedure used to get Text for Procedure,Function, Package        *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCTEXT
   (RowsToGet             IN INTEGER,
    ObjectNumIn           IN INTEGER,
    PrcText1             OUT t_proctext,
    PrcText2             OUT t_proctext);

/*--------------------------------------------------------------------*
 *  Procedure used to get Procedure List for explicit CID and Procs   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST0
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char);

/*--------------------------------------------------------------------*
 *  Get Procedure List for wildcard CID and explicit Procedure name   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST1
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char);

/*--------------------------------------------------------------------*
 *  Get Procedure List for explicit CID and wildcard Procedure name   *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST2
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char);

/*--------------------------------------------------------------------*
 *  Get Procedure List for wildcard CID and Procedure names           *
 *--------------------------------------------------------------------*/
 PROCEDURE PSTV0100_CSSGETPRCLIST3
   (RowsToGet             IN INTEGER,
    CidPattern            IN VARCHAR2,
    PrcPattern            IN VARCHAR2,
    TypVar1               IN INTEGER,
    TypVar2               IN INTEGER,
    TypVar3               IN INTEGER,
    CreatorName          OUT t_ownername,
    ProcedureName        OUT t_objectname,
    SubType              OUT t_char);
 END PSTO12V0100_CSSTRIGGER;
/

grant execute on ~ALTSPQUALIFIER..PSTO12V0100_CSSTRIGGER to ~ALTGRANTAUTHID
/

