#!/bin/sh
# This script creates symbolic links for the Data Direct driver manager
# Usage: 
# sh createDriverManagerSymLinks.sh <path>
# <path> - This is the path to the folder containing the Data Direct driver manager binaries. For Optim Distributed this is ($PSTHOME/bin).
#
# Note:
# On SunOS, the standards compliant sh utility must be used to execute the script
# /usr/xpg4/bin/sh createDataDirectSymLinks.sh <path>
#


if [ "$1" = "" ]
then
   echo "The first argument to the script must be the folder containing the Data Direct driver manager binaries. For Optim Distributed this is the bin folder under rt."
   exit 1
fi

# Verify that libodbc.so and libodbcinst.so are present.
if [ ! -e $1/libodbc.so ]
then
   echo "Cannot create symbolic links to $1/libodbc.so since it does not exist."
   exit 1
fi
if [ ! -e $1/libodbcinst.so ]
then
   echo "Cannot create symbolic links to $1/libodbcinst.so since it does not exist."
   exit 1
fi

echo "Deleting Data Direct driver manager symbolic links and duplicates."
[[ -L $1/libodbc.so.1 || -e $1/libodbc.so.1 ]] && rm $1/libodbc.so.1
[[ -L $1/libodbcinst.so.1 || -e $1/libodbcinst.so.1 ]] && rm $1/libodbcinst.so.1
[[ -L $1/libodbc.so.2 || -e $1/libodbc.so.2 ]] && rm $1/libodbc.so.2
[[ -L $1/libodbcinst.so.2 || -e $1/libodbcinst.so.2 ]] && rm $1/libodbcinst.so.2

echo "Creating Data Direct driver manager symbolic links."
ln -s $1/libodbc.so $1/libodbc.so.1
ln -s $1/libodbcinst.so $1/libodbcinst.so.1
ln -s $1/libodbc.so $1/libodbc.so.2
ln -s $1/libodbcinst.so $1/libodbcinst.so.2
