#!/bin/ksh
# 
# -cr_beg-
# ********************************************************************
# IBM Confidential
# OCO Source Materials
# 5724-U38, 5724-U39, 5724-U48, 5655-V17, 5655-V19, 5655-V35, 5655-V37
# (C) Copyright IBM Corp. 2009
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
# ********************************************************************
# -cr_end-
# 


# ----------------------------------------------------------------------------
# Script pstinfo
#
#  Parameters passed are
#        1 = Pid of program spawning this, used to identify files created
#        2 = Option ('core' to produce core dump, but in windows that's
#            the default
#
#  The caller also sets the following environment variables
#
#      PSTHOME  Install directory (beneath this is the bin and etc subdir).
#         If omitted some utilities that are distributed with the product
#         so we default to the directory where this batch was located.
#      PSTHOMEDATA Data directory from Applet/options
#         If omitted we won't be able to zip of the sql logs
#         we default to $PSTHOME/data if it exist else we don't get the files
#      PSTHOMETEMP Temp directory from Applet/options
#         Output directory, If omitted we will default to the TEMP virable
#         we default to $PSTHOME/temp if it exist else we use /tmp
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Change this list if you want to execute one of our programs under SUDO
# example in AIX would be:   sudoers="pstat"
# ----------------------------------------------------------------------------
sudoers=""

# ----------------------------------------------------------------------------
# Do not modify from this point on
# ----------------------------------------------------------------------------

# This will end up being the prefix for all files
filePfx=""

# This will end up being the output file
outFile=""

# Copy to make it global
ourPid=$1
options=$2
outDir=${PSTHOMETEMP}
binDir=${PSTHOME}/bin
dtaDir=${PSTHOMEDATA}

# Globals
gSudo=""
gPlatform=""

# ----------------------------------------------------------------------------
# Handle defaults
# ----------------------------------------------------------------------------
if [ -z "$ourPid" ]; then

   ourPid=$$
   echo "PID for the program executing this script was not passed as argument, assuming $ourPid"

fi

if [ -z "$outDir" ]; then

   if [ -z "$PSTHOME" ]; then
      outDir="/tmp"
   else
      if [ -d $PSTHOME/temp ]; then
         outDir="$PSTHOME/temp"
      else
         outDir="/tmp"
      fi
   fi

   echo "PSTHOMETEMP not set, assuming $outDir"

fi

if [ -z "$binDir" ]; then

   if [ -z "$PSTHOME" ]; then
      binDir="."
   else
      if [ -d $PSTHOME/bin ]; then
         binDir="$PSTHOME/bin"
      else
         binDir="."
      fi
   fi

   echo "PSTHOME not set assuming $binDir"

fi

if [ -z "$dtaDir" ]; then

   if [ -n "$PSTHOME" ]; then
      if [ -d $PSTHOME/data ]; then
         dtaDir="$PSTHOME/data"
      fi
   fi

   if [ -n "$dtaDir" ]; then
      echo "PSTHOMEDATA not set, assuming $dtaDir"
   fi

fi

# ----------------------------------------------------------------------------
# printBanner
#     There is probably a better way but this works in all platforms
# ----------------------------------------------------------------------------
printBanner()
{
   if [ -z "$2" ]; then
      pb_ch="-"
   else
      pb_ch=$2
   fi

   bantxtx="$pb_ch"

   ((banlen=${#1}))
   ((banlen=77-$banlen))
   ((banlen=$banlen/2))

   while [ ${#bantxtx} -lt $banlen ]
   do
      bantxtx="$bantxtx$pb_ch"
   done

   if [ "$1" = "$pb_ch" ]; then
      bantxt="$bantxtx$pb_ch$1$pb_ch$bantxtx"
   else
      bantxt="$bantxtx $1 $bantxtx"
   fi

   while [ ${#bantxt} -lt 79 ]
   do
      bantxt="$bantxt$pb_ch"
   done

   echo "$bantxt" >> $outFile
}

# ----------------------------------------------------------------------------
# isSudo
# ----------------------------------------------------------------------------
isSudo()
{
   for sudo_prg in $sudoers
   do
      if [ -n "$sudo_prg" ]; then
         if [ "$sudo_prg" = "$1" ]; then
            return 0
         fi
      fi
   done

   return 1
}

# ----------------------------------------------------------------------------
# isOnPath: Checks if program is on path or specified directory
#     Used to skip programs that are not installed
# ----------------------------------------------------------------------------
isOnPath()
{
   # isOnPath program "path:path:path"
   oldIfs=$IFS
   IFS=:

   for iop_dir in $2
   do
      if [ -n "$iop_dir" ]; then
         IsOnPathPrg="$iop_dir/$1"
         if [ -f $IsOnPathPrg ]; then
            IFS=$oldIfs
            return 0
         fi
      fi
   done

   echo "Could not find $1 in $2" >> $outFile

   IFS=$oldIfs

   return 1
}

# ----------------------------------------------------------------------------
# isOnPathExe: Checks if program is on path or specified directory and
#              executable
# ----------------------------------------------------------------------------
isOnPathExe()
{
   # See if on passed in subdirectories or the PATH
   if isOnPath $1 "$2:$PATH" ; then

      # On path, can WE execute it?
      if [ -x $IsOnPathPrg ]; then

         # Is there a sudo list?
         if [ -n "$sudoers" ]; then

            # If this guy is in it prefix with the sudo path
            if isSudo $1; then
               IsOnPathPrg="$gSudo $IsOnPathPrg"
            fi

         fi

         return 0
      fi

      # On path but not executable
      echo "Program $IsOnPathPrg is not executable by this process" >> $outFile

   fi

   # Not on path
   return 1
}

# ----------------------------------------------------------------------------
# doSUN: Solaris specific
# ----------------------------------------------------------------------------
doSUN()
{
   for F in `ps -e | grep pr0 | awk "{print \\$1}"`; do

      echo "Gathering information for PID $F"

      printBanner "=" "="
      printBanner "$F" "="
      printBanner "=" "="

      if isOnPathExe "pstack" "/usr/proc/bin"; then
         printBanner "pstack -f $F"
         $IsOnPathPrg -F $F >> $outFile 2>&1
      fi

      if isOnPathExe "pmap" "/usr/proc/bin"; then
         printBanner "pmap -rlF $F"
         $IsOnPathPrg -rlF $F >> $outFile 2>&1
         printBanner "pmap -xlF $F"
         $IsOnPathPrg -xlF $F >> $outFile 2>&1
      fi

      if isOnPathExe "pflags" "/usr/proc/bin"; then
         printBanner "pflags -r $F"
         $IsOnPathPrg -r $F >> $outFile 2>&1
      fi

      if isOnPathExe "pcred" "/usr/proc/bin"; then
         printBanner "pcred $F"
         $IsOnPathPrg $F >> $outFile 2>&1
      fi

      if isOnPathExe "pldd" "/usr/proc/bin"; then
         printBanner "pldd -F $F"
         $IsOnPathPrg -F $F >> $outFile 2>&1
      fi

      if isOnPathExe "psig" "/usr/proc/bin"; then
         printBanner "psig $F"
         $IsOnPathPrg $F >> $outFile 2>&1
      fi

      if isOnPathExe "pfiles" "/usr/proc/bin"; then
         printBanner "pfiles -F $F"
         $IsOnPathPrg -F $F >> $outFile 2>&1
      fi

      if isOnPathExe "pwdx" "/usr/proc/bin"; then
         printBanner "pwdx -F $F"
         $IsOnPathPrg -F $F >> $outFile 2>&1
      fi

      if isOnPathExe "ptree" "/usr/proc/bin"; then
         printBanner "$ptree -a $F"
         $IsOnPathPrg -a $F >> $outFile 2>&1
      fi

      if [ "$options" = "core" ]; then
         if isOnPathExe "gcore" "/usr/bin"; then
            printBanner "gcore -o ${outFile}.core $F"
            $IsOnPathPrg -o ${filePfx}.core $F >> $outFile 2>&1
         fi
       fi

   done

   if isOnPathExe "ipcs" "/usr/bin"; then
      printBanner "ipcs -a"
      $IsOnPathPrg -a >> $outFile 2>&1
   fi

   if isOnPathExe "swap" "/usr/sbin"; then
      printBanner "swap -l"
      $IsOnPathPrg -l >> $outFile 2>&1
      printBanner "swap -s"
      $IsOnPathPrg -s >> $outFile 2>&1
   fi

   if isOnPathExe "lsof" "/usr/local/bin"; then
      printBanner "lsof -i tcp"
      $IsOnPathPrg -i tcp  >> $outFile 2>&1
   fi
}

# ----------------------------------------------------------------------------
# HP-UX specific
# ----------------------------------------------------------------------------
doHPUX()
{
   # pr0hpux will get stacks for all running pr0* processes and put them into $PSTHOME
   if isOnPathExe "pr0hpux" "$PSTHOME/bin"; then
      hpuxPrg=$IsOnPathPrg
      if isOnPathExe "mv" "/sbin/mv:/usr/bin"; then
         printBanner "pr0hpux -stacks"
         $hpuxPrg -stacks >> $outFile
         $IsOnPathPrg $PSTHOME/pr0hpux.out $filePfx.stk
      fi
   fi

   if isOnPathExe "lsof" "/usr/local/bin"; then
      printBanner "lsof -i tcp"
      $IsOnPathPrg -i tcp >> $outFile 2>&1
   fi
}

# ----------------------------------------------------------------------------
# AIX specific
# ----------------------------------------------------------------------------
doAIX()
{
   # Proc commands available only on AIX 5.x
   if [ `uname -v` = "5" ]; then

      for F in `ps -e | grep pr0 | awk "{print \\$1}"`; do

         echo "Gathering information for PID $F"

         printBanner "=" "@"
         printBanner "$F" "="
         printBanner "=" "@"

         if isOnPathExe "procstack" "/usr/bin" ; then
            printBanner "procstack -F $F"
            $IsOnPathPrg -F $F >> $outFile 2>&1
         fi

         if isOnPathExe "procmap" "/usr/bin"; then
            printBanner "procmap -F $F"
            $IsOnPathPrg -F $F >> $outFile 2>&1
         fi

         if isOnPathExe "procflags" "/usr/bin"; then
            printBanner "procflags -r $F"
            $IsOnPathPrg -r $F >> $outFile 2>&1
         fi

         if isOnPathExe "proccred" "/usr/bin"; then
            printBanner "proccred $F"
            $IsOnPathPrg $F >> $outFile 2>&1
         fi

         if isOnPathExe "procldd" "/usr/bin"; then
            printBanner "procldd -F $F"
            $IsOnPathPrg -F $F >> $outFile 2>&1
         fi

         if isOnPathExe "procsig" "/usr/bin"; then
            printBanner "procsig $F"
            $IsOnPathPrg $F >> $outFile 2>&1
         fi

         if isOnPathExe "procfiles" "/usr/bin"; then
            printBanner "procfiles -nF $F"
            $IsOnPathPrg -nF $F >> $outFile 2>&1
         fi

         if isOnPathExe "procwdx" "/usr/bin"; then
            printBanner "procwdx $F"
            $IsOnPathPrg $F >> $outFile 2>&1
         fi

         if isOnPathExe "proctree" "/usr/bin"; then
            printBanner "proctree -a $F"
            $IsOnPathPrg -a $F >> $outFile 2>&1
         fi

      done

      if isOnPathExe "swap" "/usr/sbin"; then
         printBanner "swap -l"
         $IsOnPathPrg -l >> $outFile 2>&1
         printBanner "swap -s"
         $IsOnPathPrg -s >> $outFile 2>&1
      fi

   else

      # NOTE: The problem with pstat is that it usually does not work unless
      #       you are ROOT. However, it is important to run this script under
      #       the owner of the program so mwmemvalid, etc work fine.
      #
      #       The solution is to put pstat as a setuid or sudo file

      if isOnPathExe "pstat" "/usr/sbin"; then
         printBanner "pstat -s"
         $IsOnPathPrg -s >> $outFile 2>&1
         printBanner "pstat -f"
         $IsOnPathPrg -f >> $outFile 2>&1
         printBanner "pstat -a"
         $IsOnPathPrg -a  >> $outFile 2>&1
      fi

   fi
}

# ----------------------------------------------------------------------------
# Red Hat Linux specific
# ----------------------------------------------------------------------------
doREDHAT()
{
   for F in `ps -e | grep pr0 | awk "{print \\$1}"`; do

      echo "Gathering information for PID $F"

      printBanner "=" "@"
      printBanner "$F" "="
      printBanner "=" "@"

      if isOnPathExe "pstack" "/usr/bin"; then
         printBanner "pstack"
         $IsOnPathPrg $F >> $outFile 2>&1
      fi

      if isOnPathExe "cat" "/bin"; then
         printBanner "cat /proc/$F/bin"
         $IsOnPathPrg /proc/$F/maps   >> $outFile 2>&1
      fi

      if isOnPathExe "ls" "/bin"; then
         printBanner "ls -la /proc/$F/fd"
         $IsOnPathPrg -la /proc/$F/fd >> $outFile 2>&1
      fi

   done

   if isOnPathExe "free" "/usr/bin"; then
      printBanner "free -l"
      $IsOnPathPrg -l >> $outFile 2>&1
   fi
}

# ----------------------------------------------------------------------------
# Change to the output directory and validate the change
# ----------------------------------------------------------------------------
cd $outDir

if [ "`pwd`" != "$outDir" ]; then
   echo "pstinfo: Could not change to the output directory $outDir"
   echo "pstinfo: Current directory is `pwd`"
   echo "pstinfo: Aborted"
   exit 1
fi

# ----------------------------------------------------------------------------
# Remove all the output files
# ----------------------------------------------------------------------------
filePfx="pstinfo.$ourPid"

rm $filePfx.*.core > /dev/null 2>&1
rm $filePfx.mem > /dev/null 2>&1
rm $filePfx.out > /dev/null 2>&1
rm $filePfx.stk > /dev/null 2>&1
rm $filePfx.pstserv.cfg > /dev/null 2>&1
rm $filePfx.pstlocal.cfg > /dev/null 2>&1
rm $filePfx.locale.conf > /dev/null 2>&1
rm $filePfx.sqlnet.log > /dev/null 2>&1

# ----------------------------------------------------------------------------
# Get output redirected stdout file
# ----------------------------------------------------------------------------
outFile="$filePfx.out"

# ----------------------------------------------------------------------------
# Eyecatcher output
# ----------------------------------------------------------------------------
usr=$USER
if [ -z $usr ]; then
   usr=$LOGNAME
fi

echo ========================================================================= > $outFile
echo Created by $usr on `date`                                                 >> $outFile
echo `uname -a`                                                                >> $outFile
echo ========================================================================= >> $outFile

# ----------------------------------------------------------------------------
# Get location of sudo if sudoers not empty (if sudo not found set empty)
# ----------------------------------------------------------------------------
if [ -n "$sudoers" ]; then
   if [ -z "$gSudo" ]; then
      if isOnPath "sudo" "/usr/local/bin"; then
         gSudo=$IsOnPathPrg
      else
         sudoers=""
      fi
   fi
fi

# ----------------------------------------------------------------------------
# Get platform specific info
# ----------------------------------------------------------------------------
case `uname -s` in
HP-UX)
    gPlatform="H"
    doHPUX
    ;;
SunOS)
    gPlatform="S"
    doSUN
    ;;
AIX)
    gPlatform="A"
    doAIX
    ;;
Linux)
    gPlatform="R"
    doREDHAT
    ;;
*)
    echo Unknown O/S
    exit 1
    ;;
esac

# ----------------------------------------------------------------------------
# Common commands
# ----------------------------------------------------------------------------

if isOnPathExe "netstat" "/usr/bin"; then
   printBanner "netstat -a"
   $IsOnPathPrg -a >> $outFile 2>&1
fi

if isOnPathExe "ps" "/usr/bin"; then
   printBanner "ps -ef"
   $IsOnPathPrg -ef >> $outFile 2>&1
fi

if isOnPathExe "mwadm" "$PSTHOME/bin"; then
   printBanner "mwadm status"
   $IsOnPathPrg status >> $outFile 2>&1
fi

if isOnPathExe "mwmemvalid" "$PSTHOME/bin"; then
   printBanner "mwmemvalid -n -a"
   $IsOnPathPrg -n -a >> $outFile 2>&1
   printBanner "mwmemvalid -n -d $filePfx.mem"
   $IsOnPathPrg -n -d $filePfx.mem >> $outFile 2>&1
fi

if isOnPathExe "env" "/usr/bin"; then
   printBanner "env"
   $IsOnPathPrg >> $outFile 2>&1
fi

# ----------------------------------------------------------------------------
# Find tar and compress
# (I know gzip, bzip2, etc may be better but I KNOW compress is on the system)
# ----------------------------------------------------------------------------
tarPrg=""
cmpPrg=""

if isOnPathExe "tar" "/usr/bin"; then
   tarPrg=$IsOnPathPrg
   if isOnPathExe "compress" "/usr/bin"; then
      cmpPrg=$IsOnPathPrg
   fi
fi

if [ -z "$tarPrg" ]; then
   if isOnPathExe "tar" "/bin"; then
      tarPrg=$IsOnPathPrg
      if isOnPathExe "compress" "/bin"; then
         cmpPrg=$IsOnPathPrg
      fi
   fi
fi

# ----------------------------------------------------------------------------
# TAR and ZIP up the output(s)
# ----------------------------------------------------------------------------
if [ -n "$tarPrg" ]; then

   # build list of files to tar
   fileList="$filePfx.out"

   if [ -f $filePfx.mem ]; then
      fileList="$fileList $filePfx.mem"
   fi

   if [ -f $filePfx.stk ]; then
      fileList="$fileList $filePfx.stk"
   fi

   if [ -f $filePfx.core ]; then
      fileList="$fileList $filePfx.core"
   fi

   if [ -f $filePfx.*.core ]; then
      fileList="$fileList $filePfx.*.core"
   fi

   if [ -f $PSTHOME/etc/pstserv.cfg ]; then
      cp $PSTHOME/etc/pstserv.cfg $filePfx.pstserv.cfg
      fileList="$fileList $filePfx.pstserv.cfg"
   fi

   if [ -f $PSTHOME/etc/pstlocal.cfg ]; then
      cp $PSTHOME/etc/pstlocal.cfg $filePfx.pstlocal.cfg
      fileList="$fileList $filePfx.pstlocal.cfg"
   fi

   if [ -f $PSTHOME/etc/locale.conf ]; then
      cp $PSTHOME/etc/locale.conf $filePfx.locale.conf
      fileList="$fileList $filePfx.locale.conf"
   fi

   if [ -f $dtaDir/sqlnet.log ]; then
      cp $dtaDir/sqlnet.log $filePfx.sqlnet.log
      fileList="$fileList $filePfx.sqlnet.log"
   fi

   if [ -f sql.txt ]; then
      fileList="$fileList sql.txt"
   fi

   echo "tarring and compressing files -- this could take some time"
   $tarPrg -cf X$filePfx.tar $fileList

   $cmpPrg -f X$filePfx.tar

   rm $filePfx.*

   mv X$filePfx.tar.Z $filePfx.tar.Z

   echo "Please send the file $filePfx.tar.Z to Princeton Softech Support"

else

   echo "Please send all files matching $filePfx.* to Princeton Softech Support"

fi

# ----------------------------------------------------------------------------
# Tar up the traces
# ----------------------------------------------------------------------------
if [ -n "$tarPrg" ]; then

   echo "tarring and compressing traces"

   if [ -f pr0svce.out ]; then
      $tarPrg -cf psttraces.tar PR0*.0* pr0svce.out
   else
      $tarPrg -cf psttraces.tar PR0*.0*
   fi

   $cmpPrg -f psttraces.tar

   echo "Please send the file psttrace.tar.Z to Princeton Softech Support"

else

   echo "Please send all files matching PR0*.0* and pstsvce.out to Princeton Softech Support"

fi

# ----------------------------------------------------------------------------
# Clean up
# ----------------------------------------------------------------------------
rm $filePfx.*.core > /dev/null 2>&1
rm $filePfx.mem > /dev/null 2>&1
rm $filePfx.out > /dev/null 2>&1
rm $filePfx.stk > /dev/null 2>&1
rm $filePfx.pstserv.cfg > /dev/null 2>&1
rm $filePfx.pstlocal.cfg > /dev/null 2>&1
rm $filePfx.locale.conf > /dev/null 2>&1
rm $filePfx.sqlnet.log > /dev/null 2>&1

exit 0
